@@ -1,10 +1,26 @@
 <?php
 /**
+ * Zend Framework
+ *
+ * LICENSE
+ *
+ * This source file is subject to the new BSD license that is bundled
+ * with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://framework.zend.com/license/new-bsd
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@zend.com so we can send you a copy immediately.
+ *
+ * @category   Zend
  * @package    Zend_Cache
  * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id: CoreTest.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
- /**
+/**
  * Zend_Cache
  */
 require_once 'Zend/Cache.php';
@@ -12,17 +28,18 @@ require_once 'Zend/Cache/Core.php';
 require_once 'Zend/Cache/Backend/File.php'; // TODO : use only Test backend ?
 require_once 'Zend/Cache/Backend/Test.php';
 
-/**
- * PHPUnit test case
- */
-require_once 'PHPUnit/Framework/TestCase.php';
+require_once 'Zend/Config.php';
 
 /**
+ * @category   Zend
  * @package    Zend_Cache
  * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Cache
  */
-class Zend_Cache_CoreTest extends PHPUnit_Framework_TestCase {
-
+class Zend_Cache_CoreTest extends PHPUnit_Framework_TestCase
+{
     private $_instance;
 
     public function setUp()
@@ -44,10 +61,42 @@ class Zend_Cache_CoreTest extends PHPUnit_Framework_TestCase {
         $test = new Zend_Cache_Core(array('lifetime' => 3600, 'caching' => true));
     }
 
+    /**
+     * @group ZF-7568
+     */
+    public function testConstructorCorrectCallWithZendConfig()
+    {
+        $test = new Zend_Cache_Core(
+            new Zend_Config(array('lifetime' => 3600, 'caching' => true))
+        );
+    }
+
+    /**
+     * @group ZF-7568
+     */
+    public function testSettingOptionsWithZendConfig()
+    {
+        $config = new Zend_Config(array('lifetime' => 3600, 'caching' => true));
+        $test = new Zend_Cache_Core();
+        $test->setConfig($config);
+        $this->assertEquals(3600, $test->getOption('lifetime'));
+    }
+
+    /**
+     * @group ZF-9092
+     */
+    public function testSettingLifetimeAsEmptyIsInterpretedAsNull()
+    {
+        $config = new Zend_Config(array('lifetime' => '', 'caching' => true));
+        $test = new Zend_Cache_Core();
+        $test->setConfig($config);
+        $this->assertSame(NULL, $test->getOption('lifetime'));
+    }
+
     public function testConstructorBadOption()
     {
         try {
-            $test = new Zend_Cache_Core(array('foo' => 'bar', 'lifetime' => 3600));
+            $test = new Zend_Cache_Core(array(0 => 'bar', 'lifetime' => 3600));
         } catch (Zend_Cache_Exception $e) {
             return;
         }
@@ -89,14 +138,25 @@ class Zend_Cache_CoreTest extends PHPUnit_Framework_TestCase {
         $this->fail('Zend_Cache_Exception was expected but not thrown');
     }
 
+    /**
+     * Unknown options are okay and should be silently ignored. Non-string
+     * options, however, should throw exceptions.
+     *
+     * @group ZF-5034
+     */
     public function testSetOptionUnknownOption()
     {
+        try {
+            $this->_instance->setOption(0, 1200);
+            $this->fail('Zend_Cache_Exception was expected but not thrown');
+        } catch (Zend_Cache_Exception $e) {
+        }
+
         try {
             $this->_instance->setOption('foo', 1200);
         } catch (Zend_Cache_Exception $e) {
-            return;
+            $this->fail('Zend_Cache_Exception was thrown but should not have been');
         }
-        $this->fail('Zend_Cache_Exception was expected but not thrown');
     }
 
     public function testSaveCorrectBadCall1()
@@ -224,13 +284,15 @@ class Zend_Cache_CoreTest extends PHPUnit_Framework_TestCase {
 
     public function testSaveCorrectCallButFileCorruption()
     {
+        $cacheIdPrefix = 'cacheIdPrefix';
+        $this->_instance->setOption('cache_id_prefix', $cacheIdPrefix);
         $res = $this->_instance->save('data', 'false', array('tag1', 'tag2'));
         $logs = $this->_backend->getAllLogs();
         $expected1 = array(
             'methodName' => 'save',
             'args' => array(
                 0 => 'data',
-                1 => 'false',
+                1 => $cacheIdPrefix . 'false',
                 2 => array(
                     0 => 'tag1',
                     1 => 'tag2'
@@ -240,7 +302,7 @@ class Zend_Cache_CoreTest extends PHPUnit_Framework_TestCase {
         $expected2 = array(
             'methodName' => 'remove',
             'args' => array(
-                0 => 'false'
+                0 => $cacheIdPrefix.'false'
             )
         );
         $this->assertFalse($res);
@@ -425,6 +487,61 @@ class Zend_Cache_CoreTest extends PHPUnit_Framework_TestCase {
         $this->assertEquals($expected, $log);
     }
 
+    public function testGetIds()
+    {
+        $this->_instance->setOption('cache_id_prefix', 'prefix_');
+        $ids = $this->_instance->getIds();
+        $this->assertContains('id1', $ids);
+        $this->assertContains('id2', $ids);
+    }
+
+    public function testGetIdsMatchingTags()
+    {
+        $this->_instance->setOption('cache_id_prefix', 'prefix_');
+        $ids = $this->_instance->getIdsMatchingTags(array('tag1', 'tag2'));
+        $this->assertContains('id1', $ids);
+        $this->assertContains('id2', $ids);
+    }
+
+    public function testGetIdsNotMatchingTags()
+    {
+        $this->_instance->setOption('cache_id_prefix', 'prefix_');
+        $ids = $this->_instance->getIdsNotMatchingTags(array('tag3', 'tag4'));
+        $this->assertContains('id3', $ids);
+        $this->assertContains('id4', $ids);
+    }
+
+    public function testGetIdsMatchingAnyTags()
+    {
+        $this->_instance->setOption('cache_id_prefix', 'prefix_');
+        $ids = $this->_instance->getIdsMatchingAnyTags(array('tag5', 'tag6'));
+        $this->assertContains('id5', $ids);
+        $this->assertContains('id6', $ids);
+    }
+
+    public function testLoggerSanity()
+    {
+        $this->_instance = new Zend_Cache_Core(array(
+            'logging' => true
+        ));
+        $this->_instance->setBackend($this->_backend);
+
+        $logger = $this->_instance->getOption('logger');
+        $this->assertType('Zend_Log', $logger);
+    }
+
+    /**
+     * @group ZF-10189
+     */
+    public function testIfFileZendLogWasIncluded()
+    {
+        if (class_exists('Zend_Log', false)) {
+            $this->markTestSkipped('File Zend/Log.php already included');
+        }
+
+        $cacheCore = new Zend_Cache_Core(
+            array('logging' => true)
+        );
+        $this->assertTrue($cacheCore->getOption('logger') instanceof Zend_Log);
+    }
 }
-
-
