@@ -15,16 +15,11 @@
  * @category   Zend
  * @package    Zend_Config
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: IniTest.php 9636 2008-06-08 15:04:42Z rob $
+ * @version    $Id: IniTest.php 24715 2012-04-17 13:53:52Z rob $
  */
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
 /**
  * Zend_Config_Ini
  */
@@ -34,8 +29,9 @@ require_once 'Zend/Config/Ini.php';
  * @category   Zend
  * @package    Zend_Config
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Config
  */
 class Zend_Config_IniTest extends PHPUnit_Framework_TestCase
 {
@@ -226,29 +222,33 @@ class Zend_Config_IniTest extends PHPUnit_Framework_TestCase
 
     public function testZF739()
     {
+        if (version_compare('5.3.0', PHP_VERSION) < 1) {
+            $this->markTestSkipped('PHP >= 5.3.0 does not allow : as a nest separator');
+            return;
+        }
+
         $config = new Zend_Config_Ini($this->_iniFileSeparatorConfig, 'all', array('nestSeparator'=>':'));
 
         $this->assertEquals('all', $config->hostname);
         $this->assertEquals('live', $config->db->name);
         $this->assertEquals('multi', $config->one->two->three);
     }
-    
+
     public function testZF2508NoSections()
     {
         $config = new Zend_Config_Ini($this->_iniFileNoSectionsConfig);
-        
+
         $this->assertEquals('all', $config->hostname);
         $this->assertEquals('two', $config->one->two);
         $this->assertEquals('4', $config->one->three->four);
         $this->assertEquals('5', $config->one->three->five);
     }
-    
+
     public function testZF2843NoSectionNoTree()
     {
         $filename = dirname(__FILE__) . '/_files/zf2843.ini';
         $config = new Zend_Config_Ini($filename, null, array('nestSeparator' => '.'));
-        
-        
+
         $this->assertEquals('123', $config->abc);
         $this->assertEquals('jkl', $config->ghi);
     }
@@ -259,8 +259,54 @@ class Zend_Config_IniTest extends PHPUnit_Framework_TestCase
             $config = new Zend_Config_Ini($this->_iniFileInvalid);
             $this->fail('An expected Zend_Config_Exception has not been raised');
         } catch (Zend_Config_Exception $expected) {
-            $this->assertContains('Error parsing', $expected->getMessage());
+            $this->assertRegexp('/(Error parsing|parse error|syntax error, unexpected)/', $expected->getMessage());
         }
-        
+
     }
+
+    /**
+     * @group ZF-8159
+     */
+    public function testZF8159()
+    {
+        $config = new Zend_Config_Ini(
+            dirname(__FILE__) . '/_files/zf8159.ini',
+            array('first', 'second')
+        );
+
+        $this->assertTrue(isset(
+           $config->user->login->elements->password
+        ));
+
+        $this->assertEquals(
+            'password',
+            $config->user->login->elements->password->type
+        );
+    }
+
+    /*
+     * @group ZF-5800
+     *
+     */
+    public function testArraysOfKeysCreatedUsingAttributesAndKeys()
+    {
+        $filename = dirname(__FILE__) . '/_files/zf5800.ini';
+        $config = new Zend_Config_Ini($filename, 'dev');
+        $this->assertEquals('nice.guy@company.com', $config->receiver->{0}->mail);
+        $this->assertEquals('1', $config->receiver->{0}->html);
+        $this->assertNull($config->receiver->mail);
+    }
+
+    /*
+     * @group ZF-6508
+     */
+    public function testPreservationOfIntegerKeys()
+    {
+        $filename = dirname(__FILE__) . '/_files/zf6508.ini';
+        $config = new Zend_Config_Ini($filename, 'all');
+        $this->assertEquals(true, isset($config->{1002}));
+
+    }
+
+
 }
