@@ -15,16 +15,11 @@
  * @category   Zend
  * @package    Zend_Config
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: ConfigTest.php 11502 2008-09-23 20:16:32Z rob $
+ * @version    $Id: ConfigTest.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../TestHelper.php';
-
 /**
  * Zend_Config
  */
@@ -34,8 +29,9 @@ require_once 'Zend/Config.php';
  * @category   Zend
  * @package    Zend_Config
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Config
  */
 class Zend_ConfigTest extends PHPUnit_Framework_TestCase
 {
@@ -200,8 +196,7 @@ class Zend_ConfigTest extends PHPUnit_Framework_TestCase
 
         ob_start();
         print_r($config->toArray());
-        $contents = ob_get_contents();
-        ob_end_clean();
+        $contents = ob_get_clean();
 
         $this->assertContains('Array', $contents);
         $this->assertContains('[hostname] => all', $contents);
@@ -365,7 +360,7 @@ class Zend_ConfigTest extends PHPUnit_Framework_TestCase
         $this->assertType('stdClass', $config->b->c);
         $this->assertType('stdClass', $config->b->d);
     }
-    
+
     /**
      * ensure that modification is not allowed after calling setReadOnly()
      *
@@ -377,17 +372,17 @@ class Zend_ConfigTest extends PHPUnit_Framework_TestCase
             );
         $config = new Zend_Config($configData, true);
         $config->b = 'b';
-        
+
         $config->setReadOnly();
         try {
             $config->c = 'c';
         } catch (Zend_Config_Exception $expected) {
             $this->assertContains('is read only', $expected->getMessage());
             return;
-        }        
+        }
         $this->fail('Expected read only exception has not been raised.');
     }
-    
+
     public function testZF3408_countNotDecreasingOnUnset()
     {
         $configData = array(
@@ -400,8 +395,8 @@ class Zend_ConfigTest extends PHPUnit_Framework_TestCase
         unset($config->b);
         $this->assertEquals(count($config), 2);
     }
-    
-    public function testZF4107_ensureCloneDoesNotKeepNestedReferences() 
+
+    public function testZF4107_ensureCloneDoesNotKeepNestedReferences()
     {
         $parent = new Zend_Config(array('key' => array('nested' => 'parent')), true);
         $newConfig = clone $parent;
@@ -409,9 +404,9 @@ class Zend_ConfigTest extends PHPUnit_Framework_TestCase
 
         $this->assertEquals('override', $newConfig->key->nested, '$newConfig is not overridden');
         $this->assertEquals('parent', $parent->key->nested, '$parent has been overridden');
-        
+
     }
-    
+
     /**
      * @group ZF-3575
      *
@@ -435,7 +430,109 @@ class Zend_ConfigTest extends PHPUnit_Framework_TestCase
             $this->fail('Unexpected exception on nested object has been raised: ' . $e->getMessage());
         }
         $this->assertEquals('no', $config2->key->nested);
-        
+
+    }
+
+    /**
+     * @group ZF-5771a
+     *
+     */
+    public function testUnsettingFirstElementDuringForeachDoesNotSkipAnElement()
+    {
+        $config = new Zend_Config(array(
+            'first'  => array(1),
+            'second' => array(2),
+            'third'  => array(3)
+        ), true);
+
+        $keyList = array();
+        foreach ($config as $key => $value)
+        {
+            $keyList[] = $key;
+            if ($key == 'first') {
+                unset($config->$key); // uses magic Zend_Config::__unset() method
+            }
+        }
+
+        $this->assertEquals('first', $keyList[0]);
+        $this->assertEquals('second', $keyList[1]);
+        $this->assertEquals('third', $keyList[2]);
+    }
+
+    /**
+     * @group ZF-5771
+     *
+     */
+    public function testUnsettingAMiddleElementDuringForeachDoesNotSkipAnElement()
+    {
+        $config = new Zend_Config(array(
+            'first'  => array(1),
+            'second' => array(2),
+            'third'  => array(3)
+        ), true);
+
+        $keyList = array();
+        foreach ($config as $key => $value)
+        {
+            $keyList[] = $key;
+            if ($key == 'second') {
+                unset($config->$key); // uses magic Zend_Config::__unset() method
+            }
+        }
+
+        $this->assertEquals('first', $keyList[0]);
+        $this->assertEquals('second', $keyList[1]);
+        $this->assertEquals('third', $keyList[2]);
+    }
+
+    /**
+     * @group ZF-5771
+     *
+     */
+    public function testUnsettingLastElementDuringForeachDoesNotSkipAnElement()
+    {
+        $config = new Zend_Config(array(
+            'first'  => array(1),
+            'second' => array(2),
+            'third'  => array(3)
+        ), true);
+
+        $keyList = array();
+        foreach ($config as $key => $value)
+        {
+            $keyList[] = $key;
+            if ($key == 'third') {
+                unset($config->$key); // uses magic Zend_Config::__unset() method
+            }
+        }
+
+        $this->assertEquals('first', $keyList[0]);
+        $this->assertEquals('second', $keyList[1]);
+        $this->assertEquals('third', $keyList[2]);
+    }
+
+    /**
+     * @group ZF-4728
+     *
+     */
+    public function testSetReadOnlyAppliesToChildren()
+    {
+        $config = new Zend_Config($this->_all, true);
+
+        $config->setReadOnly();
+        $this->assertTrue($config->readOnly());
+        $this->assertTrue($config->one->readOnly(), 'First level children are writable');
+        $this->assertTrue($config->one->two->readOnly(), 'Second level children are writable');
+    }
+
+    public function testZF6995_toArrayDoesNotDisturbInternalIterator()
+    {
+        $config = new Zend_Config(range(1,10));
+        $config->rewind();
+        $this->assertEquals(1, $config->current());
+
+        $config->toArray();
+        $this->assertEquals(1, $config->current());
     }
 }
 
