@@ -1,12 +1,30 @@
 <?php
+/**
+ * Zend Framework
+ *
+ * LICENSE
+ *
+ * This source file is subject to the new BSD license that is bundled
+ * with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://framework.zend.com/license/new-bsd
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@zend.com so we can send you a copy immediately.
+ *
+ * @category   Zend
+ * @package    Zend_Controller
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id: ContextSwitchTest.php 24864 2012-06-02 00:51:50Z adamlundrigan $
+ */
+
 // Call Zend_Controller_Action_Helper_ContextSwitchTest::main() if this source file is executed directly.
 if (!defined("PHPUnit_MAIN_METHOD")) {
-    require_once dirname(__FILE__) . '/../../../../TestHelper.php';
     define("PHPUnit_MAIN_METHOD", "Zend_Controller_Action_Helper_ContextSwitchTest::main");
 }
 
-require_once "PHPUnit/Framework/TestCase.php";
-require_once "PHPUnit/Framework/TestSuite.php";
 
 require_once 'Zend/Controller/Action/Helper/ContextSwitch.php';
 
@@ -19,11 +37,21 @@ require_once 'Zend/Controller/Response/Cli.php';
 require_once 'Zend/Json.php';
 require_once 'Zend/Layout.php';
 require_once 'Zend/View.php';
+require_once 'Zend/View/Interface.php';
 
 /**
  * Test class for Zend_Controller_Action_Helper_ContextSwitch.
+ *
+ * @category   Zend
+ * @package    Zend_Controller
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Controller
+ * @group      Zend_Controller_Action
+ * @group      Zend_Controller_Action_Helper
  */
-class Zend_Controller_Action_Helper_ContextSwitchTest extends PHPUnit_Framework_TestCase 
+class Zend_Controller_Action_Helper_ContextSwitchTest extends PHPUnit_Framework_TestCase
 {
     /**
      * Runs the test methods of this class.
@@ -33,7 +61,6 @@ class Zend_Controller_Action_Helper_ContextSwitchTest extends PHPUnit_Framework_
      */
     public static function main()
     {
-        require_once "PHPUnit/TextUI/TestRunner.php";
 
         $suite  = new PHPUnit_Framework_TestSuite("Zend_Controller_Action_Helper_ContextSwitchTest");
         $result = PHPUnit_TextUI_TestRunner::run($suite);
@@ -47,7 +74,7 @@ class Zend_Controller_Action_Helper_ContextSwitchTest extends PHPUnit_Framework_
      */
     public function setUp()
     {
-        Zend_Controller_Action_Helper_ContextSwitchTest_LayoutOverride::$_mvcInstance = null;
+        Zend_Controller_Action_Helper_ContextSwitchTest_LayoutOverride::resetMvcInstance();
         Zend_Controller_Action_HelperBroker::resetHelpers();
 
         $this->front = Zend_Controller_Front::getInstance();
@@ -67,7 +94,6 @@ class Zend_Controller_Action_Helper_ContextSwitchTest extends PHPUnit_Framework_
                     ->addControllerDirectory(dirname(__FILE__));
 
         $this->view = new Zend_View();
-        $this->view->addHelperPath(dirname(__FILE__) . '/../../../../../library/Zend/View/Helper/');
         $this->viewRenderer = Zend_Controller_Action_HelperBroker::getStaticHelper('viewRenderer');
         $this->viewRenderer->setView($this->view);
 
@@ -823,6 +849,90 @@ class Zend_Controller_Action_Helper_ContextSwitchTest extends PHPUnit_Framework_
         $this->helper = new Zend_Controller_Action_Helper_ContextSwitch($config);
         $this->checkOptionsAreSet();
     }
+
+    /**
+     * @group ZF-3279
+     */
+    public function testPostJsonContextDoesntThrowExceptionWhenGetVarsMethodsExists()
+    {
+        try {
+            $this->helper->setAutoJsonSerialization(true);
+            $this->helper->postJsonContext();
+        } catch(Zend_Controller_Action_Exception $zcae) {
+            $this->fail('Exception should be throw when view does not implement getVars() method');
+        }
+    }
+
+    /**
+     * @group ZF-3279
+     */
+    public function testPostJsonContextThrowsExceptionWhenGetVarsMethodsDoesntExist()
+    {
+        $view = new Zend_Controller_Action_Helper_ContextSwitchText_CustomView();
+        $this->viewRenderer->setView($view);
+
+        try {
+            $this->helper->setAutoJsonSerialization(true);
+            $this->helper->postJsonContext();
+            $this->fail('Exception should be throw when view does not implement getVars() method');
+        } catch(Zend_Controller_Action_Exception $zcae) {
+        }
+    }
+
+    /**
+     * @group ZF-4866
+     */
+    public function testForwardingShouldNotUseContextSuffixIfNewActionDoesNotDetectValidContext()
+    {
+        $this->request->setParam('format', 'xml')
+                      ->setActionName('foo');
+        $this->helper->setActionContext('bar', 'json');
+        $this->helper->initContext();
+        $this->assertEquals('xml', $this->helper->getCurrentContext());
+        $this->request->setActionName('bar');
+        $this->helper->init();
+        $this->helper->initContext();
+        $suffix = $this->viewRenderer->getViewSuffix();
+        $this->assertNotContains('xml', $suffix, $suffix);
+    }
+
+    /**
+     * @group ZF-4866
+     */
+    public function testForwardingShouldNotPrependMultipleViewSuffixesForCustomContexts()
+    {
+        $this->helper->addContext('foo', array('suffix' => 'foo'));
+        $this->helper->setActionContext('foo', 'foo');
+        $this->helper->setActionContext('bar', 'foo');
+        $this->request->setParam('format', 'foo')
+                      ->setActionName('foo');
+        $this->helper->initContext();
+        $this->assertEquals('foo', $this->helper->getCurrentContext());
+        $suffix = $this->viewRenderer->getViewSuffix();
+        $this->assertContains('foo', $suffix, $suffix);
+
+        $this->request->setActionName('bar');
+        $this->helper->init();
+        $this->helper->initContext();
+        $this->assertEquals('foo', $this->helper->getCurrentContext());
+        $suffix = $this->viewRenderer->getViewSuffix();
+        $this->assertContains('foo', $suffix, $suffix);
+        $this->assertNotContains('foo.foo', $suffix, $suffix);
+    }
+
+    /**
+     * @group ZF-11793
+     */
+    public function testGetActionContextsReturnsFullListWhenArgumentIsNull()
+    {
+        $expected = array(
+            'foo' => array('xml'),
+            'bar' => array('xml', 'json'),
+            'all' => array('json','xml')
+        );
+        $actual = $this->helper->getActionContexts(null);
+        $this->assertEquals($expected, $actual);
+    }
 }
 
 class Zend_Controller_Action_Helper_ContextSwitchTestController extends Zend_Controller_Action
@@ -862,7 +972,46 @@ class Zend_Controller_Action_Helper_ContextSwitchTestController extends Zend_Con
 
 class Zend_Controller_Action_Helper_ContextSwitchTest_LayoutOverride extends Zend_Layout
 {
-    public static $_mvcInstance;
+    public static function resetMvcInstance()
+    {
+        self::$_mvcInstance = null;
+    }
+}
+
+class Zend_Controller_Action_Helper_ContextSwitchText_CustomView implements Zend_View_Interface
+{
+    public function getEngine()
+    {}
+
+    public function setScriptPath($path)
+    {}
+
+    public function getScriptPaths()
+    {}
+
+    public function setBasePath($path, $classPrefix = 'Zend_View')
+    {}
+
+    public function addBasePath($path, $classPrefix = 'Zend_View')
+    {}
+
+    public function __set($key, $val)
+    {}
+
+    public function __isset($key)
+    {}
+
+    public function __unset($key)
+    {}
+
+    public function assign($spec, $value = null)
+    {}
+
+    public function clearVars()
+    {}
+
+    public function render($name)
+    {}
 }
 
 // Call Zend_Controller_Action_Helper_ContextSwitchTest::main() if this source file is executed directly.
