@@ -1,11 +1,30 @@
 <?php
+/**
+ * Zend Framework
+ *
+ * LICENSE
+ *
+ * This source file is subject to the new BSD license that is bundled
+ * with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://framework.zend.com/license/new-bsd
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@zend.com so we can send you a copy immediately.
+ *
+ * @category   Zend
+ * @package    Zend_Controller
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id: RedirectorTest.php 24593 2012-01-05 20:35:02Z matthew $
+ */
+
 // Call Zend_Controller_Action_Helper_RedirectorTest::main() if this source file is executed directly.
 if (!defined("PHPUnit_MAIN_METHOD")) {
     define("PHPUnit_MAIN_METHOD", "Zend_Controller_Action_Helper_RedirectorTest::main");
 }
 
-require_once dirname(__FILE__) . '/../../../../TestHelper.php';
-
 require_once 'Zend/Controller/Front.php';
 require_once 'Zend/Controller/Action.php';
 require_once 'Zend/Controller/Action/HelperBroker.php';
@@ -15,8 +34,17 @@ require_once 'Zend/Controller/Response/Http.php';
 
 /**
  * Test class for Zend_Controller_Action_Helper_Redirector.
+ *
+ * @category   Zend
+ * @package    Zend_Controller
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Controller
+ * @group      Zend_Controller_Action
+ * @group      Zend_Controller_Action_Helper
  */
-class Zend_Controller_Action_Helper_RedirectorTest extends PHPUnit_Framework_TestCase 
+class Zend_Controller_Action_Helper_RedirectorTest extends PHPUnit_Framework_TestCase
 {
     /**
      * @var Zend_Controller_Action_Helper_Redirector
@@ -43,7 +71,6 @@ class Zend_Controller_Action_Helper_RedirectorTest extends PHPUnit_Framework_Tes
      */
     public static function main()
     {
-        require_once "PHPUnit/TextUI/TestRunner.php";
 
         $suite  = new PHPUnit_Framework_TestSuite("Zend_Controller_Action_Helper_RedirectorTest");
         $result = PHPUnit_TextUI_TestRunner::run($suite);
@@ -52,7 +79,7 @@ class Zend_Controller_Action_Helper_RedirectorTest extends PHPUnit_Framework_Tes
     /**
      * Set up redirector
      *
-     * Creates request, response, and action controller objects; sets action 
+     * Creates request, response, and action controller objects; sets action
      * controller in redirector, and sets exit to false.
      *
      * Also resets the front controller instance.
@@ -119,7 +146,7 @@ class Zend_Controller_Action_Helper_RedirectorTest extends PHPUnit_Framework_Tes
     {
         $this->redirector->setCode('303');
         $this->assertEquals(303, $this->redirector->getCode());
-        
+
         try {
             $this->redirector->setCode('251');
             $this->fail('Invalid redirect code should throw exception');
@@ -130,7 +157,7 @@ class Zend_Controller_Action_Helper_RedirectorTest extends PHPUnit_Framework_Tes
             $this->redirector->setCode('351');
             $this->fail('Invalid redirect code should throw exception');
         } catch (Exception $e) {
-        }        
+        }
     }
 
     public function testRedirectorShouldOnlyAllowValidHttpRedirectCodes()
@@ -139,12 +166,12 @@ class Zend_Controller_Action_Helper_RedirectorTest extends PHPUnit_Framework_Tes
             $this->redirector->setCode('306');
             $this->fail('Invalid redirect code should throw exception');
         } catch (Zend_Controller_Action_Exception $e) {
-        }        
+        }
         try {
             $this->redirector->setCode('304');
             $this->fail('Invalid redirect code should throw exception');
         } catch (Zend_Controller_Action_Exception $e) {
-        }        
+        }
     }
 
     public function testExit()
@@ -161,6 +188,13 @@ class Zend_Controller_Action_Helper_RedirectorTest extends PHPUnit_Framework_Tes
         $this->assertFalse($this->redirector->getPrependBase());
     }
 
+    public function testCloseSessionOnExit()
+    {
+        $this->assertTrue($this->redirector->getCloseSessionOnExit());
+        $this->redirector->setCloseSessionOnExit(false);
+        $this->assertFalse($this->redirector->getCloseSessionOnExit());
+    }
+
     public function testGetRedirectUrlNullByDefault()
     {
         $this->assertNull($this->redirector->getRedirectUrl());
@@ -380,19 +414,31 @@ class Zend_Controller_Action_Helper_RedirectorTest extends PHPUnit_Framework_Tes
         $this->redirector->setUseAbsoluteUri(true);
         $this->redirector->gotoUrl('/bar/baz');
         $headers = $this->response->getHeaders();
-        $uri = false;
-        foreach ($headers as $header) {
-            if ('Location' == $header['name']) {
-                $uri = $header['value'];
-            }
-        }
-        if (!$uri) {
+
+        if (!($uri = $this->_parseLocationHeaderValue())) {
             $this->fail('No redirect header set in response');
         }
 
         $this->assertEquals('https://foobar.example.com:4443/bar/baz', $uri);
     }
 
+    /**
+     * ZF-10163
+     */
+    public function testUseAbsoluteUriStripsPortFromServerHttpHost()
+    {
+        $_SERVER['HTTP_HOST']   = 'foobar.example.com:8080';
+        $_SERVER['SERVER_PORT'] = '8080';
+        $this->redirector->setUseAbsoluteUri(true);
+        $this->redirector->gotoUrl('/bar/baz');
+
+        if (!($uri = $this->_parseLocationHeaderValue())) {
+            $this->fail('No redirect header set in response');
+        }
+
+        $this->assertEquals('http://foobar.example.com:8080/bar/baz', $uri);
+    }
+
     /**
      * ZF-2602
      */
@@ -434,7 +480,93 @@ class Zend_Controller_Action_Helper_RedirectorTest extends PHPUnit_Framework_Tes
         $test = $this->redirector->getRedirectUrl();
         $this->assertEquals('/account/login', $test, $test);
     }
+
+    /**
+     * @group ZF-4318
+     */
+    public function testServerVariableHttpsToOffDoesNotBuildHttpsUrl()
+    {
+        // Set Preconditions from Issue:
+        $_SERVER['HTTPS'] = "off";
+        $_SERVER['HTTP_HOST'] = 'localhost';
+        $_SERVER['SERVER_PORT'] = 80;
+        $this->redirector->setUseAbsoluteUri(true);
+
+        $this->request->setModuleName('admin')
+                      ->setControllerName('class')
+                      ->setActionName('view');
+        $this->redirector->gotoUrl('/bar/baz');
+        $test = $this->redirector->getRedirectUrl();
+
+        $this->assertNotContains('https://', $test);
+        $this->assertEquals('http://localhost/bar/baz', $test);
+    }
+
+    /**
+     * @group ZF-9859
+     */
+    public function testGotoUrlAndSetGotoUrlBehaveTheSame()
+    {
+        $url = 'http://www.example.com';
+        $gotoUrl = $this->redirector->gotoUrl($url);
+        $setGotoUrl = $this->redirector->setGotoUrl($url);
+        $this->assertSame($gotoUrl, $setGotoUrl);
+    }
+
+    /**
+     * @group ZF-10364
+     */
+    public function testGotoSimpleDefaultModuleRedirectsToDefaultModule()
+    {
+        $this->controller->getFrontController()->setDefaultModule('test')
+                                               ->setDefaultControllerName('test')
+                                               ->setDefaultAction('test');
+
+        $this->redirector->gotoSimple('test', 'test', 'test');
+        $result = $this->redirector->getRedirectUrl();
+        $expected = '/';
+        $this->assertEquals($expected, $result);
+
+        $this->redirector->gotoSimple('index', 'index', 'default');
+        $result = $this->redirector->getRedirectUrl();
+        $expected = '/default/index/index';
+        $this->assertEquals($expected, $result);
+    }
+
+    /** @group ZF-6025 */
+    public function testGotoSimpleShouldNotHardcodeControllerActionModuleKeys()
+    {
+        $this->request->setControllerKey('foo')
+                      ->setActionKey('bar')
+                      ->setModuleKey('baz');
+
+        $this->router->removeRoute('default');
+        $this->router->addRoute('default', new Zend_Controller_Router_Route(
+            ':baz/:foo/:bar/*', array(
+                'baz' => 'default',
+                'foo' => 'index',
+                'bar' => 'index'
+            )
+        ));
+
+        $this->redirector->gotoSimple('babar', 'barbapapa', 'barbazoo', array('asd' => 1));
+        $result = $this->redirector->getRedirectUrl();
+        $expected = '/barbazoo/barbapapa/babar/asd/1';
+        $this->assertEquals($expected, $result);
+    }
+
     /**#@-*/
+
+    protected function _parseLocationHeaderValue()
+    {
+        $headers = $this->response->getHeaders();
+
+        foreach ($headers as $header) {
+            if ('Location' == $header['name']) {
+                return $header['value'];
+            }
+        }
+    }
 }
 
 /**
@@ -450,3 +582,4 @@ if (PHPUnit_MAIN_METHOD == "Zend_Controller_Action_Helper_RedirectorTest::main")
 }
 
 
+
