@@ -1,11 +1,30 @@
 <?php
+/**
+ * Zend Framework
+ *
+ * LICENSE
+ *
+ * This source file is subject to the new BSD license that is bundled
+ * with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://framework.zend.com/license/new-bsd
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@zend.com so we can send you a copy immediately.
+ *
+ * @category   Zend
+ * @package    Zend_Controller
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id: ViewRendererTest.php 24593 2012-01-05 20:35:02Z matthew $
+ */
+
 // Call Zend_Controller_Action_Helper_ViewRendererTest::main() if this source file is executed directly.
 if (!defined("PHPUnit_MAIN_METHOD")) {
     define("PHPUnit_MAIN_METHOD", "Zend_Controller_Action_Helper_ViewRendererTest::main");
 }
 
-require_once dirname(__FILE__) . '/../../../../TestHelper.php';
-
 require_once 'Zend/Controller/Action/Helper/ViewRenderer.php';
 require_once 'Zend/Controller/Front.php';
 require_once 'Zend/Controller/Request/Http.php';
@@ -18,8 +37,17 @@ require_once dirname(__FILE__) . '/../../_files/modules/bar/controllers/IndexCon
 
 /**
  * Test class for Zend_Controller_Action_Helper_ViewRenderer.
+ *
+ * @category   Zend
+ * @package    Zend_Controller
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Controller
+ * @group      Zend_Controller_Action
+ * @group      Zend_Controller_Action_Helper
  */
-class Zend_Controller_Action_Helper_ViewRendererTest extends PHPUnit_Framework_TestCase 
+class Zend_Controller_Action_Helper_ViewRendererTest extends PHPUnit_Framework_TestCase
 {
     /**
      * Base path to controllers, views
@@ -248,7 +276,10 @@ class Zend_Controller_Action_Helper_ViewRendererTest extends PHPUnit_Framework_T
 
         $scriptPaths = $this->helper->view->getScriptPaths();
         $scriptPath  = $scriptPaths[0];
-        $this->assertContains($viewDir, $scriptPath);
+        $this->assertContains(
+            $this->_normalizePath($viewDir),
+            $this->_normalizePath($scriptPath)
+            );
 
         $helperPaths = $this->helper->view->getHelperPaths();
         $found       = false;
@@ -498,9 +529,9 @@ class Zend_Controller_Action_Helper_ViewRendererTest extends PHPUnit_Framework_T
         $controller = new Bar_IndexController($this->request, $this->response, array());
         $expected   = 'baz/bat.php';
         $this->assertEquals(
-            $expected, 
+            $expected,
             $this->helper->getViewScript(
-                null, 
+                null,
                 array('controller' => 'baz', 'action' => 'bat', 'suffix' => 'php')
             )
         );
@@ -714,13 +745,13 @@ class Zend_Controller_Action_Helper_ViewRendererTest extends PHPUnit_Framework_T
 
         require_once 'Zend/Filter/PregReplace.php';
         require_once 'Zend/Filter/Word/UnderscoreToSeparator.php';
-        
+
         $inflector = new Zend_Filter_Inflector('test.phtml');
         $inflector->addRules(array(
             ':module'     => array('Word_CamelCaseToDash', 'stringToLower'),
             ':controller' => array('Word_CamelCaseToDash', new Zend_Filter_Word_UnderscoreToSeparator(DIRECTORY_SEPARATOR), 'StringToLower'),
             ':action'     => array(
-                'Word_CamelCaseToDash', 
+                'Word_CamelCaseToDash',
                 new Zend_Filter_PregReplace('/[^a-z0-9]+/i', '-'),
                 'StringToLower'
             ),
@@ -731,7 +762,7 @@ class Zend_Controller_Action_Helper_ViewRendererTest extends PHPUnit_Framework_T
         $body = $this->response->getBody();
         $this->assertContains('Rendered index/test.phtml in bar module', $body);
     }
-    
+
     public function testStockInflectorAllowsSubDirectoryViewScripts()
     {
         $this->request->setModuleName('bar')
@@ -750,18 +781,20 @@ class Zend_Controller_Action_Helper_ViewRendererTest extends PHPUnit_Framework_T
                       ->setActionName('admin');
         $controller = new Bar_IndexController($this->request, $this->response, array());
         $this->helper->setActionController($controller);
-                      
+
         $this->helper->setViewBasePathSpec(':moduleDir/:module');
         $this->helper->initView();
-        
-        $viewScriptPaths = $this->helper->view->getAllPaths(); 
 
-        // we need this until View decides to not use DIRECTORY_SEPARATOR
-        $expectedPathRegex = (DIRECTORY_SEPARATOR == '\\') ? '#modules\\\\bar\\\\bar\\\\scripts\\\\$#' : '#modules/bar/bar/scripts/$#';
-        $this->assertRegExp($expectedPathRegex, $viewScriptPaths['script'][0]);
+        $viewScriptPaths = $this->helper->view->getAllPaths();
+
+        $expectedPathRegex = '#modules/bar/bar/scripts/$#';
+        $this->assertRegExp(
+            $expectedPathRegex,
+            $this->_normalizePath($viewScriptPaths['script'][0])
+            );
         $this->assertEquals($this->helper->getViewScript(), 'index/admin.phtml');
     }
-    
+
     /**
      * @see ZF-2738
      */
@@ -774,11 +807,14 @@ class Zend_Controller_Action_Helper_ViewRendererTest extends PHPUnit_Framework_T
         $this->helper->setActionController($controller);
         $viewScriptPaths = $this->helper->view->getAllPaths();
 
-        $expectedPathRegex = (DIRECTORY_SEPARATOR == '\\') ? '#modules\\\\foo\\\\views\\\\scripts\\\\$#' : '#modules/foo/views/scripts/$#';
-        $this->assertRegExp($expectedPathRegex, $viewScriptPaths['script'][0]);
-        $this->assertEquals($this->helper->getViewScript(), 'car-bar/baz.phtml');
+        $expectedPathRegex = '#modules/foo/views/scripts/$#';
+        $this->assertRegExp(
+            $expectedPathRegex,
+            $this->_normalizePath($viewScriptPaths['script'][0])
+            );
+        $this->assertEquals('car-bar/baz.phtml', $this->helper->getViewScript());
     }
-    
+
     public function testCorrectViewHelperPathShouldBePropagatedWhenSubControllerInvoked()
     {
         require_once $this->basePath . '/_files/modules/foo/controllers/Admin/IndexController.php';
@@ -791,7 +827,20 @@ class Zend_Controller_Action_Helper_ViewRendererTest extends PHPUnit_Framework_T
         $body = $this->response->getBody();
         $this->assertContains('fooUseHelper invoked', $body, 'Received ' . $body);
     }
-    
+    /**
+     * @group ZF-10725
+     */
+    public function testThatCharactersStrippedFromActionNameByDispatcherAreAlsoStrippedFromViewScriptName()
+    {
+        $this->request->setModuleName('default')
+                      ->setControllerName('foo')
+                      ->setActionName('-myBar-');
+        $controller = new Bar_IndexController($this->request, $this->response, array());
+        $this->helper->setActionController($controller);
+        $scriptName = $this->helper->getViewScript();
+        $this->assertEquals('foo/my-bar.phtml', $scriptName);
+    }
+
     public function testCorrectViewHelperPathShouldBePropagatedWhenSubControllerInvokedInDefaultModule()
     {
         require_once $this->basePath . '/_files/modules/default/controllers/Admin/HelperController.php';
@@ -803,6 +852,76 @@ class Zend_Controller_Action_Helper_ViewRendererTest extends PHPUnit_Framework_T
         $body = $this->response->getBody();
         $this->assertContains('SampleZfHelper invoked', $body, 'Received ' . $body);
     }
+    
+    /**
+     * @group ZF-11127
+     */
+    public function testViewSuffixInstanceNotSharedWhenViewHelperIsCloned()
+    {
+        $a = new Zend_Controller_Action_Helper_ViewRenderer();
+        $a->init();
+        $a->setViewSuffix('A');
+        
+        $this->assertEquals('A', $a->getViewSuffix());
+        
+        $b = clone $a;        
+        $this->assertEquals('A', $b->getViewSuffix());
+        $b->setViewSuffix('B');
+        
+        $this->assertEquals('B', $b->getViewSuffix());
+        $this->assertNotEquals('B', $a->getViewSuffix());
+    }
+    
+    /**
+     * @group ZF-10725
+     * @dataProvider providerViewScriptNameDoesNotIncludeDisallowedCharacters
+     */
+    public function testViewScriptNameDoesNotIncludeDisallowedCharacters($actionName)
+    {
+        $this->request->setModuleName('default')
+                      ->setControllerName('foo')
+                      ->setActionName($actionName);
+        $controller = new Bar_IndexController($this->request, $this->response, array());
+        $this->helper->setActionController($controller);
+        $scriptName = $this->helper->getViewScript();
+        $this->assertEquals('foo/my-bar.phtml', $scriptName);
+    }
+    
+    /**
+     * Data provider for testViewScriptNameDoesNotIncludeDisallowedCharacters
+     * @group ZF-10725
+     * @return array
+     */
+    public function providerViewScriptNameDoesNotIncludeDisallowedCharacters()
+    {
+        return array(
+            array('myBar-'),
+            array('-myBar'),
+            array('-myBar-'),
+            array('-MyBar-'),
+            array('MyBar-'),
+            array('-MyBar')
+        );
+    }
+
+    protected function _normalizePath($path)
+    {
+        return str_replace(array('/', '\\'), '/', $path);
+    }
+
+    /**
+     * @group ZF-10725
+     */
+    public function testActionsWithLeadingCapitalLettersShouldNotInvokeTruncatedViewScripts()
+    {
+        $this->request->setModuleName('default')
+                      ->setControllerName('Controller')
+                      ->setActionName('Action');
+        $controller = new Bar_IndexController($this->request, $this->response, array());
+        $this->helper->setActionController($controller);
+        $scriptName = $this->helper->getViewScript();
+        $this->assertEquals('controller/action.phtml', $scriptName);
+    }
 }
 
 // Call Zend_Controller_Action_Helper_ViewRendererTest::main() if this source file is executed directly.
