@@ -1,12 +1,30 @@
 <?php
+/**
+ * Zend Framework
+ *
+ * LICENSE
+ *
+ * This source file is subject to the new BSD license that is bundled
+ * with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://framework.zend.com/license/new-bsd
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@zend.com so we can send you a copy immediately.
+ *
+ * @category   Zend
+ * @package    Zend_Controller
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id: ActionTest.php 24593 2012-01-05 20:35:02Z matthew $
+ */
+
 // Call Zend_Controller_ActionTest::main() if this source file is executed directly.
 if (!defined("PHPUnit_MAIN_METHOD")) {
-    require_once dirname(__FILE__) . '/../../TestHelper.php';
     define("PHPUnit_MAIN_METHOD", "Zend_Controller_ActionTest::main");
 }
 
-require_once "PHPUnit/Framework/TestCase.php";
-require_once "PHPUnit/Framework/TestSuite.php";
 
 require_once 'Zend/Controller/Action.php';
 require_once 'Zend/Controller/Action/Helper/Redirector.php';
@@ -14,7 +32,16 @@ require_once 'Zend/Controller/Action/Helper/ViewRenderer.php';
 require_once 'Zend/Controller/Request/Http.php';
 require_once 'Zend/Controller/Response/Cli.php';
 
-class Zend_Controller_ActionTest extends PHPUnit_Framework_TestCase 
+/**
+ * @category   Zend
+ * @package    Zend_Controller
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Controller
+ * @group      Zend_Controller_Action
+ */
+class Zend_Controller_ActionTest extends PHPUnit_Framework_TestCase
 {
     /**
      * Runs the test methods of this class.
@@ -24,7 +51,6 @@ class Zend_Controller_ActionTest extends PHPUnit_Framework_TestCase
      */
     public static function main()
     {
-        require_once "PHPUnit/TextUI/TestRunner.php";
 
         $suite  = new PHPUnit_Framework_TestSuite("Zend_Controller_ActionTest");
         $result = PHPUnit_TextUI_TestRunner::run($suite);
@@ -32,6 +58,11 @@ class Zend_Controller_ActionTest extends PHPUnit_Framework_TestCase
 
     public function setUp()
     {
+        Zend_Controller_Action_HelperBroker::resetHelpers();
+        $front = Zend_Controller_Front::getInstance();
+        $front->resetInstance();
+        $front->setControllerDirectory('.', 'default');
+
         $this->_controller = new Zend_Controller_ActionTest_TestController(
             new Zend_Controller_Request_Http(),
             new Zend_Controller_Response_Cli(),
@@ -40,8 +71,7 @@ class Zend_Controller_ActionTest extends PHPUnit_Framework_TestCase
                 'bar' => 'baz'
             )
         );
-        Zend_Controller_Front::getInstance()->resetInstance();
-        Zend_Controller_Action_HelperBroker::resetHelpers();
+
         $redirector = $this->_controller->getHelper('redirector');
         $redirector->setExit(false);
     }
@@ -169,7 +199,7 @@ class Zend_Controller_ActionTest extends PHPUnit_Framework_TestCase
             $this->fail('Should not be able to call bar as action');
         } catch (Exception $e) {
             //success!
-        } 
+        }
     }
 
     public function testRun3()
@@ -193,18 +223,41 @@ class Zend_Controller_ActionTest extends PHPUnit_Framework_TestCase
     public function testSetParam()
     {
         $this->_controller->setParam('foo', 'bar');
-        $params = $this->_controller->getParams();
+        $params = $this->_controller->getAllParams();
         $this->assertTrue(isset($params['foo']));
         $this->assertEquals('bar', $params['foo']);
     }
 
+    /**
+     * @group ZF-5163
+     */
+    public function testGetParamForZeroValues()
+    {
+        $this->_controller->setParam('foo', 'bar');
+        $this->_controller->setParam('bar', 0);
+        $this->_controller->setParam('baz', null);
+
+        $this->assertEquals('bar', $this->_controller->getParam('foo', -1));
+        $this->assertEquals(0, $this->_controller->getParam('bar', -1));
+        $this->assertEquals(-1, $this->_controller->getParam('baz', -1));
+    }
+
+	/**
+     * @group ZF-9179
+     */
+	public function testGetParamForEmptyString()
+	{
+		$this->_controller->setParam('lang', '');
+		$this->assertEquals('en', $this->_controller->getParam('lang', 'en'));
+	}
+
     public function testGetParams()
     {
         $this->_controller->setParam('foo', 'bar');
         $this->_controller->setParam('bar', 'baz');
         $this->_controller->setParam('boo', 'bah');
 
-        $params = $this->_controller->getParams();
+        $params = $this->_controller->getAllParams();
         $this->assertEquals('bar', $params['foo']);
         $this->assertEquals('baz', $params['bar']);
         $this->assertEquals('bah', $params['boo']);
@@ -242,7 +295,7 @@ class Zend_Controller_ActionTest extends PHPUnit_Framework_TestCase
         $this->assertTrue($view instanceof Zend_View);
         $scriptPath = $view->getScriptPaths();
         $this->assertTrue(is_array($scriptPath));
-        $this->assertEquals(dirname(__FILE__) . DIRECTORY_SEPARATOR . 'views' . DIRECTORY_SEPARATOR . 'scripts' . DIRECTORY_SEPARATOR, $scriptPath[0]);
+        $this->assertEquals(dirname(__FILE__) . DIRECTORY_SEPARATOR . 'views' . DIRECTORY_SEPARATOR . 'scripts/', $scriptPath[0]);
     }
 
     public function testRender()
@@ -492,32 +545,6 @@ class Zend_Controller_ActionTest_TestController extends Zend_Controller_Action
     {
         $this->getResponse()->setBody("Should never see this\n");
     }
-
-    public function forward($action, $controller = null, $module = null, array $params = null)
-    {
-        $this->_forward($action, $controller, $module, $params);
-    }
-
-    public function hasParam($param)
-    {
-        return $this->_hasParam($param);
-    }
-
-    public function getParams()
-    {
-        return $this->_getAllParams();
-    }
-
-    public function setParam($key, $value)
-    {
-        $this->_setParam($key, $value);
-        return $this;
-    }
-
-    public function redirect($url, $code = 302, $prependBase = true)
-    {
-        $this->_redirect($url, array('code' => $code, 'prependBase' => $prependBase));
-    }
 }
 
 // Call Zend_Controller_ActionTest::main() if this source file is executed directly.
