@@ -1,23 +1,23 @@
 <?php
-// Call Zend_Controller_Router_Route_ModuleTest::main() if this source file is executed directly.
-if (!defined("PHPUnit_MAIN_METHOD")) {
-    define("PHPUnit_MAIN_METHOD", "Zend_Controller_Router_Route_ModuleTest::main");
-
-    $basePath = realpath(dirname(__FILE__) . str_repeat(DIRECTORY_SEPARATOR . '..', 4));
-
-    set_include_path(
-        $basePath . DIRECTORY_SEPARATOR . 'tests'
-        . PATH_SEPARATOR . $basePath . DIRECTORY_SEPARATOR . 'library'
-        . PATH_SEPARATOR . get_include_path()
-    );
-}
-
-require_once "PHPUnit/Framework/TestCase.php";
-require_once "PHPUnit/Framework/TestSuite.php";
 /**
+ * Zend Framework
+ *
+ * LICENSE
+ *
+ * This source file is subject to the new BSD license that is bundled
+ * with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://framework.zend.com/license/new-bsd
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@zend.com so we can send you a copy immediately.
+ *
  * @category   Zend
  * @package    Zend_Controller
  * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id: ModuleTest.php 25217 2013-01-11 11:14:17Z frosch $
  */
 
 /** Zend_Controller_Router_Route_Module */
@@ -26,18 +26,27 @@ require_once 'Zend/Controller/Router/Route/Module.php';
 /** Zend_Controller_Front */
 require_once 'Zend/Controller/Front.php';
 
+// Call Zend_Controller_Router_Route_ModuleTest::main() if this source file is executed directly.
+if (!defined("PHPUnit_MAIN_METHOD")) {
+    define("PHPUnit_MAIN_METHOD", "Zend_Controller_Router_Route_ModuleTest::main");
+}
+
 /**
  * @category   Zend
  * @package    Zend_Controller
  * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Controller
+ * @group      Zend_Controller_Router
  */
 class Zend_Controller_Router_Route_ModuleTest extends PHPUnit_Framework_TestCase
 {
-    
-    protected $_request; 
-    protected $_dispatcher; 
-    protected $route; 
-    
+
+    protected $_request;
+    protected $_dispatcher;
+    protected $route;
+
     /**
      * Runs the test methods of this class.
      *
@@ -46,7 +55,6 @@ class Zend_Controller_Router_Route_ModuleTest extends PHPUnit_Framework_TestCase
      */
     public static function main()
     {
-        require_once "PHPUnit/TextUI/TestRunner.php";
 
         $suite  = new PHPUnit_Framework_TestSuite("Zend_Controller_Router_Route_ModuleTest");
         $result = PHPUnit_TextUI_TestRunner::run($suite);
@@ -60,30 +68,30 @@ class Zend_Controller_Router_Route_ModuleTest extends PHPUnit_Framework_TestCase
               ->setParam('noViewRenderer', true);
 
         $this->_dispatcher = $front->getDispatcher();
-        
+
         $this->_dispatcher->setControllerDirectory(array(
             'default' => dirname(__FILE__) . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . '_files',
             'mod'     => dirname(__FILE__) . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . '_files' . DIRECTORY_SEPARATOR . 'Admin',
         ));
-        
+
         $defaults = array(
-            'controller' => 'defctrl', 
+            'controller' => 'defctrl',
             'action'     => 'defact',
             'module'     => 'default'
         );
-        
+
         require_once 'Zend/Controller/Request/Http.php';
         $this->_request = new Zend_Controller_Request_Http();
         $front->setRequest($this->_request);
-        
+
         $this->route = new Zend_Controller_Router_Route_Module($defaults, $this->_dispatcher, $this->_request);
     }
 
     public function testModuleMatch()
     {
         $values = $this->route->match('mod');
-        
-        $this->assertType('array', $values);
+
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
     }
@@ -91,7 +99,7 @@ class Zend_Controller_Router_Route_ModuleTest extends PHPUnit_Framework_TestCase
     public function testModuleAndControllerMatch()
     {
         $values = $this->route->match('mod/con');
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertTrue(isset($values['controller']));
@@ -101,7 +109,7 @@ class Zend_Controller_Router_Route_ModuleTest extends PHPUnit_Framework_TestCase
     public function testModuleControllerAndActionMatch()
     {
         $values = $this->route->match('mod/con/act');
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertTrue(isset($values['controller']));
@@ -113,7 +121,7 @@ class Zend_Controller_Router_Route_ModuleTest extends PHPUnit_Framework_TestCase
     public function testModuleControllerActionAndParamsMatch()
     {
         $values = $this->route->match('mod/con/act/var/val/foo');
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertTrue(isset($values['controller']));
@@ -129,7 +137,7 @@ class Zend_Controller_Router_Route_ModuleTest extends PHPUnit_Framework_TestCase
     public function testControllerOnlyMatch()
     {
         $values = $this->route->match('con');
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['controller']));
         $this->assertEquals('con', $values['controller']);
     }
@@ -137,7 +145,7 @@ class Zend_Controller_Router_Route_ModuleTest extends PHPUnit_Framework_TestCase
     public function testControllerOnlyAndActionMatch()
     {
         $values = $this->route->match('con/act');
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['controller']));
         $this->assertEquals('con', $values['controller']);
         $this->assertTrue(isset($values['action']));
@@ -147,7 +155,7 @@ class Zend_Controller_Router_Route_ModuleTest extends PHPUnit_Framework_TestCase
     public function testControllerOnlyActionAndParamsMatch()
     {
         $values = $this->route->match('con/act/var/val/foo');
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['controller']));
         $this->assertEquals('con', $values['controller']);
         $this->assertTrue(isset($values['action']));
@@ -163,31 +171,31 @@ class Zend_Controller_Router_Route_ModuleTest extends PHPUnit_Framework_TestCase
         $this->_request->setModuleKey('m');
         $this->_request->setControllerKey('c');
         $this->_request->setActionKey('a');
-        
+
         $this->route = new Zend_Controller_Router_Route_Module(array(), $this->_dispatcher, $this->_request);
-        
+
         $values = $this->route->match('mod/ctrl');
-        
-        $this->assertType('array', $values);
+
+        $this->assertTrue(is_array($values));
         $this->assertSame('mod', $values['m']);
         $this->assertSame('ctrl', $values['c']);
         $this->assertSame('index', $values['a']);
     }
-    
+
     public function testModuleMatchWithLateControlKeysChange()
     {
         $this->_request->setModuleKey('m');
         $this->_request->setControllerKey('c');
         $this->_request->setActionKey('a');
-        
+
         $values = $this->route->match('mod/ctrl');
-        
-        $this->assertType('array', $values);
+
+        $this->assertTrue(is_array($values));
         $this->assertSame('mod', $values['m'], var_export(array_keys($values), 1));
         $this->assertSame('ctrl', $values['c'], var_export(array_keys($values), 1));
         $this->assertSame('index', $values['a'], var_export(array_keys($values), 1));
     }
-    
+
     public function testAssembleNoModuleOrController()
     {
         $params = array(
@@ -206,7 +214,7 @@ class Zend_Controller_Router_Route_ModuleTest extends PHPUnit_Framework_TestCase
             'controller' => 'con'
         );
         $url = $this->route->assemble($params);
-        
+
         $this->assertEquals('con/act/foo/bar', $url);
     }
 
@@ -246,7 +254,7 @@ class Zend_Controller_Router_Route_ModuleTest extends PHPUnit_Framework_TestCase
     public function testAssembleNoActionWithParams()
     {
         $params = array(
-            'foo'		 => 'bar',
+            'foo'         => 'bar',
             'module'     => 'mod',
             'controller' => 'ctrl'
         );
@@ -257,7 +265,7 @@ class Zend_Controller_Router_Route_ModuleTest extends PHPUnit_Framework_TestCase
     public function testAssembleNoModuleOrControllerMatched()
     {
         $this->route->match('');
-        
+
         $params = array(
             'action' => 'act',
             'foo'    => 'bar'
@@ -265,25 +273,25 @@ class Zend_Controller_Router_Route_ModuleTest extends PHPUnit_Framework_TestCase
         $url = $this->route->assemble($params);
         $this->assertEquals('defctrl/act/foo/bar', $url);
     }
-    
+
     public function testAssembleControllerOnlyMatched()
     {
         $this->route->match('ctrl');
-        
+
         $params = array(
             'foo'        => 'bar',
             'action'     => 'act',
             'controller' => 'con'
         );
         $url = $this->route->assemble($params);
-        
+
         $this->assertEquals('con/act/foo/bar', $url);
     }
 
     public function testAssembleModuleAndControllerMatched()
     {
         $this->route->match('mod/ctrl');
-        
+
         $params = array(
             'foo'        => 'bar',
             'action'     => 'act',
@@ -296,7 +304,7 @@ class Zend_Controller_Router_Route_ModuleTest extends PHPUnit_Framework_TestCase
     public function testAssembleNoControllerMatched()
     {
         $this->route->match('mod');
-        
+
         $params = array(
             'foo'        => 'bar',
             'action'     => 'act',
@@ -309,7 +317,7 @@ class Zend_Controller_Router_Route_ModuleTest extends PHPUnit_Framework_TestCase
     public function testAssembleNoActionMatched()
     {
         $this->route->match('mod/ctrl');
-        
+
         $params = array(
             'module'     => 'def',
             'controller' => 'con'
@@ -317,7 +325,7 @@ class Zend_Controller_Router_Route_ModuleTest extends PHPUnit_Framework_TestCase
         $url = $this->route->assemble($params);
         $this->assertEquals('def/con', $url);
     }
-    
+
     public function testAssembleWithReset()
     {
         $values = $this->route->match('mod/con/act/sort/name');
@@ -326,7 +334,7 @@ class Zend_Controller_Router_Route_ModuleTest extends PHPUnit_Framework_TestCase
 
         $this->assertSame('defctrl/new', $url);
     }
-    
+
     public function testAssembleWithReset2()
     {
         $values = $this->route->match('mod/con/act/sort/name');
@@ -346,7 +354,7 @@ class Zend_Controller_Router_Route_ModuleTest extends PHPUnit_Framework_TestCase
     }
 
     public function testAssembleResetOneVariable()
-    {    
+    {
         $values = $this->route->match('mod/con/act');
 
         $url = $this->route->assemble(array('action' => null), false);
@@ -355,7 +363,7 @@ class Zend_Controller_Router_Route_ModuleTest extends PHPUnit_Framework_TestCase
     }
 
     public function testAssembleResetOneVariable2()
-    {    
+    {
         $values = $this->route->match('mod/con/act');
 
         $url = $this->route->assemble(array('controller' => null), false);
@@ -364,30 +372,30 @@ class Zend_Controller_Router_Route_ModuleTest extends PHPUnit_Framework_TestCase
     }
 
     public function testAssembleResetOneVariable3()
-    {    
+    {
         $values = $this->route->match('mod/con/act');
 
         $url = $this->route->assemble(array('module' => null), false);
 
         $this->assertSame('con/act', $url);
     }
-    
+
     public function testAssembleDefaultModuleResetZF1415()
     {
         $values = $this->route->match('con/act');
-    	
-    	$url = $this->route->assemble(array('controller' => 'foo', 'action' => 'bar'), true);
 
-		$this->assertSame('foo/bar', $url);
+        $url = $this->route->assemble(array('controller' => 'foo', 'action' => 'bar'), true);
+
+        $this->assertSame('foo/bar', $url);
     }
-    
+
     public function testAssembleDefaultModuleZF1415()
     {
         $values = $this->route->match('con/act');
-    	
-    	$url = $this->route->assemble(array('controller' => 'foo', 'action' => 'bar'), false);
 
-		$this->assertSame('foo/bar', $url);
+        $url = $this->route->assemble(array('controller' => 'foo', 'action' => 'bar'), false);
+
+        $this->assertSame('foo/bar', $url);
     }
 
     public function testAssembleDefaultModuleZF1415_2()
@@ -395,12 +403,12 @@ class Zend_Controller_Router_Route_ModuleTest extends PHPUnit_Framework_TestCase
         $values = $this->route->match('default/defctrl/defact');
         $url = $this->route->assemble();
         $this->assertSame('', $url);
-        
+
         $values = $this->route->match('mod/defctrl/defact');
         $url = $this->route->assemble();
         $this->assertSame('mod', $url);
     }
-    
+
     public function testGetInstance()
     {
         require_once 'Zend/Config.php';
@@ -410,11 +418,11 @@ class Zend_Controller_Router_Route_ModuleTest extends PHPUnit_Framework_TestCase
                 'controller' => 'ctrl'
             )
         );
-        
+
         $config = new Zend_Config($routeConf);
         $route = Zend_Controller_Router_Route_Module::getInstance($config);
-        
-        $this->assertType('Zend_Controller_Router_Route_Module', $route);
+
+        $this->assertTrue($route instanceof Zend_Controller_Router_Route_Module);
     }
 
     public function testEncode()
@@ -426,15 +434,55 @@ class Zend_Controller_Router_Route_ModuleTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('My Controller', $url);
 
         $token = $this->route->match('en/foo/id/My Value');
-    
+
         $url = $this->route->assemble(array(), false, true);
         $this->assertEquals('en/foo/id/My+Value', $url);
-        
+
         $url = $this->route->assemble(array('id' => 'My Other Value'), false, true);
         $this->assertEquals('en/foo/id/My+Other+Value', $url);
-        
+
+    }
+
+    public function testArrayValues()
+    {
+        $url = $this->route->assemble(array('foo' => array('bar', 'baz')));
+        $this->assertEquals('defctrl/defact/foo/bar/foo/baz', $url);
+
+        $token = $this->route->match('defctrl/defact/foo/bar/foo/baz');
+        $this->assertEquals('bar', $token['foo'][0]);
+        $this->assertEquals('baz', $token['foo'][1]);
+    }
+
+    public function testGetInstanceMatching()
+    {
+        $this->route = Zend_Controller_Router_Route_Module::getInstance(new Zend_Config(array()));
+
+        $this->_request->setModuleKey('m');
+        $this->_request->setControllerKey('c');
+        $this->_request->setActionKey('a');
+
+        $values = $this->route->match('mod/ctrl');
+
+        $this->assertTrue(is_array($values));
+        $this->assertSame('mod', $values['m'], var_export(array_keys($values), 1));
+        $this->assertSame('ctrl', $values['c'], var_export(array_keys($values), 1));
+        $this->assertSame('index', $values['a'], var_export(array_keys($values), 1));
+    }
+
+    /**
+     * @group ZF-8029
+     */
+    public function testAssembleShouldUrlEncodeAllParameterNames()
+    {
+        $params = array(
+            'controller' => 'foo',
+            'action' => 'bar',
+            '"><script>alert(11639)<' => 'script>',
+            'module' => 'default',
+        );
+        $url = $this->route->assemble($params);
+        $this->assertNotContains('"><script>alert(11639)<', $url);
     }
-    
 }
 
 // Call Zend_Controller_Router_Route_ModuleTest::main() if this source file is executed directly.
