@@ -1,23 +1,49 @@
 <?php
 /**
+ * Zend Framework
+ *
+ * LICENSE
+ *
+ * This source file is subject to the new BSD license that is bundled
+ * with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://framework.zend.com/license/new-bsd
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@zend.com so we can send you a copy immediately.
+ *
  * @category   Zend
  * @package    Zend_Controller
  * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id: RouteTest.php 25217 2013-01-11 11:14:17Z frosch $
  */
 
+if (!defined('PHPUnit_MAIN_METHOD')) {
+    define('PHPUnit_MAIN_METHOD', 'Zend_Controller_Router_RouteTest::main');
+}
+
 /** @see Zend_Controller_Request_Http */
 require_once 'Zend/Controller/Request/Http.php';
 
 /** @see Zend_Controller_Router_Route */
 require_once 'Zend/Controller/Router/Route.php';
 
-/** PHPUnit test case */
-require_once 'PHPUnit/Framework/TestCase.php';
+/** @see Zend_Translate */
+require_once 'Zend/Translate.php';
+
+/** @see Zend_Registry */
+require_once 'Zend/Registry.php';
 
 /**
  * @category   Zend
  * @package    Zend_Controller
  * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Controller
+ * @group      Zend_Controller_Router
  */
 class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
 {
@@ -41,6 +67,13 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
         // Clean host env
         unset($_SERVER['HTTP_HOST'],
             $_SERVER['HTTPS'], $_SERVER['SERVER_NAME'], $_SERVER['SERVER_PORT']);
+
+       // Set translator
+       $translator = new Zend_Translate('array', array('foo' => 'en_foo', 'bar' => 'en_bar'), 'en');
+       $translator->addTranslation(array('foo' => 'de_foo', 'bar' => 'de_bar'), 'de');
+       $translator->setLocale('en');
+
+       Zend_Registry::set('Zend_Translate', $translator);
     }
 
     /**
@@ -52,6 +85,12 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
     {
         // Restore server array
         $_SERVER = $this->_server;
+
+        // Remove translator and locale
+        Zend_Registry::set('Zend_Translate', null);
+        Zend_Registry::set('Zend_Locale', null);
+        Zend_Controller_Router_Route::setDefaultTranslator(null);
+        Zend_Controller_Router_Route::setDefaultLocale(null);
     }
 
     public function testStaticMatch()
@@ -388,17 +427,35 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
     {
         $route = new Zend_Controller_Router_Route('archives/:year/:month');
         $values = $route->match('archives/2006/07');
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
 
         $url = $route->assemble(array('month' => '03'));
         $this->assertEquals('archives/2006/03', $url);
     }
 
+    /**
+     * @group ZF-7917
+     */
+    public function testAssembleWithGivenDataEqualsDefaults()
+    {
+        $route = new Zend_Controller_Router_Route('index/*', array(
+            'module'     => 'default',
+            'controller' => 'index',
+            'action'     => 'index'
+        ));
+
+        $this->assertEquals('index', $route->assemble(array(
+            'module'     => 'default',
+            'controller' => 'index',
+            'action'     => 'index'
+        )));
+    }
+
     public function testWildcardUrlVariablesOverwriting()
     {
         $route = new Zend_Controller_Router_Route('archives/:year/:month/*', array('controller' => 'archive'));
         $values = $route->match('archives/2006/07/controller/test/year/10000/sort/author');
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
 
         $this->assertEquals('archive', $values['controller']);
         $this->assertEquals('2006', $values['year']);
@@ -413,7 +470,7 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
 
         $values = $route->getDefaults();
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertEquals('ctrl', $values['controller']);
         $this->assertEquals('act', $values['action']);
     }
@@ -441,7 +498,7 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
         $config = new Zend_Config($routeConf);
         $route = Zend_Controller_Router_Route::getInstance($config);
 
-        $this->assertType('Zend_Controller_Router_Route', $route);
+        $this->assertTrue($route instanceof Zend_Controller_Router_Route);
 
         $values = $route->match('users/all');
 
@@ -511,26 +568,31 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
      * Test guarding performance. Test may be failing on slow systems and shouldn't be failing on production.
      * This test is not critical in nature - it allows keeping changes performant.
      */
-    public function testRoutePerformance()
-    {
-        $count = 10000;
-        $expectedTime = 1;
 
-        $info = "This test may be failing on slow systems and shouldn't be failing on production. Tests if " . ($count / 10) . " complicated routes can be matched in a tenth of a second. Actual test matches " . $count . " times to make the test more reliable.";
-
-        $route = new Zend_Controller_Router_Route('archives/:year/:month/*', array('controller' => 'archive'));
-
-        $time_start = microtime(true);
-
-        for ($i = 1; $i <= $count; $i++) {
-            $values = $route->match('archives/2006/' . $i . '/controller/test/year/' . $i . '/sort/author');
-        }
-
-        $time_end = microtime(true);
-        $time = $time_end - $time_start;
-
-        $this->assertLessThan($expectedTime, $time, $info);
-    }
+    /**
+     * This test is commented out because performance testing should be done separately from unit
+     * testing. It will be ported to a performance regression suite when such a suite is available.
+     */
+//    public function testRoutePerformance()
+//    {
+//        $count = 10000;
+//        $expectedTime = 1;
+//
+//        $info = "This test may be failing on slow systems and shouldn't be failing on production. Tests if " . ($count / 10) . " complicated routes can be matched in a tenth of a second. Actual test matches " . $count . " times to make the test more reliable.";
+//
+//        $route = new Zend_Controller_Router_Route('archives/:year/:month/*', array('controller' => 'archive'));
+//
+//        $time_start = microtime(true);
+//
+//        for ($i = 1; $i <= $count; $i++) {
+//            $values = $route->match('archives/2006/' . $i . '/controller/test/year/' . $i . '/sort/author');
+//        }
+//
+//        $time_end = microtime(true);
+//        $time = $time_end - $time_start;
+//
+//        $this->assertLessThan($expectedTime, $time, $info);
+//    }
 
     public function testForZF2543()
     {
@@ -538,7 +600,7 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('families', $route->assemble());
 
         $values = $route->match('families/edit/id/4');
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
 
         $this->assertEquals('families/edit/id/4', $route->assemble());
     }
@@ -565,27 +627,176 @@ class Zend_Controller_Router_RouteTest extends PHPUnit_Framework_TestCase
         $url = $route->assemble(array('id' => 1), false, true);
         $this->assertEquals('My+Controller/id/1', $url);
     }
-    
+
     public function testPartialMatch()
     {
-        $this->markTestSkipped('Route features not ready');
-        
         $route = new Zend_Controller_Router_Route(':lang/:temp', array('lang' => 'pl'), array('temp' => '\d+'));
 
         $values = $route->match('en/tmp/ctrl/action/id/1', true);
 
         $this->assertFalse($values);
-        
+
         $route = new Zend_Controller_Router_Route(':lang/:temp', array('lang' => 'pl'));
 
         $values = $route->match('en/tmp/ctrl/action/id/1', true);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertEquals('en', $values['lang']);
         $this->assertEquals('tmp', $values['temp']);
-        $this->assertEquals(6, $values[null]);
-        
-    }
-    
+        $this->assertEquals('en/tmp', $route->getMatchedPath());
 
+    }
+
+    /**
+     * Translated behaviour
+     */
+    public function testStaticTranslationAssemble()
+    {
+        $route = new Zend_Controller_Router_Route('foo/@foo');
+        $url   = $route->assemble();
+
+        $this->assertEquals('foo/en_foo', $url);
+    }
+
+    public function testStaticTranslationMatch()
+    {
+        $route  = new Zend_Controller_Router_Route('foo/@foo');
+        $values = $route->match('foo/en_foo');
+
+        $this->assertTrue(is_array($values));
+    }
+
+    public function testDynamicTranslationAssemble()
+    {
+        $route = new Zend_Controller_Router_Route('foo/:@myvar');
+        $url   = $route->assemble(array('myvar' => 'foo'));
+
+        $this->assertEquals('foo/en_foo', $url);
+    }
+
+    public function testDynamicTranslationMatch()
+    {
+        $route  = new Zend_Controller_Router_Route('foo/:@myvar');
+        $values = $route->match('foo/en_foo');
+
+        $this->assertEquals($values['myvar'], 'foo');
+    }
+
+    public function testTranslationMatchWrongLanguage()
+    {
+        $route  = new Zend_Controller_Router_Route('foo/@foo');
+        $values = $route->match('foo/de_foo');
+
+        $this->assertFalse($values);
+    }
+
+    public function testTranslationAssembleLocaleInstanceOverride()
+    {
+        $route = new Zend_Controller_Router_Route('foo/@foo', null, null, null, 'de');
+        $url   = $route->assemble();
+
+        $this->assertEquals('foo/de_foo', $url);
+    }
+
+    public function testTranslationAssembleLocaleParamOverride()
+    {
+        $route = new Zend_Controller_Router_Route('foo/@foo');
+        $url   = $route->assemble(array('@locale' => 'de'));
+
+        $this->assertEquals('foo/de_foo', $url);
+    }
+
+    public function testTranslationAssembleLocaleStaticOverride()
+    {
+        Zend_Controller_Router_Route::setDefaultLocale('de');
+
+        $route = new Zend_Controller_Router_Route('foo/@foo');
+        $url   = $route->assemble();
+
+        $this->assertEquals('foo/de_foo', $url);
+    }
+
+    public function testTranslationAssembleLocaleRegistryOverride()
+    {
+        Zend_Registry::set('Zend_Locale', 'de');
+
+        $route = new Zend_Controller_Router_Route('foo/@foo');
+        $url   = $route->assemble();
+
+        $this->assertEquals('foo/de_foo', $url);
+    }
+
+    public function testTranslationAssembleTranslatorInstanceOverride()
+    {
+        $translator = new Zend_Translate('array', array('foo' => 'en_baz'), 'en');
+
+        $route = new Zend_Controller_Router_Route('foo/@foo', null, null, $translator);
+        $url   = $route->assemble();
+
+        $this->assertEquals('foo/en_baz', $url);
+    }
+
+    public function testTranslationAssembleTranslatorStaticOverride()
+    {
+        $translator = new Zend_Translate('array', array('foo' => 'en_baz'), 'en');
+
+        Zend_Controller_Router_Route::setDefaultTranslator($translator);
+
+        $route = new Zend_Controller_Router_Route('foo/@foo');
+        $url   = $route->assemble();
+
+        $this->assertEquals('foo/en_baz', $url);
+    }
+
+    public function testTranslationAssembleTranslatorRegistryOverride()
+    {
+        $translator = new Zend_Translate('array', array('foo' => 'en_baz'), 'en');
+
+        Zend_Registry::set('Zend_Translate', $translator);
+
+        $route = new Zend_Controller_Router_Route('foo/@foo');
+        $url   = $route->assemble();
+
+        $this->assertEquals('foo/en_baz', $url);
+    }
+
+    public function testTranslationAssembleTranslatorNotFound()
+    {
+        Zend_Registry::set('Zend_Translate', null);
+
+        $route = new Zend_Controller_Router_Route('foo/@foo');
+
+        try {
+            $url = $route->assemble();
+            $this->fail('Expected Zend_Controller_Router_Exception was not raised');
+        } catch (Zend_Controller_Router_Exception $e) {
+            $this->assertEquals('Could not find a translator', $e->getMessage());
+        }
+    }
+
+    public function testEscapedSpecialCharsWithoutTranslation()
+    {
+        $route = new Zend_Controller_Router_Route('::foo/@@bar/:foo');
+
+        $path = $route->assemble(array('foo' => 'bar'));
+        $this->assertEquals($path, ':foo/@bar/bar');
+
+        $values = $route->match(':foo/@bar/bar');
+        $this->assertEquals($values['foo'], 'bar');
+    }
+
+    public function testEscapedSpecialCharsWithTranslation()
+    {
+        $route = new Zend_Controller_Router_Route('::foo/@@bar/:@myvar');
+
+        $path = $route->assemble(array('myvar' => 'foo'));
+        $this->assertEquals($path, ':foo/@bar/en_foo');
+
+        $values = $route->match(':foo/@bar/en_foo');
+        $this->assertEquals($values['myvar'], 'foo');
+    }
+}
+
+if (PHPUnit_MAIN_METHOD == 'Zend_Controller_Router_RouteTests::main') {
+    Zend_Controller_Router_RouteTests::main();
 }
