@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,12 +15,11 @@
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: MysqliTest.php 6923 2007-11-25 02:00:06Z peptolab $
+ * @version    $Id: MysqliTest.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
-
 /**
  * @see Zend_Db_Adapter_TestCommon
  */
@@ -32,16 +30,14 @@ require_once 'Zend/Db/Adapter/TestCommon.php';
  */
 require_once 'Zend/Db/Adapter/Mysqli.php';
 
-
-PHPUnit_Util_Filter::addFileToFilter(__FILE__);
-
-
 /**
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Db
+ * @group      Zend_Db_Adapter
  */
 class Zend_Db_Adapter_MysqliTest extends Zend_Db_Adapter_TestCommon
 {
@@ -227,18 +223,31 @@ class Zend_Db_Adapter_MysqliTest extends Zend_Db_Adapter_TestCommon
         $this->assertEquals('`foo` AS `bar`', $value);
     }
 
+    /**
+     * test that describeTable() returns correct types
+     * @group ZF-3624
+     *
+     */
+    public function testAdapterDescribeTableAttributeColumnFloat()
+    {
+        $desc = $this->_db->describeTable('zfprice');
+        $this->assertEquals('zfprice',  $desc['price']['TABLE_NAME']);
+        $this->assertRegExp('/float/i', $desc['price']['DATA_TYPE']);
+    }
+
     /**
      * Ensures that the PDO Buffered Query does not throw the error
      * 2014 General error
      *
+     * @group  ZF-2101
      * @link   http://framework.zend.com/issues/browse/ZF-2101
      * @return void
      */
-    public function testZF2101()
+    public function testAdapterToEnsurePdoBufferedQueryThrowsNoError()
     {
         $params = $this->_util->getParams();
         $db = Zend_Db::factory($this->getDriver(), $params);
-        
+
         // Set default bound value
         $customerId = 1;
 
@@ -251,7 +260,7 @@ class Zend_Db_Adapter_MysqliTest extends Zend_Db_Adapter_TestCommon
 
         // Reset statement
         $stmt->closeCursor();
-        
+
         // Stored procedure returns a single row
         $stmt = $db->prepare('CALL zf_test_procedure(?)');
         $stmt->bindParam(1, $customerId);
@@ -264,6 +273,22 @@ class Zend_Db_Adapter_MysqliTest extends Zend_Db_Adapter_TestCommon
         $this->_testAdapterAlternateStatement('Test_MysqliStatement');
     }
 
+    public function testMySqliInitCommand()
+    {
+        $params = $this->_util->getParams();
+        $params['driver_options'] = array(
+            'mysqli_init_command' => 'SET AUTOCOMMIT=0;'
+        );
+
+        $db = Zend_Db::factory($this->getDriver(), $params);
+
+        $sql = 'SELECT @@AUTOCOMMIT as autocommit';
+
+        $row = $db->fetchRow($sql);
+
+        $this->assertEquals(0, $row['autocommit']);
+    }
+
     public function getDriver()
     {
         return 'Mysqli';
