@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: MysqlTest.php 6923 2007-11-25 02:00:06Z peptolab $
+ * @version    $Id: MysqlTest.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
 
@@ -34,15 +33,14 @@ require_once 'Zend/Db/Adapter/Pdo/TestCommon.php';
 require_once 'Zend/Db/Adapter/Pdo/Mysql.php';
 
 
-PHPUnit_Util_Filter::addFileToFilter(__FILE__);
-
-
 /**
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Db
+ * @group      Zend_Db_Adapter
  */
 class Zend_Db_Adapter_Pdo_MysqlTest extends Zend_Db_Adapter_Pdo_TestCommon
 {
@@ -107,7 +105,7 @@ class Zend_Db_Adapter_Pdo_MysqlTest extends Zend_Db_Adapter_Pdo_TestCommon
     /**
      * Ensures that driver_options are properly passed along to PDO
      *
-     * @see    http://framework.zend.com/issues/browse/ZF-285
+     * @group ZF-285
      * @return void
      */
     public function testAdapterDriverOptions()
@@ -239,6 +237,18 @@ class Zend_Db_Adapter_Pdo_MysqlTest extends Zend_Db_Adapter_Pdo_TestCommon
         $this->assertEquals('`table_\'_name`', $value);
     }
 
+    /**
+     * test that describeTable() returns correct types
+     * @group ZF-3624
+     *
+     */
+    public function testAdapterDescribeTableAttributeColumnFloat()
+    {
+        $desc = $this->_db->describeTable('zfprice');
+        $this->assertEquals('zfprice',  $desc['price']['TABLE_NAME']);
+        $this->assertRegExp('/float/i', $desc['price']['DATA_TYPE']);
+    }
+
     /**
      * test that quoteTableAs() accepts a string and an alias,
      * and returns each as delimited identifiers.
@@ -275,7 +285,7 @@ class Zend_Db_Adapter_Pdo_MysqlTest extends Zend_Db_Adapter_Pdo_TestCommon
         $params = $this->_util->getParams();
         $params['driver_options'] = array(PDO::MYSQL_ATTR_USE_BUFFERED_QUERY => true);
         $db = Zend_Db::factory($this->getDriver(), $params);
-        
+
         // Set default bound value
         $customerId = 1;
 
@@ -288,7 +298,7 @@ class Zend_Db_Adapter_Pdo_MysqlTest extends Zend_Db_Adapter_Pdo_TestCommon
 
         // Reset statement
         $stmt->closeCursor();
-        
+
         // Stored procedure returns a single row
         $stmt = $db->prepare('CALL zf_test_procedure(:customerId)');
         $stmt->bindParam('customerId', $customerId, PDO::PARAM_INT);
@@ -297,9 +307,27 @@ class Zend_Db_Adapter_Pdo_MysqlTest extends Zend_Db_Adapter_Pdo_TestCommon
         $this->assertEquals(1, $result[0]['product_id']);
     }
 
+    /**
+     * @group ZF-11304
+     */
+    public function testAdapterIncludesCharsetInsideGeneratedPdoDsn()
+    {
+        $adapter = new ZendTest_Db_Adapter_Pdo_Mysql(array('dbname' => 'foo', 'charset' => 'XYZ', 'username' => 'bar', 'password' => 'foo'));
+        $this->assertEquals('mysql:dbname=foo;charset=XYZ', $adapter->_dsn());
+    }
+    
     public function getDriver()
     {
         return 'Pdo_Mysql';
     }
 
 }
+
+class ZendTest_Db_Adapter_Pdo_Mysql extends Zend_Db_Adapter_Pdo_Mysql
+{
+    public function _dsn()
+    {
+        return parent::_dsn();
+    }
+}
+
