@@ -14,21 +14,15 @@
  *
  * @category   Zend
  * @package    Zend_Db
- * @subpackage Adapter
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: PdoStatement.php 9577 2008-05-31 01:50:27Z peptolab $
+ * @version    $Id: PdoStatement.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
 
-/**
- * PHPUnit_Util_Filter
- */
-require_once 'PHPUnit/Util/Filter.php';
 
 
-PHPUnit_Util_Filter::addFileToFilter(__FILE__);
-
 
 /**
  * @see Zend_Db_Statement_Pdo
@@ -40,8 +34,8 @@ require_once 'Zend/Db/Statement/Pdo.php';
  *
  * @category   Zend
  * @package    Zend_Db
- * @subpackage Adapter
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Test_PdoStatement extends Zend_Db_Statement_Pdo
