@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,53 +15,26 @@
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: AllTests.php 7538 2008-01-21 12:25:15Z kgbfernando $
+ * @version    $Id: AllTests.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
-
 if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'Zend_Db_AllTests::main');
 }
 
-
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
-/**
- * PHPUnit_Framework_TestSuite
- */
-require_once 'PHPUnit/Framework/TestSuite.php';
-
-/**
- * PHPUnit_TextUI_TestRunner
- */
-require_once 'PHPUnit/TextUI/TestRunner.php';
-
-/**
- * @see Zend_Loader
- */
 require_once 'Zend/Loader.php';
-
-/**
- * @see Zend_Db_SkipTests
- */
 require_once 'Zend/Db/SkipTests.php';
-
-/**
- * @see Zend_Db_Profiler_AllTests
- */
 require_once 'Zend/Db/Profiler/AllTests.php';
 
 /**
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Db
  */
 class Zend_Db_AllTests
 {
@@ -90,7 +62,7 @@ class Zend_Db_AllTests
         self::_addDbTestSuites($suite, 'Db2');
         self::_addDbTestSuites($suite, 'Mysqli');
         self::_addDbTestSuites($suite, 'Oracle');
-		self::_addDbTestSuites($suite, 'Firebird');
+        self::_addDbTestSuites($suite, 'Sqlsrv');
 
         /**
          * @todo  self::_addDbTestSuites($suite, 'Odbc');
@@ -101,7 +73,6 @@ class Zend_Db_AllTests
         self::_addDbTestSuites($suite, 'Pdo_Oci');
         self::_addDbTestSuites($suite, 'Pdo_Pgsql');
         self::_addDbTestSuites($suite, 'Pdo_Sqlite');
-		self::_addDbTestSuites($suite, 'Pdo_Firebird');
 
         if (self::$_skipTestSuite !== null) {
             $suite->addTest(self::$_skipTestSuite);
@@ -125,7 +96,7 @@ class Zend_Db_AllTests
             'Oracle' => 'oci8',
             'Db2'    => 'ibm_db2',
             'Mysqli' => 'mysqli',
-			'Firebird' => 'interbase',
+            'Sqlsrv' => 'sqlsrv',
             /**
              * @todo  'Odbc'
              */
