@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: StaticTest.php 4700 2007-05-04 04:25:11Z bkarwin $
+ * @version    $Id: OracleTest.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
 
@@ -28,15 +27,14 @@
 require_once 'Zend/Db/Profiler/TestCommon.php';
 
 
-PHPUnit_Util_Filter::addFileToFilter(__FILE__);
-
-
 /**
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Db
+ * @group      Zend_Db_Profiler
  */
 class Zend_Db_Profiler_OracleTest extends Zend_Db_Profiler_TestCommon
 {
@@ -147,6 +145,38 @@ class Zend_Db_Profiler_OracleTest extends Zend_Db_Profiler_TestCommon
         $this->assertEquals(array(':bug_id' => 3), $params);
     }
 
+    /**
+     * Ensures that setFilterQueryType() actually filters
+     *
+     * @return void
+     */
+    protected function _testProfilerSetFilterQueryTypeCommon($queryType)
+    {
+        $bugs = $this->_db->quoteIdentifier('zfbugs', true);
+        $bug_id = $this->_db->quoteIdentifier('bug_id', true);
+        $bug_status = $this->_db->quoteIdentifier('bug_status', true);
+
+        $prof = $this->_db->getProfiler();
+        $prof->setEnabled(true);
+
+        $this->assertSame($prof->setFilterQueryType($queryType), $prof);
+        $this->assertEquals($queryType, $prof->getFilterQueryType());
+
+        $this->_db->query("SELECT * FROM $bugs");
+        $this->_db->query("INSERT INTO $bugs ($bug_id, $bug_status) VALUES (:id, :status)", array(':id' => 100,':status' => 'NEW'));
+        $this->_db->query("DELETE FROM $bugs");
+        $this->_db->query("UPDATE $bugs SET $bug_status = :status", array(':status'=>'FIXED'));
+
+        $qps = $prof->getQueryProfiles();
+        $this->assertType('array', $qps, 'Expecting some query profiles, got none');
+        foreach ($qps as $qp) {
+            $qtype = $qp->getQueryType();
+            $this->assertEquals($queryType, $qtype,
+                "Found query type $qtype, which should have been filtered out");
+        }
+
+        $prof->setEnabled(false);
+    }
 
     public function getDriver()
     {
