@@ -15,14 +15,26 @@
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2007 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id $
  */
 
 require_once 'Zend/Db/Table/Row/TestCommon.php';
 
-PHPUnit_Util_Filter::addFileToFilter(__FILE__);
 
+
+
+/**
+ * @category   Zend
+ * @package    Zend_Db
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Db
+ * @group      Zend_Db_Table
+ * @group      Zend_Db_Table_Row
+ */
 class Zend_Db_Table_Row_OracleTest extends Zend_Db_Table_Row_TestCommon
 {
 
@@ -31,6 +43,15 @@ class Zend_Db_Table_Row_OracleTest extends Zend_Db_Table_Row_TestCommon
         $this->markTestSkipped($this->getDriver() . ' does not support auto-increment keys.');
     }
 
+    /**
+     * ZF-4330: Oracle need sequence
+     */
+    protected function _testTableRowSetReadOnlyGetTableBugs()
+    {
+        return $this->_getTable('My_ZendDbTable_TableBugs',
+                                array(Zend_Db_Table_Abstract::SEQUENCE => 'zfbugs_seq'));
+    }
+
     public function getDriver()
     {
         return 'Oracle';
