@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: TestCommon.php 7508 2008-01-19 03:12:38Z peptolab $
+ * @version    $Id: TestCommon.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
 
@@ -27,7 +26,8 @@
  */
 require_once 'Zend/Db/Table/TestSetup.php';
 
-PHPUnit_Util_Filter::addFileToFilter(__FILE__);
+
+
 
 require_once 'Zend/Db/Table/Row.php';
 
@@ -36,8 +36,11 @@ require_once 'Zend/Db/Table/Row.php';
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Db
+ * @group      Zend_Db_Table
+ * @group      Zend_Db_Table_Row
  */
 abstract class Zend_Db_Table_Row_TestCommon extends Zend_Db_Table_TestSetup
 {
@@ -73,8 +76,9 @@ abstract class Zend_Db_Table_Row_TestCommon extends Zend_Db_Table_TestSetup
             'data'   => $data,
         );
 
-        Zend_Loader::loadClass('Zend_Db_Table_Row_TestTableRow');
-        return new Zend_Db_Table_Row_TestTableRow($config);
+        $this->_useMyIncludePath();
+        Zend_Loader::loadClass('My_ZendDbTable_Row_TestTableRow');
+        return new My_ZendDbTable_Row_TestTableRow($config);
     }
 
     public function testTableFindRow()
@@ -90,7 +94,7 @@ abstract class Zend_Db_Table_Row_TestCommon extends Zend_Db_Table_TestSetup
     public function testTableRowConstructor()
     {
         $table = $this->_table['bugs'];
-        
+
         $config = array(
                 'db'    => $this->_db,
                 'table' => $table,
@@ -124,6 +128,24 @@ abstract class Zend_Db_Table_Row_TestCommon extends Zend_Db_Table_TestSetup
         }
     }
 
+    // ZF-1144
+    public function testTableRowContructorWithTableNameSpecifiedInSubclass()
+    {
+        $this->_useMyIncludePath();
+
+        /**
+         * @see Zend_Db_Table_Row_TestStandaloneRow
+         */
+        require_once 'My/ZendDbTable/Row/TestStandaloneRow.php';
+
+        Zend_Db_Table_Abstract::setDefaultAdapter($this->_db);
+
+        $row = new My_ZendDbTable_Row_TestStandaloneRow();
+        $this->assertType('Zend_Db_Table_Abstract', $row->getTable());
+
+        Zend_Db_Table_Abstract::setDefaultAdapter();
+    }
+
     public function testTableRowReadOnly()
     {
         $table = $this->_table['bugs'];
@@ -153,12 +175,12 @@ abstract class Zend_Db_Table_Row_TestCommon extends Zend_Db_Table_TestSetup
         $a = $row1->toArray();
 
         $this->assertTrue(is_array($a));
-        
+
         // fix for #ZF-1898
         $arrayObject = new ArrayObject($row1->toArray(),ArrayObject::ARRAY_AS_PROPS);
         $arrayObject->bug_status = 'foobar';
         $this->assertNotEquals('foobar',$row1->bug_status);
-        
+
         $cols = array(
             'bug_id',
             'bug_description',
@@ -215,6 +237,25 @@ abstract class Zend_Db_Table_Row_TestCommon extends Zend_Db_Table_TestSetup
         }
     }
 
+    public function testTableRowMagicUnset()
+    {
+        $table = $this->_table['bugs'];
+        $row   = $table->find(1)->current();
+
+        unset($row->assigned_to);
+        $this->assertFalse(isset($row->assigned_to));
+        $diff = array_diff_key(array('assigned_to'=>''), $row->toArray());
+        $this->assertEquals(array('assigned_to'),array_keys($diff));
+    }
+
+    public function testTableRowMagicUnsetWhenUnsettingPkValueThrowsException()
+    {
+        $table = $this->_table['bugs'];
+        $row   = $table->find(1)->current();
+        $this->setExpectedException('Zend_Db_Table_Row_Exception');
+        unset($row->bug_id);
+    }
+
     public function testTableRowMagicSet()
     {
         $table = $this->_table['bugs'];
@@ -235,6 +276,75 @@ abstract class Zend_Db_Table_Row_TestCommon extends Zend_Db_Table_TestSetup
         }
     }
 
+    // ZF-2013
+    public function testTableRowOffsetGet()
+    {
+        $table = $this->_table['bugs'];
+        $bug_id = $this->_db->foldCase('bug_id');
+        $bug_description = $this->_db->foldCase('bug_description');
+        $bug_status = $this->_db->foldCase('bug_status');
+
+        $rowset = $table->find(1);
+        $this->assertType('Zend_Db_Table_Rowset_Abstract', $rowset,
+            'Expecting object of type Zend_Db_Table_Rowset_Abstract, got '.get_class($rowset));
+        $row1 = $rowset->current();
+        $this->assertType('Zend_Db_Table_Row_Abstract', $row1,
+            'Expecting object of type Zend_Db_Table_Row_Abstract, got '.get_class($row1));
+
+        try {
+            $this->assertEquals(1, $row1->offsetGet($bug_id));
+            $this->assertEquals('System needs electricity to run', $row1->offsetGet($bug_description));
+            $this->assertEquals('NEW', $row1->offsetGet($bug_status));
+        } catch (Zend_Exception $e) {
+            $this->fail("Caught exception of type \"".get_class($e)."\" where no exception was expected.  Exception message: \"".$e->getMessage()."\"\n");
+        }
+    }
+
+    // ZF-2013
+    public function testTableRowOffsetSet()
+    {
+        $table = $this->_table['bugs'];
+        $bug_description = $this->_db->foldCase('bug_description');
+
+        $rowset = $table->find(1);
+        $this->assertType('Zend_Db_Table_Rowset_Abstract', $rowset,
+            'Expecting object of type Zend_Db_Table_Rowset_Abstract, got '.get_class($rowset));
+        $row1 = $rowset->current();
+        $this->assertType('Zend_Db_Table_Row_Abstract', $row1,
+            'Expecting object of type Zend_Db_Table_Row_Abstract, got '.get_class($row1));
+
+        try {
+            $row1->offsetSet($bug_description, 'foo');
+            $this->assertEquals('foo', $row1->offsetGet($bug_description));
+        } catch (Zend_Exception $e) {
+            $this->fail("Caught exception of type \"".get_class($e)."\" where no exception was expected.  Exception message: \"".$e->getMessage()."\"\n");
+        }
+    }
+
+    /**
+     * @group ZF-8902
+     */
+    public function testTableRowOffsetUnset()
+    {
+        $table = $this->_table['bugs'];
+        $bug_description = $this->_db->foldCase('bug_description');
+
+        $rowset = $table->find(1);
+        $this->assertType('Zend_Db_Table_Rowset_Abstract', $rowset,
+            'Expecting object of type Zend_Db_Table_Rowset_Abstract, got '.get_class($rowset));
+        $row1 = $rowset->current();
+        $this->assertType('Zend_Db_Table_Row_Abstract', $row1,
+            'Expecting object of type Zend_Db_Table_Row_Abstract, got '.get_class($row1));
+
+        try {
+            $this->assertTrue($row1->offsetExists($bug_description));
+            $row1->offsetUnset($bug_description);
+            $this->assertFalse($row1->offsetExists($bug_description));
+        } catch (Zend_Exception $e) {
+            $this->fail("Caught exception of type \"".get_class($e)."\" where no exception was expected.  Exception message: \"".$e->getMessage()."\"\n");
+        }
+    }
+
     public function testTableRowSetFromArray()
     {
         $table = $this->_table['bugs'];
@@ -265,6 +375,41 @@ abstract class Zend_Db_Table_Row_TestCommon extends Zend_Db_Table_TestSetup
         }
     }
 
+    /**
+     * ZF-2243: Zend_Db_Table::createRow and Zend_Db_Table_Row::setFromArray have same behaviour
+     */
+    public function testTableRowSetFromBigArray()
+    {
+        $table = $this->_table['bugs'];
+        $bug_description = $this->_db->foldCase('bug_description');
+        $bug_status = $this->_db->foldCase('bug_status');
+
+        // Data issued from form object
+        $data = array(
+            $bug_description => 'New Description',
+            $bug_status      => 'INVALID',
+            'btnAccept'      => 1           // Button value
+        );
+
+        $rowset = $table->find(1);
+        $this->assertType('Zend_Db_Table_Rowset_Abstract', $rowset,
+            'Expecting object of type Zend_Db_Table_Rowset_Abstract, got '.get_class($rowset));
+        $row1 = $rowset->current();
+        $this->assertType('Zend_Db_Table_Row_Abstract', $row1,
+            'Expecting object of type Zend_Db_Table_Row_Abstract, got '.get_class($row1));
+
+        $row1->setFromArray($data);
+
+        try {
+            $button = $row1->btnAccept;
+            $this->fail('Expected to catch Zend_Db_Table_Row_Exception');
+        } catch (Zend_Exception $e) {
+            $this->assertType('Zend_Db_Table_Row_Exception', $e,
+                'Expecting object of type Zend_Db_Table_Row_Exception, got '.get_class($e));
+            $this->assertEquals("Specified column \"btnAccept\" is not in the row", $e->getMessage());
+        }
+    }
+
     public function testTableRowSaveInsert()
     {
         $table = $this->_table['bugs'];
@@ -286,7 +431,7 @@ abstract class Zend_Db_Table_Row_TestCommon extends Zend_Db_Table_TestSetup
 
     public function testTableRowSaveInsertSequence()
     {
-        $table = $this->_getTable('Zend_Db_Table_TableProducts',
+        $table = $this->_getTable('My_ZendDbTable_TableProducts',
             array(Zend_Db_Table_Abstract::SEQUENCE => 'zfproducts_seq'));
         $product_id   = $this->_db->foldCase('product_id');
         $product_name = $this->_db->foldCase('product_name');
@@ -333,11 +478,11 @@ abstract class Zend_Db_Table_Row_TestCommon extends Zend_Db_Table_TestSetup
             $this->fail("Caught exception of type \"".get_class($e)."\" where no exception was expected.  Exception message: \"".$e->getMessage()."\"\n");
         }
     }
-    
+
     public function testTableRowSaveInvalidTable()
     {
         $table = $this->_table['bugs'];
-        
+
         $row = $this->_testTableRow();
 
         try {
@@ -359,14 +504,14 @@ abstract class Zend_Db_Table_Row_TestCommon extends Zend_Db_Table_TestSetup
         } catch (Zend_Exception $e) {
             $this->assertType('Zend_Db_Table_Exception', $e,
                 'Expecting object of type Zend_Db_Table_Row_Exception got '.get_class($e));
-            $this->assertEquals('The specified Table \'Zend_Db_Table_TableBugs\' does not have the same primary key as the Row', $e->getMessage());
+            $this->assertEquals('The specified Table \'My_ZendDbTable_TableBugs\' does not have the same primary key as the Row', $e->getMessage());
         }
     }
 
     public function testTableRowSaveUpdateInvalidInfo()
     {
         $table = $this->_table['bugs'];
-        
+
         $row = $this->_testTableRow();
 
         $bug_status      = $this->_db->foldCase('bug_status');
@@ -391,7 +536,7 @@ abstract class Zend_Db_Table_Row_TestCommon extends Zend_Db_Table_TestSetup
         } catch (Zend_Exception $e) {
             $this->assertType('Zend_Db_Table_Exception', $e,
                 'Expecting object of type Zend_Db_Table_Row_Exception got '.get_class($e));
-            $this->assertEquals('The specified Table \'Zend_Db_Table_TableBugs\' does not have the same primary key as the Row', $e->getMessage());
+            $this->assertEquals('The specified Table \'My_ZendDbTable_TableBugs\' does not have the same primary key as the Row', $e->getMessage());
         }
     }
 
@@ -400,7 +545,7 @@ abstract class Zend_Db_Table_Row_TestCommon extends Zend_Db_Table_TestSetup
         $table = $this->_table['bugs'];
 
         $bug_status = $this->_db->foldCase('bug_status');
-        
+
         $row = $this->_testTableRow();
         $row->$bug_status = 'VALID';
 
@@ -435,14 +580,14 @@ abstract class Zend_Db_Table_Row_TestCommon extends Zend_Db_Table_TestSetup
         } catch (Zend_Exception $e) {
             $this->assertType('Zend_Db_Table_Exception', $e,
                 'Expecting object of type Zend_Db_Table_Exception got '.get_class($e));
-            $this->assertEquals('The specified Table is of class Zend_Db_Table_TableProducts, expecting class to be instance of Zend_Db_Table_TableBugs', $e->getMessage());
+            $this->assertEquals('The specified Table is of class My_ZendDbTable_TableProducts, expecting class to be instance of My_ZendDbTable_TableBugs', $e->getMessage());
         }
     }
 
     public function testTableRowSetInvalidTable()
     {
         $table = $this->_table['bugs'];
-        
+
         $row = $this->_testTableRow();
 
         try {
@@ -452,7 +597,7 @@ abstract class Zend_Db_Table_Row_TestCommon extends Zend_Db_Table_TestSetup
         } catch (Zend_Exception $e) {
             $this->assertType('Zend_Db_Table_Exception', $e,
                 'Expecting object of type Zend_Db_Table_Row_Exception got '.get_class($e));
-            $this->assertEquals('The specified Table is of class Zend_Db_Table_TableBugs, expecting class to be instance of foo', $e->getMessage());
+            $this->assertEquals('The specified Table is of class My_ZendDbTable_TableBugs, expecting class to be instance of foo', $e->getMessage());
         }
     }
 
@@ -516,7 +661,7 @@ abstract class Zend_Db_Table_Row_TestCommon extends Zend_Db_Table_TestSetup
         } catch (Zend_Exception $e) {
             $this->assertType('Zend_Db_Table_Row_Exception', $e,
                 'Expecting object of type Zend_Db_Table_Row_Exception, got '.get_class($e));
-            $this->assertEquals("The specified Table 'Zend_Db_Table_TableBugsProducts' does not have the same primary key as the Row", $e->getMessage());
+            $this->assertEquals("The specified Table 'My_ZendDbTable_TableBugsProducts' does not have the same primary key as the Row", $e->getMessage());
         }
     }
 
@@ -666,14 +811,14 @@ abstract class Zend_Db_Table_Row_TestCommon extends Zend_Db_Table_TestSetup
         } catch (Zend_Exception $e) {
             $this->assertType('Zend_Db_Table_Row_Exception', $e,
                 'Expecting object of type Zend_Db_Table_Row_Exception, got '.get_class($e));
-            $this->assertEquals('The specified Table is of class Zend_Db_Table_TableProducts, expecting class to be instance of Zend_Db_Table_TableBugs', $e->getMessage());
+            $this->assertEquals('The specified Table is of class My_ZendDbTable_TableProducts, expecting class to be instance of My_ZendDbTable_TableBugs', $e->getMessage());
         }
         $this->assertFalse($connected);
     }
 
     public function testTableRowSetReadOnly()
     {
-        $table = $this->_table['bugs'];
+        $table = $this->_testTableRowSetReadOnlyGetTableBugs();
         $bug_status = $this->_db->foldCase('bug_status');
 
         $rowset = $table->find(1);
@@ -731,4 +876,42 @@ abstract class Zend_Db_Table_Row_TestCommon extends Zend_Db_Table_TestSetup
         }
     }
 
+    /**
+     * @group ZF-9836
+     */
+    public function testTableRowIsIterable()
+    {
+        $table = $this->_table['bugs'];
+
+        $rowset = $table->find(1);
+        $row = $rowset->current();
+        $this->assertTrue($row instanceof Traversable);
+        $this->assertTrue($row instanceof IteratorAggregate);
+        $this->assertType('ArrayIterator', $row->getIterator());
+
+        $count=0;
+        foreach ($row as $columnValue) {
+            $count++;
+        }
+
+        $this->assertEquals(8, $count, 'The row was iterated, there should be 8 columns iterated');
+    }
+
+
+    /**
+     * Utility methods below
+     */
+
+
+
+
+    /**
+     * Allow adapters with sequences to declare them
+     * @return Zend_Db_Table_Abstract
+     */
+    protected function _testTableRowSetReadOnlyGetTableBugs()
+    {
+        return $this->_table['bugs'];
+    }
+
 }
