@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Dojo
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: DojoTest.php 11745 2008-10-08 18:25:37Z zendbot $
+ * @version    $Id: DojoTest.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
 // Call Zend_Dojo_View_Helper_DojoTest::main() if this source file is executed directly.
@@ -25,8 +25,6 @@ if (!defined("PHPUnit_MAIN_METHOD")) {
     define("PHPUnit_MAIN_METHOD", "Zend_Dojo_View_Helper_DojoTest::main");
 }
 
-require_once dirname(__FILE__) . '/../../../../TestHelper.php';
-
 /** Zend_Dojo_View_Helper_Dojo */
 require_once 'Zend/Dojo/View/Helper/Dojo.php';
 
@@ -45,10 +43,12 @@ require_once 'Zend/View.php';
  * @category   Zend
  * @package    Zend_Dojo
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Dojo
+ * @group      Zend_Dojo_View
  */
-class Zend_Dojo_View_Helper_DojoTest extends PHPUnit_Framework_TestCase 
+class Zend_Dojo_View_Helper_DojoTest extends PHPUnit_Framework_TestCase
 {
     /**
      * Runs the test methods of this class.
@@ -206,22 +206,22 @@ class Zend_Dojo_View_Helper_DojoTest extends PHPUnit_Framework_TestCase
         $this->assertTrue($this->helper->useCdn());
     }
 
-    public function testShouldUseAolCdnByDefault()
+    public function testShouldUseGoogleCdnByDefault()
     {
-        $this->assertEquals(Zend_Dojo::CDN_BASE_AOL, $this->helper->getCdnBase());
+        $this->assertEquals(Zend_Dojo::CDN_BASE_GOOGLE, $this->helper->getCdnBase());
     }
 
     public function testShouldAllowSpecifyingCdnBasePath()
     {
-        $this->testShouldUseAolCdnByDefault();
-        $this->helper->setCdnBase(Zend_Dojo::CDN_BASE_GOOGLE);
-        $this->assertEquals(Zend_Dojo::CDN_BASE_GOOGLE, $this->helper->getCdnBase());
+        $this->testShouldUseGoogleCdnByDefault();
+        $this->helper->setCdnBase(Zend_Dojo::CDN_BASE_AOL);
+        $this->assertEquals(Zend_Dojo::CDN_BASE_AOL, $this->helper->getCdnBase());
     }
 
     public function testShouldUseLatestVersionWhenUsingCdnByDefault()
     {
         $this->helper->enable();
-        $this->assertEquals('1.1.1', $this->helper->getCdnVersion());
+        $this->assertEquals('1.5.0', $this->helper->getCdnVersion());
     }
 
     public function testShouldAllowSpecifyingDojoVersionWhenUtilizingCdn()
@@ -429,7 +429,7 @@ function() {
                     $this->assertContains('parseOnLoad', $script);
                     break;
                 case 1:
-                    $this->assertContains('src="http://o.aolcdn.com/dojo/1.1/dojo/dojo.xd.js"', $script);
+                    $this->assertRegexp('#src="http://.+/dojo/[0-9.]+/dojo/dojo.xd.js"#', $script);
                     $this->assertContains('/>', $script);
                     break;
                 case 2:
@@ -446,7 +446,7 @@ function() {
         $style = $doc->saveXML($results->item(0));
         $this->assertContains('@import', $style);
         $this->assertEquals(2, substr_count($style, '@import'));
-        $this->assertEquals(1, substr_count($style, 'http://o.aolcdn.com/dojo/1.1/'), $style);
+        $this->assertEquals(1, substr_count($style, 'http://ajax.googleapis.com/ajax/libs/dojo/'), $style);
         $this->assertContains('css/custom.css', $style);
         $this->assertContains('dijit/themes/tundra/tundra.css', $style);
     }
@@ -640,7 +640,7 @@ function() {
         $this->assertContains($json, $html, $html);
 
         $found = false;
-        foreach ($this->helper->getOnLoadActions() as $action) {
+        foreach ($this->helper->_getZendLoadActions() as $action) {
             if (strstr($action, 'dojo.mixin')) {
                 $found = true;
                 break;
@@ -799,7 +799,6 @@ function() {
     }
 
     /**
-     * @see   ZF-3962
      * @group ZF-3962
      */
     public function testHelperShouldAllowDisablingParseOnLoadWithDeclarativeStyle()
@@ -835,6 +834,81 @@ function() {
         $this->assertNull($test);
     }
 
+    /**
+     * @group ZF-4587
+     * @group ZF-5808
+     */
+    public function testZendDijitOnLoadMarkupShouldPrecedeAllOtherOnLoadEvents()
+    {
+        $this->helper->addOnLoad('zend.custom');
+        $this->view->textBox('foo', 'bar');
+        $test = $this->helper->__toString();
+        $this->assertRegexp('/zendDijits.*?(zend\.custom)/s', $test, 'Generated markup: ' . $test);
+    }
+
+    public function testDojoViewHelperContainerAddOptionsPassesOnAllStringOptions() {
+        $helper = $this->helper;
+        $options = array(
+            'requireModules' => 'ZfTestRequiredModule',
+            'laYers' => '_added_layer_',
+            'cdnBase' => 'ZF-RLZ',
+            'cdnVersion' => '1.9.5',
+            'cdnDojoPath' => '_cdn_dojo_path_',
+            'localPath' => '/srv/ZF/dojo/',
+            'stylesheetmodules' => 'test.stylesheet.module',
+            'stylesheets' => 'someStyleSheet',
+            'registerdojostylesheet' => true
+        );
+
+        $helper->setOptions($options);
+
+        $this->assertEquals(array('ZfTestRequiredModule'), $helper->getModules());
+        $this->assertEquals(array('_added_layer_'), $helper->getLayers());
+        $this->assertEquals('ZF-RLZ', $helper->getCdnBase());
+        $this->assertEquals('1.9.5', $helper->getCdnVersion());
+        $this->assertEquals('_cdn_dojo_path_', $helper->getCdnDojoPath());
+        $this->assertEquals('/srv/ZF/dojo/', $helper->getLocalPath());
+        $this->assertEquals(array('test.stylesheet.module'), $helper->getStyleSheetModules());
+        $this->assertEquals(array('someStyleSheet'), $helper->getStylesheets());
+        $this->assertTrue($helper->registerDojoStylesheet());
+    }
+
+    public function testDojoViewHelperContainerAddOptionsPassesOnAllArrayOptions() {
+        $helper = $this->helper;
+        $modulePaths = array('module1' => 'path1', 'module2' => 'path2');
+        $layers = array('layer_two','layer_three');
+        $djConfig = array('foo1' => 'bar1', 'foo2' => 'bar2');
+        $stylesheetMods = array('test.one.style', 'test.two.style');
+        $stylesheets = array('style1', 'style2');
+        $options = array(
+            'modulePaths'   => $modulePaths,
+            'layers'        => $layers,
+            'djConfig'      => $djConfig,
+            'styleShEEtModules' => $stylesheetMods,
+            'stylesheets'   => $stylesheets,
+            'registerdojostylesheet' => false
+        );
+
+        $helper->setOptions($options);
+
+        $this->assertEquals($modulePaths, $helper->getModulePaths());
+        $this->assertEquals($layers, $helper->getLayers());
+        $this->assertEquals($djConfig, $helper->getDjConfig());
+        $this->assertEquals($stylesheetMods, $helper->getStyleSheetModules());
+        $this->assertEquals($stylesheets, $helper->getStylesheets());
+        $this->assertFalse($helper->registerDojoStylesheet());
+    }
+
+    public function testJsonExpressionRenders()
+    {
+        $this->helper->addDijit('foo',
+                array('dojoType' => 'dijit.form.TextBox',
+                      'onChange' => new Zend_Json_Expr('function(){alert(\'foo\');}'),
+                      ));
+        $output = $this->helper->dijitsToJson();
+        $this->assertRegexp('#(function\\(\\){alert\\(\'foo\'\\);})#', $output);
+    }
+
     public function setupDojo()
     {
         $this->helper->requireModule('dijit.layout.ContentPane')
