@@ -1,20 +1,47 @@
 <?php
+/**
+ * Zend Framework
+ *
+ * LICENSE
+ *
+ * This source file is subject to the new BSD license that is bundled
+ * with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://framework.zend.com/license/new-bsd
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@zend.com so we can send you a copy immediately.
+ *
+ * @category   Zend
+ * @package    Zend_File
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id: AbstractTest.php 24593 2012-01-05 20:35:02Z matthew $
+ */
+
 // Call Zend_File_Transfer_Adapter_AbstractTest::main() if this source file is executed directly.
 if (!defined("PHPUnit_MAIN_METHOD")) {
     define("PHPUnit_MAIN_METHOD", "Zend_File_Transfer_Adapter_AbstractTest::main");
 }
 
-require_once dirname(__FILE__) . '/../../../../TestHelper.php';
-
 require_once 'Zend/File/Transfer/Adapter/Abstract.php';
 require_once 'Zend/Filter/BaseName.php';
 require_once 'Zend/Filter/StringToLower.php';
+require_once 'Zend/Filter/StringToUpper.php';
 require_once 'Zend/Loader/PluginLoader.php';
 require_once 'Zend/Validate/File/Count.php';
 require_once 'Zend/Validate/File/Extension.php';
 
 /**
  * Test class for Zend_File_Transfer_Adapter_Abstract
+ *
+ * @category   Zend
+ * @package    Zend_File
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_File
  */
 class Zend_File_Transfer_Adapter_AbstractTest extends PHPUnit_Framework_TestCase
 {
@@ -50,14 +77,6 @@ class Zend_File_Transfer_Adapter_AbstractTest extends PHPUnit_Framework_TestCase
     {
     }
 
-    public function testAdapterShouldImplementValidatorInterface()
-    {
-        // Commented out: The implementation is actually not instancing
-        // Zend_Validate_Interface. This was a failure in the initial implementation.
-        // But it allows to set validators to use within it.
-        // $this->assertTrue($this->adapter instanceof Zend_Validate_Interface);
-    }
-
     /**
      * @expectedException Zend_File_Transfer_Exception
      */
@@ -152,7 +171,7 @@ class Zend_File_Transfer_Adapter_AbstractTest extends PHPUnit_Framework_TestCase
 
     public function testAdapterShouldAllowAddingValidatorInstance()
     {
-        $validator = new Zend_Validate_File_Count(1, 1);
+        $validator = new Zend_Validate_File_Count(array('min' => 1, 'max' => 1));
         $this->adapter->addValidator($validator);
         $test = $this->adapter->getValidator('Zend_Validate_File_Count');
         $this->assertSame($validator, $test);
@@ -160,7 +179,7 @@ class Zend_File_Transfer_Adapter_AbstractTest extends PHPUnit_Framework_TestCase
 
     public function testAdapterShouldAllowAddingValidatorViaPluginLoader()
     {
-        $this->adapter->addValidator('Count');
+        $this->adapter->addValidator('Count', false, array('min' => 1, 'max' => 1));
         $test = $this->adapter->getValidator('Count');
         $this->assertTrue($test instanceof Zend_Validate_File_Count);
     }
@@ -301,12 +320,9 @@ class Zend_File_Transfer_Adapter_AbstractTest extends PHPUnit_Framework_TestCase
         $this->assertFalse($this->adapter->isValid('foo'));
     }
 
-    /**
-     * @expectedException Zend_File_Transfer_Exception
-     */
     public function testValidationShouldThrowExceptionForNonexistentFile()
     {
-        $this->adapter->isValid('bogus');
+        $this->assertFalse($this->adapter->isValid('bogus'));
     }
 
     public function testErrorMessagesShouldBeEmptyByDefault()
@@ -356,7 +372,7 @@ class Zend_File_Transfer_Adapter_AbstractTest extends PHPUnit_Framework_TestCase
 
     public function testAdapterShouldAllowAddingFilterInstance()
     {
-        $filter = new Zend_Filter_StringToLower(1, 1);
+        $filter = new Zend_Filter_StringToLower();
         $this->adapter->addFilter($filter);
         $test = $this->adapter->getFilter('Zend_Filter_StringToLower');
         $this->assertSame($filter, $test);
@@ -364,9 +380,9 @@ class Zend_File_Transfer_Adapter_AbstractTest extends PHPUnit_Framework_TestCase
 
     public function testAdapterShouldAllowAddingFilterViaPluginLoader()
     {
-        $this->adapter->addFilter('StringToUpper');
-        $test = $this->adapter->getFilter('StringToUpper');
-        $this->assertTrue($test instanceof Zend_Filter_StringToUpper);
+        $this->adapter->addFilter('StringTrim');
+        $test = $this->adapter->getFilter('StringTrim');
+        $this->assertTrue($test instanceof Zend_Filter_StringTrim);
     }
 
     /**
@@ -484,20 +500,8 @@ class Zend_File_Transfer_Adapter_AbstractTest extends PHPUnit_Framework_TestCase
         $this->assertEquals(0, count($filters));
     }
 
-    public function testDestinationShouldDefaultToSystemTempDirectory()
-    {
-        $tmpdir = sys_get_temp_dir();
-        $tmpdir = rtrim($tmpdir, "/\\");
-        $destinations = $this->adapter->getDestination();
-        foreach ($destinations as $file => $destination) {
-            $this->assertEquals($tmpdir, $destination);
-        }
-        $this->assertEquals($tmpdir, $this->adapter->getDestination('foo'));
-    }
-
     public function testTransferDestinationShouldBeMutable()
     {
-        $this->testDestinationShouldDefaultToSystemTempDirectory();
         $directory = dirname(__FILE__);
         $this->adapter->setDestination($directory);
         $destinations = $this->adapter->getDestination();
@@ -518,27 +522,52 @@ class Zend_File_Transfer_Adapter_AbstractTest extends PHPUnit_Framework_TestCase
 
     public function testAdapterShouldAllowRetrievingDestinationsForAnArrayOfSpecifiedFiles()
     {
-        $this->testTransferDestinationShouldBeMutable();
+        $this->adapter->setDestination(dirname(__FILE__));
         $destinations = $this->adapter->getDestination(array('bar', 'baz'));
         $this->assertTrue(is_array($destinations));
+        $directory = dirname(__FILE__);
         foreach ($destinations as $file => $destination) {
             $this->assertTrue(in_array($file, array('bar', 'baz')));
-            $this->assertEquals('/var/www/upload', $destination);
+            $this->assertEquals($directory, $destination);
         }
     }
 
     public function testSettingAndRetrievingOptions()
     {
-        $this->assertEquals(array('ignoreNoFile' => false), $this->adapter->getOptions());
+        $this->assertEquals(
+            array(
+                'bar' => array('ignoreNoFile' => false, 'useByteString' => true),
+                'baz' => array('ignoreNoFile' => false, 'useByteString' => true),
+                'foo' => array('ignoreNoFile' => false, 'useByteString' => true, 'detectInfos' => true),
+                'file_0_' => array('ignoreNoFile' => false, 'useByteString' => true),
+                'file_1_' => array('ignoreNoFile' => false, 'useByteString' => true),
+            ), $this->adapter->getOptions());
 
         $this->adapter->setOptions(array('ignoreNoFile' => true));
-        $this->assertEquals(array('ignoreNoFile' => true), $this->adapter->getOptions());
+        $this->assertEquals(
+            array(
+                'bar' => array('ignoreNoFile' => true, 'useByteString' => true),
+                'baz' => array('ignoreNoFile' => true, 'useByteString' => true),
+                'foo' => array('ignoreNoFile' => true, 'useByteString' => true, 'detectInfos' => true),
+                'file_0_' => array('ignoreNoFile' => true, 'useByteString' => true),
+                'file_1_' => array('ignoreNoFile' => true, 'useByteString' => true),
+            ), $this->adapter->getOptions());
+
+        $this->adapter->setOptions(array('ignoreNoFile' => false), 'foo');
+        $this->assertEquals(
+            array(
+                'bar' => array('ignoreNoFile' => true, 'useByteString' => true),
+                'baz' => array('ignoreNoFile' => true, 'useByteString' => true),
+                'foo' => array('ignoreNoFile' => false, 'useByteString' => true, 'detectInfos' => true),
+                'file_0_' => array('ignoreNoFile' => true, 'useByteString' => true),
+                'file_1_' => array('ignoreNoFile' => true, 'useByteString' => true),
+            ), $this->adapter->getOptions());
     }
 
     public function testGetAllAdditionalFileInfos()
     {
         $files = $this->adapter->getFileInfo();
-        $this->assertEquals(3, count($files));
+        $this->assertEquals(5, count($files));
         $this->assertEquals('baz.text', $files['baz']['name']);
     }
 
@@ -556,7 +585,7 @@ class Zend_File_Transfer_Adapter_AbstractTest extends PHPUnit_Framework_TestCase
     {
         $files = $this->adapter->getFileInfo('unknown');
     }
-    
+
     /**
      * @expectedException Zend_File_Transfer_Exception
      */
@@ -607,32 +636,291 @@ class Zend_File_Transfer_Adapter_AbstractTest extends PHPUnit_Framework_TestCase
         $this->adapter->setDestination($path);
         $this->assertEquals($path . DIRECTORY_SEPARATOR . 'foo.jpg', $this->adapter->getFileName('foo'));
     }
+
+    public function testAdapterShouldAllowRetrievingFileNameWithoutPath()
+    {
+        $path = dirname(__FILE__)
+              . DIRECTORY_SEPARATOR . '..'
+              . DIRECTORY_SEPARATOR . '..'
+              . DIRECTORY_SEPARATOR . '..'
+              . DIRECTORY_SEPARATOR . '_files';
+        $this->adapter->setDestination($path);
+        $this->assertEquals('foo.jpg', $this->adapter->getFileName('foo', false));
+    }
+
+    public function testAdapterShouldAllowRetrievingAllFileNames()
+    {
+        $path = dirname(__FILE__)
+              . DIRECTORY_SEPARATOR . '..'
+              . DIRECTORY_SEPARATOR . '..'
+              . DIRECTORY_SEPARATOR . '..'
+              . DIRECTORY_SEPARATOR . '_files';
+        $this->adapter->setDestination($path);
+        $files = $this->adapter->getFileName();
+        $this->assertTrue(is_array($files));
+        $this->assertEquals($path . DIRECTORY_SEPARATOR . 'bar.png', $files['bar']);
+    }
+
+    public function testAdapterShouldAllowRetrievingAllFileNamesWithoutPath()
+    {
+        $path = dirname(__FILE__)
+              . DIRECTORY_SEPARATOR . '..'
+              . DIRECTORY_SEPARATOR . '..'
+              . DIRECTORY_SEPARATOR . '..'
+              . DIRECTORY_SEPARATOR . '_files';
+        $this->adapter->setDestination($path);
+        $files = $this->adapter->getFileName(null, false);
+        $this->assertTrue(is_array($files));
+        $this->assertEquals('bar.png', $files['bar']);
+    }
+
+    public function testExceptionForUnknownHashValue()
+    {
+        try {
+            $this->adapter->getHash('foo', 'unknown_hash');
+            $this->fail();
+        } catch (Zend_Exception $e) {
+            $this->assertContains('Unknown hash algorithm', $e->getMessage());
+        }
+    }
+
+    public function testIgnoreHashValue()
+    {
+        $this->adapter->addInvalidFile();
+        $return = $this->adapter->getHash('crc32', 'test');
+        $this->assertEquals(array(), $return);
+    }
+
+    public function testEmptyTempDirectoryDetection()
+    {
+        $this->adapter->_tmpDir = "";
+        $this->assertTrue(empty($this->adapter->_tmpDir), "Empty temporary directory");
+    }
+
+    public function testTempDirectoryDetection()
+    {
+        $this->adapter->getTmpDir();
+        $this->assertTrue(!empty($this->adapter->_tmpDir), "Temporary directory filled");
+    }
+
+    public function testTemporaryDirectoryAccessDetection()
+    {
+        $this->adapter->_tmpDir = ".";
+        $path = "/NoPath/To/File";
+        $this->assertFalse($this->adapter->isPathWriteable($path));
+        $this->assertTrue($this->adapter->isPathWriteable($this->adapter->_tmpDir));
+    }
+
+    public function testFileSizeButNoFileFound()
+    {
+        try {
+            $this->assertEquals(10, $this->adapter->getFileSize());
+            $this->fail();
+        } catch (Zend_File_Transfer_Exception $e) {
+            $this->assertContains('does not exist', $e->getMessage());
+        }
+    }
+
+    public function testIgnoreFileSize()
+    {
+        $this->adapter->addInvalidFile();
+        $return = $this->adapter->getFileSize('test');
+        $this->assertEquals(array(), $return);
+    }
+
+    public function testFileSizeByTmpName()
+    {
+        $options = $this->adapter->getOptions();
+        $this->assertTrue($options['baz']['useByteString']);
+        $this->assertEquals('1.14kB', $this->adapter->getFileSize('baz.text'));
+        $this->adapter->setOptions(array('useByteString' => false));
+        $options = $this->adapter->getOptions();
+        $this->assertFalse($options['baz']['useByteString']);
+        $this->assertEquals(1172, $this->adapter->getFileSize('baz.text'));
+    }
+
+    public function testMimeTypeButNoFileFound()
+    {
+        try {
+            $this->assertEquals('image/jpeg', $this->adapter->getMimeType());
+            $this->fail();
+        } catch (Zend_File_Transfer_Exception $e) {
+            $this->assertContains('does not exist', $e->getMessage());
+        }
+    }
+
+    public function testIgnoreMimeType()
+    {
+        $this->adapter->addInvalidFile();
+        $return = $this->adapter->getMimeType('test');
+        $this->assertEquals(array(), $return);
+    }
+
+    public function testMimeTypeByTmpName()
+    {
+        $this->assertEquals('text/plain', $this->adapter->getMimeType('baz.text'));
+    }
+
+    public function testSetOwnErrorMessage()
+    {
+        $this->adapter->addValidator('Count', false, array('min' => 5, 'max' => 5, 'messages' => array(Zend_Validate_File_Count::TOO_FEW => 'Zu wenige')));
+        $this->assertFalse($this->adapter->isValid('foo'));
+        $message = $this->adapter->getMessages();
+        $this->assertContains('Zu wenige', $message);
+
+        try {
+            $this->assertEquals('image/jpeg', $this->adapter->getMimeType());
+            $this->fail();
+        } catch (Zend_File_Transfer_Exception $e) {
+            $this->assertContains('does not exist', $e->getMessage());
+        }
+    }
+
+    public function testTransferDestinationAtNonExistingElement()
+    {
+        $directory = dirname(__FILE__);
+        $this->adapter->setDestination($directory, 'nonexisting');
+        $this->assertEquals($directory, $this->adapter->getDestination('nonexisting'));
+        try {
+            $this->assertTrue(is_string($this->adapter->getDestination('reallynonexisting')));
+            $this->fail();
+        } catch(Exception $e) {
+            $this->assertContains('not find', $e->getMessage());
+        }
+    }
+
+    /**
+     * @ZF-7376
+     */
+    public function testSettingMagicFile()
+    {
+        $this->adapter->setOptions(array('magicFile' => 'test/file'));
+        $this->assertEquals(
+            array(
+                'bar' => array('magicFile' => 'test/file', 'ignoreNoFile' => false, 'useByteString' => true),
+            ), $this->adapter->getOptions('bar'));
+    }
+
+    /**
+     * @ZF-8693
+     */
+    public function testAdapterShouldAllowAddingMultipleValidatorsAtOnceUsingBothInstancesAndPluginLoaderForDifferentFiles()
+    {
+        $validators = array(
+            array('MimeType', true, array('image/jpeg')), // no files
+            array('FilesSize', true, array('max' => '1MB', 'messages' => 'файл больше 1MБ')), // no files
+            array('Count', true, array('min' => 1, 'max' => '1', 'messages' => 'файл не 1'), 'bar'), // 'bar' from config
+            array('MimeType', true, array('image/jpeg'), 'bar'), // 'bar' from config
+        );
+
+        $this->adapter->addValidators($validators, 'foo'); // set validators to 'foo'
+
+        $test = $this->adapter->getValidators();
+        $this->assertEquals(3, count($test));
+
+        //test files specific validators
+        $test = $this->adapter->getValidators('foo');
+        $this->assertEquals(2, count($test));
+        $mimeType = array_shift($test);
+        $this->assertTrue($mimeType instanceof Zend_Validate_File_MimeType);
+        $filesSize = array_shift($test);
+        $this->assertTrue($filesSize instanceof Zend_Validate_File_FilesSize);
+
+        $test = $this->adapter->getValidators('bar');
+        $this->assertEquals(2, count($test));
+        $filesSize = array_shift($test);
+        $this->assertTrue($filesSize instanceof Zend_Validate_File_Count);
+        $mimeType = array_shift($test);
+        $this->assertTrue($mimeType instanceof Zend_Validate_File_MimeType);
+
+        $test = $this->adapter->getValidators('baz');
+        $this->assertEquals(0, count($test));
+    }
+
+    /**
+     * @ZF-9132
+     */
+    public function testSettingAndRetrievingDetectInfosOption()
+    {
+        $this->assertEquals(array(
+            'foo' => array(
+                'ignoreNoFile' => false,
+                'useByteString' => true,
+                'detectInfos' => true))
+            , $this->adapter->getOptions('foo'));
+        $this->adapter->setOptions(array('detectInfos' => false));
+        $this->assertEquals(array(
+            'foo' => array(
+                'ignoreNoFile' => false,
+                'useByteString' => true,
+                'detectInfos' => false))
+            , $this->adapter->getOptions('foo'));
+    }
 }
 
 class Zend_File_Transfer_Adapter_AbstractTest_MockAdapter extends Zend_File_Transfer_Adapter_Abstract
 {
     public $received = false;
 
+    public $_tmpDir;
+
     public function __construct()
     {
+        $testfile = dirname(__FILE__) . '/_files/test.txt';
         $this->_files = array(
             'foo' => array(
-                'name'     => 'foo.jpg',
-                'type'     => 'image/jpeg',
-                'size'     => 126976,
-                'tmp_name' => '/tmp/489127ba5c89c',
+                'name'      => 'foo.jpg',
+                'type'      => 'image/jpeg',
+                'size'      => 126976,
+                'tmp_name'  => '/tmp/489127ba5c89c',
+                'options'   => array('ignoreNoFile' => false, 'useByteString' => true, 'detectInfos' => true),
+                'validated' => false,
+                'received'  => false,
+                'filtered'  => false,
             ),
             'bar' => array(
                 'name'     => 'bar.png',
                 'type'     => 'image/png',
                 'size'     => 91136,
                 'tmp_name' => '/tmp/489128284b51f',
+                'options'  => array('ignoreNoFile' => false, 'useByteString' => true),
+                'validated' => false,
+                'received'  => false,
+                'filtered'  => false,
             ),
             'baz' => array(
                 'name'     => 'baz.text',
                 'type'     => 'text/plain',
                 'size'     => 1172,
-                'tmp_name' => '/tmp/4891286cceff3',
+                'tmp_name' => $testfile,
+                'options'  => array('ignoreNoFile' => false, 'useByteString' => true),
+                'validated' => false,
+                'received'  => false,
+                'filtered'  => false,
+            ),
+            'file_0_' => array(
+                'name'      => 'foo.jpg',
+                'type'      => 'image/jpeg',
+                'size'      => 126976,
+                'tmp_name'  => '/tmp/489127ba5c89c',
+                'options'   => array('ignoreNoFile' => false, 'useByteString' => true),
+                'validated' => false,
+                'received'  => false,
+                'filtered'  => false,
+            ),
+            'file_1_' => array(
+                'name'     => 'baz.text',
+                'type'     => 'text/plain',
+                'size'     => 1172,
+                'tmp_name' => $testfile,
+                'options'  => array('ignoreNoFile' => false, 'useByteString' => true),
+                'validated' => false,
+                'received'  => false,
+                'filtered'  => false,
+            ),
+            'file' => array(
+                'name'      => 'foo.jpg',
+                'multifiles' => array(0 => 'file_0_', 1 => 'file_1_')
             ),
         );
     }
@@ -658,10 +946,46 @@ class Zend_File_Transfer_Adapter_AbstractTest_MockAdapter extends Zend_File_Tran
         return $this->received;
     }
 
-    public function getProgress()
+    public function isUploaded($files = null)
+    {
+        return true;
+    }
+
+    public function isFiltered($files = null)
+    {
+        return true;
+    }
+
+    public static function getProgress()
     {
         return;
     }
+
+    public function getTmpDir()
+    {
+        $this->_tmpDir = parent::_getTmpDir();
+    }
+
+    public function isPathWriteable($path)
+    {
+        return parent::_isPathWriteable($path);
+    }
+
+    public function addInvalidFile()
+    {
+        $this->_files += array(
+            'test' => array(
+                'name'      => 'test.txt',
+                'type'      => 'image/jpeg',
+                'size'      => 0,
+                'tmp_name'  => '',
+                'options'   => array('ignoreNoFile' => true, 'useByteString' => true),
+                'validated' => false,
+                'received'  => false,
+                'filtered'  => false,
+            )
+        );
+    }
 }
 
 // Call Zend_File_Transfer_Adapter_AbstractTest::main() if this source file is executed directly.
