@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,17 +15,11 @@
  * @category   Zend
  * @package    Zend_Filter
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: AlnumTest.php 9268 2008-04-21 07:35:12Z yoshida@zend.co.jp $
+ * @version    $Id: AlnumTest.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
-
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
 /**
  * @see Zend_Filter_Alnum
  */
@@ -37,8 +30,9 @@ require_once 'Zend/Filter/Alnum.php';
  * @category   Zend
  * @package    Zend_Filter
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Filter
  */
 class Zend_Filter_AlnumTest extends PHPUnit_Framework_TestCase
 {
@@ -58,18 +52,18 @@ class Zend_Filter_AlnumTest extends PHPUnit_Framework_TestCase
 
     /**
      * Locale in browser.
-     * 
+     *
      * @var Zend_Locale object
      */
     protected $_locale;
-    
+
     /**
      * The Alphabet means english alphabet.
-     * 
+     *
      * @var boolean
      */
     protected static $_meansEnglishAlphabet;
-    
+
     /**
      * Creates a new Zend_Filter_Alnum object for each test method
      *
@@ -82,10 +76,10 @@ class Zend_Filter_AlnumTest extends PHPUnit_Framework_TestCase
             self::$_unicodeEnabled = (@preg_match('/\pL/u', 'a')) ? true : false;
         }
         if (null === self::$_meansEnglishAlphabet) {
-        	$this->_locale = new Zend_Locale(Zend_Locale::BROWSER);
-        	self::$_meansEnglishAlphabet = in_array($this->_locale->getLanguage(),
-        											array('ja')
-									                );
+            $this->_locale = new Zend_Locale('auto');
+            self::$_meansEnglishAlphabet = in_array($this->_locale->getLanguage(),
+                                                    array('ja')
+                                                    );
         }
     }
 
@@ -98,19 +92,19 @@ class Zend_Filter_AlnumTest extends PHPUnit_Framework_TestCase
     {
         if (!self::$_unicodeEnabled) {
             // POSIX named classes are not supported, use alternative a-zA-Z match
-	    	$valuesExpected = array(
-	            'abc123'  => 'abc123',
-	            'abc 123' => 'abc123',
-	            'abcxyz'  => 'abcxyz',
-	            'AZ@#4.3' => 'AZ43',
-	            ''        => ''
-	            );
+            $valuesExpected = array(
+                'abc123'  => 'abc123',
+                'abc 123' => 'abc123',
+                'abcxyz'  => 'abcxyz',
+                'AZ@#4.3' => 'AZ43',
+                ''        => ''
+                );
         } if (self::$_meansEnglishAlphabet) {
-        	//The Alphabet means english alphabet.
-			/**
+            //The Alphabet means english alphabet.
+            /**
              * The first element contains multibyte alphabets and digits.
              *  But , Zend_Filter_Alnum is expected to return only singlebyte alphabets and digits.
-             * 
+             *
              * The second contains multibyte or singebyte space.
              * The third  contains various multibyte or singebyte characters.
              */
@@ -120,16 +114,16 @@ class Zend_Filter_AlnumTest extends PHPUnit_Framework_TestCase
                 '，s1.2r３#:q,' => 's12rq',
             );
         } else {
-        	//The Alphabet means each language's alphabet.
+            //The Alphabet means each language's alphabet.
             $valuesExpected = array(
-	            'abc123'  => 'abc123',
-	            'abc 123' => 'abc123',
-	            'abcxyz'  => 'abcxyz',
+                'abc123'  => 'abc123',
+                'abc 123' => 'abc123',
+                'abcxyz'  => 'abcxyz',
                 'če2t3ně'         => 'če2t3ně',
                 'grz5e4gżółka'    => 'grz5e4gżółka',
                 'Be3l5gië'        => 'Be3l5gië',
-            	''        => ''
-				);
+                ''        => ''
+                );
         }
         foreach ($valuesExpected as $input => $output) {
             $this->assertEquals(
@@ -147,35 +141,35 @@ class Zend_Filter_AlnumTest extends PHPUnit_Framework_TestCase
      */
     public function testAllowWhiteSpace()
     {
-        $this->_filter->allowWhiteSpace = true;
-        
+        $this->_filter->setAllowWhiteSpace(true);
+
         if (!self::$_unicodeEnabled) {
             // POSIX named classes are not supported, use alternative a-zA-Z match
-	        $valuesExpected = array(
-	            'abc123'  => 'abc123',
-	            'abc 123' => 'abc 123',
-	            'abcxyz'  => 'abcxyz',
-	            'AZ@#4.3' => 'AZ43',
-	            ''        => '',
-	            "\n"      => "\n",
-	            " \t "    => " \t "
-	            );
-        } if (self::$_meansEnglishAlphabet) {
-        	//The Alphabet means english alphabet.
             $valuesExpected = array(
-				'a B ４5'  => 'a B 5',
-				'z3　x'  => 'z3x'
+                'abc123'  => 'abc123',
+                'abc 123' => 'abc 123',
+                'abcxyz'  => 'abcxyz',
+                'AZ@#4.3' => 'AZ43',
+                ''        => '',
+                "\n"      => "\n",
+                " \t "    => " \t "
+                );
+        } if (self::$_meansEnglishAlphabet) {
+            //The Alphabet means english alphabet.
+            $valuesExpected = array(
+                'a B ４5'  => 'a B 5',
+                'z3　x'  => 'z3x'
                 );
         } else {
-        	//The Alphabet means each language's alphabet.
+            //The Alphabet means each language's alphabet.
             $valuesExpected = array(
-	            'abc123'  => 'abc123',
-	            'abc 123' => 'abc 123',
-	            'abcxyz'  => 'abcxyz',
+                'abc123'  => 'abc123',
+                'abc 123' => 'abc 123',
+                'abcxyz'  => 'abcxyz',
                 'če2 t3ně'         => 'če2 t3ně',
                 'gr z5e4gżółka'    => 'gr z5e4gżółka',
                 'Be3l5 gië'        => 'Be3l5 gië',
-            	''        => '',
+                ''        => '',
             );
         }
         foreach ($valuesExpected as $input => $output) {
@@ -186,4 +180,4 @@ class Zend_Filter_AlnumTest extends PHPUnit_Framework_TestCase
                 );
         }
     }
-}
\ No newline at end of file
+}
