@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,17 +15,12 @@
  * @category   Zend
  * @package    Zend_Filter
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: AlphaTest.php 9268 2008-04-21 07:35:12Z yoshida@zend.co.jp $
+ * @version    $Id: AlphaTest.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
 /**
  * @see Zend_Filter_Alpha
  */
@@ -37,8 +31,9 @@ require_once 'Zend/Filter/Alpha.php';
  * @category   Zend
  * @package    Zend_Filter
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Filter
  */
 class Zend_Filter_AlphaTest extends PHPUnit_Framework_TestCase
 {
@@ -58,18 +53,18 @@ class Zend_Filter_AlphaTest extends PHPUnit_Framework_TestCase
 
     /**
      * Locale in browser.
-     * 
+     *
      * @var Zend_Locale object
      */
     protected $_locale;
-    
+
     /**
      * The Alphabet means english alphabet.
-     * 
+     *
      * @var boolean
      */
     protected static $_meansEnglishAlphabet;
-    
+
     /**
      * Creates a new Zend_Filter_Alpha object for each test method
      *
@@ -82,10 +77,10 @@ class Zend_Filter_AlphaTest extends PHPUnit_Framework_TestCase
             self::$_unicodeEnabled = (@preg_match('/\pL/u', 'a')) ? true : false;
         }
         if (null === self::$_meansEnglishAlphabet) {
-        	$this->_locale = new Zend_Locale(Zend_Locale::BROWSER);
-        	self::$_meansEnglishAlphabet = in_array($this->_locale->getLanguage(),
-        											array('ja')
-									                );
+            $this->_locale = new Zend_Locale('auto');
+            self::$_meansEnglishAlphabet = in_array($this->_locale->getLanguage(),
+                                                    array('ja')
+                                                    );
         }
     }
 
@@ -105,7 +100,7 @@ class Zend_Filter_AlphaTest extends PHPUnit_Framework_TestCase
                 ''              => ''
                 );
         } else if (self::$_meansEnglishAlphabet) {
-        	//The Alphabet means english alphabet.
+            //The Alphabet means english alphabet.
             /**
              * The first element contains multibyte alphabets.
              *  But , Zend_Filter_Alpha is expected to return only singlebyte alphabets.
@@ -120,9 +115,9 @@ class Zend_Filter_AlphaTest extends PHPUnit_Framework_TestCase
                 'Ｗ1v３Ｕ4t' => 'vt',
                 '，sй.rλ:qν＿p' => 'srqp',
                 'onml' => 'onml'
-                );               
+                );
         } else {
-        	//The Alphabet means each language's alphabet.
+            //The Alphabet means each language's alphabet.
             $valuesExpected = array(
                 'abc123'        => 'abc',
                 'abc 123'       => 'abc',
@@ -151,7 +146,7 @@ class Zend_Filter_AlphaTest extends PHPUnit_Framework_TestCase
      */
     public function testAllowWhiteSpace()
     {
-        $this->_filter->allowWhiteSpace = true;
+        $this->_filter->setAllowWhiteSpace(true);
         if (!self::$_unicodeEnabled) {
             // POSIX named classes are not supported, use alternative a-zA-Z match
             $valuesExpected = array(
@@ -163,13 +158,13 @@ class Zend_Filter_AlphaTest extends PHPUnit_Framework_TestCase
                 " \t "          => " \t "
                 );
         } if (self::$_meansEnglishAlphabet) {
-        	//The Alphabet means english alphabet.
+            //The Alphabet means english alphabet.
             $valuesExpected = array(
                 'a B'  => 'a B',
                 'zＹ　x'  => 'zx'
                 );
         } else {
-        	//The Alphabet means each language's alphabet.
+            //The Alphabet means each language's alphabet.
             $valuesExpected = array(
                 'abc123'        => 'abc',
                 'abc 123'       => 'abc ',
