@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,17 +15,11 @@
  * @category   Zend
  * @package    Zend_Filter
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: DigitsTest.php 9267 2008-04-21 06:59:08Z yoshida@zend.co.jp $
+ * @version    $Id: DigitsTest.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
-
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
 /**
  * @see Zend_Filter_Digits
  */
@@ -37,8 +30,9 @@ require_once 'Zend/Filter/Digits.php';
  * @category   Zend
  * @package    Zend_Filter
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Filter
  */
 class Zend_Filter_DigitsTest extends PHPUnit_Framework_TestCase
 {
@@ -55,7 +49,7 @@ class Zend_Filter_DigitsTest extends PHPUnit_Framework_TestCase
      * @var mixed
      **/
     protected static $_unicodeEnabled;
-    
+
     /**
      * Creates a new Zend_Filter_Digits object for each test method
      *
@@ -77,34 +71,34 @@ class Zend_Filter_DigitsTest extends PHPUnit_Framework_TestCase
     public function testBasic()
     {
         if (self::$_unicodeEnabled && extension_loaded('mbstring')) {
-        	// Filter for the value with mbstring
-	        /**
-	         * The first element of $valuesExpected contains multibyte digit characters.
-	         *   But , Zend_Filter_Digits is expected to return only singlebyte digits.
-	         *
-	         * The second contains multibyte or singebyte space, and also alphabet.
-	         * The third  contains various multibyte characters.
-	         * The last contains only singlebyte digits.
-	         */
-	        $valuesExpected = array(
-	            '1９2八3四８'     => '123',
-	            'Ｃ 4.5B　6'      => '456',
-	            '9壱8＠7．6，5＃4' => '987654',
-	            '789'              => '789'
-	            );
+            // Filter for the value with mbstring
+            /**
+             * The first element of $valuesExpected contains multibyte digit characters.
+             *   But , Zend_Filter_Digits is expected to return only singlebyte digits.
+             *
+             * The second contains multibyte or singebyte space, and also alphabet.
+             * The third  contains various multibyte characters.
+             * The last contains only singlebyte digits.
+             */
+            $valuesExpected = array(
+                '1９2八3四８'     => '123',
+                'Ｃ 4.5B　6'      => '456',
+                '9壱8＠7．6，5＃4' => '987654',
+                '789'              => '789'
+                );
         } else {
-        	// POSIX named classes are not supported, use alternative 0-9 match
-        	// Or filter for the value without mbstring
-        	$valuesExpected = array(
-	            'abc123'  => '123',
-	            'abc 123' => '123',
-	            'abcxyz'  => '',
-	            'AZ@#4.3' => '43',
-	            '1.23'    => '123',
-	            '0x9f'    => '09'
-	            );
-	    }
-	            
+            // POSIX named classes are not supported, use alternative 0-9 match
+            // Or filter for the value without mbstring
+            $valuesExpected = array(
+                'abc123'  => '123',
+                'abc 123' => '123',
+                'abcxyz'  => '',
+                'AZ@#4.3' => '43',
+                '1.23'    => '123',
+                '0x9f'    => '09'
+                );
+        }
+
         foreach ($valuesExpected as $input => $output) {
             $this->assertEquals(
                 $output,
@@ -113,4 +107,4 @@ class Zend_Filter_DigitsTest extends PHPUnit_Framework_TestCase
                 );
         }
     }
-}
\ No newline at end of file
+}
