@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Filter
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: InflectorTest.php 9045 2008-03-25 15:57:29Z ralph $
+ * @version    $Id: InflectorTest.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
 
@@ -27,11 +26,6 @@ if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'Zend_Filter_InflectorTest::main');
 }
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
 /**
  * @see Zend_Filter_Inflector
  */
@@ -49,8 +43,9 @@ require_once 'Zend/Config.php';
  * @category   Zend
  * @package    Zend_Filter
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Filter
  */
 class Zend_Filter_InflectorTest extends PHPUnit_Framework_TestCase
 {
@@ -361,10 +356,6 @@ class Zend_Filter_InflectorTest extends PHPUnit_Framework_TestCase
     {
         $options = array(
             'target' => '$controller/$action.$suffix',
-            'filterPrefixPath' => array(
-                'Zend_View_Filter' => 'Zend/View/Filter/',
-                'Foo_Filter'       => 'foo/filters/'
-            ),
             'throwTargetExceptionsOn' => true,
             'targetReplacementIdentifier' => '$',
             'rules' => array(
@@ -378,6 +369,10 @@ class Zend_Filter_InflectorTest extends PHPUnit_Framework_TestCase
                 ),
                 'suffix' => 'php'
             ),
+            'filterPrefixPath' => array(
+                'Zend_View_Filter' => 'Zend/View/Filter/',
+                'Foo_Filter'       => 'foo/filters/'
+            ),
         );
         return $options;
     }
@@ -429,15 +424,15 @@ class Zend_Filter_InflectorTest extends PHPUnit_Framework_TestCase
         $inflector->setConfig($config);
         $this->_testOptions($inflector);
     }
-    
+
     /**
      * Added str_replace('\\', '\\\\', ..) to all processedParts values to disable backreferences
-     * 
-     * @issue ZF-2538 Zend_Filter_Inflector::filter() fails with all numeric folder on Windows
+     *
+     * @group ZF-2538 Zend_Filter_Inflector::filter() fails with all numeric folder on Windows
      */
     public function testCheckInflectorWithPregBackreferenceLikeParts()
     {
-        
+
         $this->inflector = new Zend_Filter_Inflector(
             ':moduleDir' . DIRECTORY_SEPARATOR . ':controller' . DIRECTORY_SEPARATOR . ':action.:suffix',
             array(
@@ -450,10 +445,10 @@ class Zend_Filter_InflectorTest extends PHPUnit_Framework_TestCase
             );
 
         $this->inflector->setStaticRule('moduleDir', 'C:\htdocs\public\cache\00\01\42\app\modules');
-        
+
         try {
             $filtered = $this->inflector->filter(array(
-                'controller' => 'FooBar', 
+                'controller' => 'FooBar',
                 'action' => 'MooToo'
                 ));
             $this->assertEquals($filtered, 'C:\htdocs\public\cache\00\01\42\app\modules' . DIRECTORY_SEPARATOR . 'foo-bar' . DIRECTORY_SEPARATOR . 'Moo-Too.phtml');
@@ -461,21 +456,22 @@ class Zend_Filter_InflectorTest extends PHPUnit_Framework_TestCase
             $this->fail($e->getMessage());
         }
     }
-    
+
     /**
-     * @issue ZF-2522
+     * @group ZF-2522
      */
     public function testTestForFalseInConstructorParams()
     {
         $inflector = new Zend_Filter_Inflector('something', array(), false, false);
         $this->assertFalse($inflector->isThrowTargetExceptionsOn());
         $this->assertEquals($inflector->getTargetReplacementIdentifier(), ':');
+
         $inflector = new Zend_Filter_Inflector('something', array(), false, '#');
         $this->assertEquals($inflector->getTargetReplacementIdentifier(), '#');
     }
-    
+
     /**
-     * @issue ZF-2964
+     * @group ZF-2964
      */
     public function testNoInflectableTarget()
     {
@@ -483,7 +479,68 @@ class Zend_Filter_InflectorTest extends PHPUnit_Framework_TestCase
         $inflector->addRules(array(':foo' => array()));
         $this->assertEquals($inflector->filter(array('fo' => 'bar')), 'abc');
     }
-    
+
+    /**
+     * @group ZF-7544
+     */
+    public function testAddFilterRuleMultipleTimes()
+    {
+        $rules = $this->inflector->getRules();
+        $this->assertEquals(0, count($rules));
+        $this->inflector->setFilterRule('controller', 'PregReplace');
+        $rules = $this->inflector->getRules('controller');
+        $this->assertEquals(1, count($rules));
+        $this->inflector->addFilterRule('controller', array('Alpha', 'StringToLower'));
+        $rules = $this->inflector->getRules('controller');
+        $this->assertEquals(3, count($rules));
+        $this->_context = 'StringToLower';
+        $this->inflector->setStaticRuleReference('context' , $this->_context);
+        $this->inflector->addFilterRule('controller', array('Alpha', 'StringToLower'));
+        $rules = $this->inflector->getRules('controller');
+        $this->assertEquals(5, count($rules));
+    }
+
+    /**
+     * @group ZF-8997
+     */
+    public function testPassingArrayToConstructorSetsStateAndRules()
+    {
+        $options = $this->getOptions();
+        $inflector = new Zend_Filter_Inflector($options);
+        $this->_testOptions($inflector);
+    }
+
+    /**
+     * @group ZF-8997
+     */
+    public function testPassingArrayToSetConfigSetsStateAndRules()
+    {
+        $options = $this->getOptions();
+        $inflector = new Zend_Filter_Inflector();
+        $inflector->setOptions($options);
+        $this->_testOptions($inflector);
+    }
+
+    /**
+     * @group ZF-8997
+     */
+    public function testPassingZendConfigObjectToConstructorSetsStateAndRules()
+    {
+        $config = $this->getConfig();
+        $inflector = new Zend_Filter_Inflector($config);
+        $this->_testOptions($inflector);
+    }
+
+    /**
+     * @group ZF-8997
+     */
+    public function testPassingZendConfigObjectToSetConfigSetsStateAndRules()
+    {
+        $config = $this->getConfig();
+        $inflector = new Zend_Filter_Inflector();
+        $inflector->setOptions($config);
+        $this->_testOptions($inflector);
+    }
 }
 
 // Call Zend_Filter_InflectorTest::main() if this source file is executed directly.
