@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,16 +15,15 @@
  * @category   Zend
  * @package    Zend_Filter
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: StripTagsTest.php 10752 2008-08-07 13:20:50Z alexander $
+ * @version    $Id: StripTagsTest.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
-
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../TestHelper.php';
+// Call Zend_Filter_StripTagsTest::main() if this source file is executed directly.
+if (!defined('PHPUnit_MAIN_METHOD')) {
+    define('PHPUnit_MAIN_METHOD', 'Zend_Filter_StripTagsTest::main');
+}
 
 /**
  * @see Zend_Filter_StripTags
@@ -37,8 +35,9 @@ require_once 'Zend/Filter/StripTags.php';
  * @category   Zend
  * @package    Zend_Filter
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Filter
  */
 class Zend_Filter_StripTagsTest extends PHPUnit_Framework_TestCase
 {
@@ -49,6 +48,18 @@ class Zend_Filter_StripTagsTest extends PHPUnit_Framework_TestCase
      */
     protected $_filter;
 
+    /**
+     * Runs the test methods of this class.
+     *
+     * @return void
+     */
+    public static function main()
+    {
+
+        $suite  = new PHPUnit_Framework_TestSuite(__CLASS__);
+        $result = PHPUnit_TextUI_TestRunner::run($suite);
+    }
+
     /**
      * Creates a new Zend_Filter_StripTags object for each test method
      *
@@ -318,7 +329,7 @@ class Zend_Filter_StripTagsTest extends PHPUnit_Framework_TestCase
             );
         $this->_filter->setTagsAllowed($tagsAllowed);
         $input    = '<img src="image.png" alt="square height="100" width="100" />';
-        $expected = '<img src="image.png" height="100" width="100" />';
+        $expected = '<img src="image.png" alt="square height=" width="100" />';
         $this->assertEquals($expected, $this->_filter->filter($input));
     }
 
@@ -388,68 +399,75 @@ class Zend_Filter_StripTagsTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * Ensures that a comment is not removed when comments are allowed
+     * Ensures that a comment IS removed when comments are flagged as allowed
      *
+     * @group ZF-8473
      * @return void
      */
-    public function testFilterCommentAllowed()
+    public function testSpecifyingCommentsAllowedStillStripsComments()
     {
         $input    = '<!-- a comment -->';
-        $expected = '<!-- a comment -->';
-        $this->_filter->commentsAllowed = true;
+        $expected = '';
+        $this->_filter->setCommentsAllowed(true);
         $this->assertEquals($expected, $this->_filter->filter($input));
     }
 
     /**
      * Ensures that a comment containing tags is untouched when comments are allowed
      *
+     * @group ZF-8473
      * @return void
      */
-    public function testFilterCommentAllowedContainsTags()
+    public function testSpecifyingCommentsAllowedStripsCommentsContainingTags()
     {
         $input    = '<!-- a comment <br /> <h1>SuperLarge</h1> -->';
-        $expected = '<!-- a comment <br /> <h1>SuperLarge</h1> -->';
-        $this->_filter->commentsAllowed = true;
+        $expected = '';
+        $this->_filter->setCommentsAllowed(true);
         $this->assertEquals($expected, $this->_filter->filter($input));
     }
 
     /**
-     * Ensures expected behavior when comments are allowed and a comment contains tags and linebreaks
+     * Ensures expected behavior when comments are marked as allowed (in our
+     * case, this should have no effect) and a comment contains tags and
+     * linebreaks
      *
+     * @group ZF-8473
      * @return void
      */
-    public function testFilterCommentsAllowedContainsTagsLinebreaks()
+    public function testSpecifyingCommentsAllowedFiltersCommentsContainingTagsAndLinebreaks()
     {
         $input    = "<br> test <p> text </p> with <!-- comments --> and <!-- hidd\n\nen <br> -->";
-        $expected = " test  text  with <!-- comments --> and <!-- hidd\n\nen <br> -->";
-        $this->_filter->commentsAllowed = true;
+        $expected = " test  text  with  and ";
+        $this->_filter->setCommentsAllowed(true);
         $this->assertEquals($expected, $this->_filter->filter($input));
     }
 
     /**
      * Ensures expected behavior when comments are allowed but nested
      *
+     * @group ZF-8473
      * @return void
      */
-    public function testFilterCommentsAllowedNested()
+    public function testSpecifyingCommentsAllowedShouldStillStripNestedComments()
     {
         $input    = '<a> <!-- <b> <!-- <c> --> <d> --> <e>';
-        $expected = ' <!-- <b> <!-- <c> -->  -- ';
-        $this->_filter->commentsAllowed = true;
+        $expected = '  ';
+        $this->_filter->setCommentsAllowed(true);
         $this->assertEquals($expected, $this->_filter->filter($input));
     }
 
     /**
-     * Ensures that space is allowed between the double-hyphen '--' and the ending delimiter '>'
+     * Ensures that space between double-hyphen and closing bracket still matches as a comment delimiter
      *
+     * @group ZF-8473
      * @see    http://www.w3.org/TR/1999/REC-html401-19991224/intro/sgmltut.html#h-3.2.4
      * @return void
      */
     public function testFilterCommentsAllowedDelimiterEndingWhiteSpace()
     {
         $input    = '<a> <!-- <b> --  > <c>';
-        $expected = ' <!-- <b> --  > ';
-        $this->_filter->commentsAllowed = true;
+        $expected = '  ';
+        $this->_filter->setCommentsAllowed(true);
         $this->assertEquals($expected, $this->_filter->filter($input));
     }
 
@@ -473,20 +491,138 @@ class Zend_Filter_StripTagsTest extends PHPUnit_Framework_TestCase
     /**
      * Ensures that an allowed attribute's value may end with an equals sign '='
      *
-     * @return void
-     * @link   http://framework.zend.com/issues/browse/ZF-3293
+     * @group ZF-3293
+     * @group ZF-5983
      */
     public function testAllowedAttributeValueMayEndWithEquals()
     {
-        $this->markTestSkipped();
-        return;
-        /*
         $tagsAllowed = array(
             'element' => 'attribute'
         );
         $this->_filter->setTagsAllowed($tagsAllowed);
         $input = '<element attribute="a=">contents</element>';
         $this->assertEquals($input, $this->_filter->filter($input));
-        */
+    }
+
+    /**
+     * @group ZF-5983
+     */
+    public function testDisallowedAttributesSplitOverMultipleLinesShouldBeStripped()
+    {
+        $tagsAllowed = array('a' => 'href');
+        $this->_filter->setTagsAllowed($tagsAllowed);
+        $input = '<a href="http://framework.zend.com/issues" onclick
+=
+    "alert(&quot;Gotcha&quot;); return false;">http://framework.zend.com/issues</a>';
+        $filtered = $this->_filter->filter($input);
+        $this->assertNotContains('onclick', $filtered);
+    }
+
+    /**
+     * @ZF-8828
+     */
+    public function testFilterIsoChars()
+    {
+        $input    = 'äöü<!-- a comment -->äöü';
+        $expected = 'äöüäöü';
+        $this->assertEquals($expected, $this->_filter->filter($input));
+
+        $input    = 'äöü<!-- a comment -->äöü';
+        $input    = iconv("UTF-8", "ISO-8859-1", $input);
+        $output   = $this->_filter->filter($input);
+        $this->assertFalse(empty($output));
+    }
+
+    /**
+     * @ZF-8828
+     */
+    public function testFilterIsoCharsInComment()
+    {
+        $input    = 'äöü<!--üßüßüß-->äöü';
+        $expected = 'äöüäöü';
+        $this->assertEquals($expected, $this->_filter->filter($input));
+
+        $input    = 'äöü<!-- a comment -->äöü';
+        $input    = iconv("UTF-8", "ISO-8859-1", $input);
+        $output   = $this->_filter->filter($input);
+        $this->assertFalse(empty($output));
+    }
+
+    /**
+     * @ZF-8828
+     */
+    public function testFilterSplitCommentTags()
+    {
+        $input    = 'äöü<!-->üßüßüß<-->äöü';
+        $expected = 'äöüäöü';
+        $this->assertEquals($expected, $this->_filter->filter($input));
+    }
+
+    /**
+     * @group ZF-9434
+     */
+    public function testCommentWithTagInSameLine()
+    {
+        $input    = 'test <!-- testcomment --> test <div>div-content</div>';
+        $expected = 'test  test div-content';
+        $this->assertEquals($expected, $this->_filter->filter($input));
+    }
+
+    /**
+     * @group ZF-9833
+     */
+    public function testMultiParamArray()
+    {
+        $filter = new Zend_Filter_StripTags(array("a","b","hr"),array(),true);
+
+        $input    = 'test <a /> test <div>div-content</div>';
+        $expected = 'test <a /> test div-content';
+        $this->assertEquals($expected, $filter->filter($input));
+    }
+
+    /**
+     * @group ZF-9828
+     */
+    public function testMultiQuoteInput()
+    {
+        $filter = new Zend_Filter_StripTags(
+            array(
+                'allowTags' => 'img',
+                'allowAttribs' => array('width', 'height', 'src')
+            )
+        );
+
+        $input    = '<img width="10" height="10" src=\'wont_be_matched.jpg\'>';
+        $expected = '<img width="10" height="10" src=\'wont_be_matched.jpg\'>';
+        $this->assertEquals($expected, $filter->filter($input));
+    }
+
+    /**
+     * @group ZF-10256
+     */
+    public function testNotClosedHtmlCommentAtEndOfString()
+    {
+        $input    = 'text<!-- not closed comment at the end';
+        $expected = 'text';
+        $this->assertEquals($expected, $this->_filter->filter($input));
+    }
+    
+    /**
+     * @group ZF-11617
+     */
+    public function testFilterCanAllowHyphenatedAttributeNames()
+    {
+        $input     = '<li data-disallowed="no!" data-name="Test User" data-id="11223"></li>';
+        $expected  = '<li data-name="Test User" data-id="11223"></li>';
+        
+        $this->_filter->setTagsAllowed('li');
+        $this->_filter->setAttributesAllowed(array('data-id','data-name'));
+        
+        $this->assertEquals($expected, $this->_filter->filter($input));
     }
 }
+
+// Call Zend_Filter_StripTagsTest::main() if this source file is executed directly.
+if (PHPUnit_MAIN_METHOD === 'Zend_Filter_StripTagsTest::main') {
+    Zend_Filter_StripTagsTest::main();
+}
