@@ -1,12 +1,25 @@
 <?php
-
 /**
+ * Zend Framework
+ *
+ * LICENSE
+ *
+ * This source file is subject to the new BSD license that is bundled
+ * with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://framework.zend.com/license/new-bsd
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@zend.com so we can send you a copy immediately.
+ *
  * @category   Zend
  * @package    Zend_Mail
  * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id: ImapTest.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
-
 /**
  * Zend_Mail_Storage_Imap
  */
@@ -22,16 +35,14 @@ require_once 'Zend/Mail/Protocol/Imap.php';
  */
 require_once 'Zend/Config.php';
 
-/**
- * PHPUnit test case
- */
-require_once 'PHPUnit/Framework/TestCase.php';
-
 
 /**
  * @category   Zend
  * @package    Zend_Mail
  * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Mail
  */
 class Zend_Mail_ImapTest extends PHPUnit_Framework_TestCase
 {
@@ -294,13 +305,13 @@ class Zend_Mail_ImapTest extends PHPUnit_Framework_TestCase
         $mail = new Zend_Mail_Storage_Imap($this->_params);
 
         $count = $mail->countMessages();
-        $this->assertEquals(6, $count);
+        $this->assertEquals(7, $count);
     }
 
     public function testSize()
     {
         $mail = new Zend_Mail_Storage_Imap($this->_params);
-        $shouldSizes = array(1 => 397, 89, 694, 452, 497, 101);
+        $shouldSizes = array(1 => 397, 89, 694, 452, 497, 101, 139);
 
 
         $sizes = $mail->getSize();
@@ -732,7 +743,7 @@ class Zend_Mail_ImapTest extends PHPUnit_Framework_TestCase
         $protocol->login($this->_params['user'], $this->_params['password']);
         $status = $protocol->select('INBOX');
         $this->assertTrue(is_array($status['flags']));
-        $this->assertEquals($status['exists'], 6);
+        $this->assertEquals($status['exists'], 7);
     }
 
 
@@ -742,7 +753,7 @@ class Zend_Mail_ImapTest extends PHPUnit_Framework_TestCase
         $protocol->login($this->_params['user'], $this->_params['password']);
         $status = $protocol->examine('INBOX');
         $this->assertTrue(is_array($status['flags']));
-        $this->assertEquals($status['exists'], 6);
+        $this->assertEquals($status['exists'], 7);
     }
 
     public function testClosedSocketNewlineToken()
@@ -778,10 +789,10 @@ class Zend_Mail_ImapTest extends PHPUnit_Framework_TestCase
         $protocol->login($this->_params['user'], $this->_params['password']);
         $protocol->select('INBOX');
 
-        $range = array_combine(range(1, 6), range(1, 6));
+        $range = array_combine(range(1, 7), range(1, 7));
         $this->assertEquals($protocol->fetch('UID', 1, INF), $range);
-        $this->assertEquals($protocol->fetch('UID', 1, 6), $range);
-        $this->assertEquals($protocol->fetch('UID', range(1, 6)), $range);
+        $this->assertEquals($protocol->fetch('UID', 1, 7), $range);
+        $this->assertEquals($protocol->fetch('UID', range(1, 7)), $range);
         $this->assertTrue(is_numeric($protocol->fetch('UID', 1)));
 
         $result = $protocol->fetch(array('UID', 'FLAGS'), 1, INF);
@@ -815,7 +826,7 @@ class Zend_Mail_ImapTest extends PHPUnit_Framework_TestCase
         $result = $protocol->store(array('\Flagged'), 1, null, '+', false);
         $this->assertTrue(in_array('\Flagged', $result[1]));
     }
-    
+
     public function testMove()
     {
         $mail = new Zend_Mail_Storage_Imap($this->_params);
@@ -835,18 +846,18 @@ class Zend_Mail_ImapTest extends PHPUnit_Framework_TestCase
     {
         $mail = new Zend_Mail_Storage_Imap($this->_params);
         foreach ($mail as $id => $message) {
-        	$mail->setFlags($id, array());
+            $mail->setFlags($id, array());
         }
-		$this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_SEEN), 0);
-		$this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_ANSWERED), 0);
-		$this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_FLAGGED), 0);
+        $this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_SEEN), 0);
+        $this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_ANSWERED), 0);
+        $this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_FLAGGED), 0);
 
-		$mail->setFlags(1, array(Zend_Mail_Storage::FLAG_SEEN, Zend_Mail_Storage::FLAG_ANSWERED));
-		$mail->setFlags(2, array(Zend_Mail_Storage::FLAG_SEEN));
-		$this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_SEEN), 2);
-		$this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_ANSWERED), 1);
-		$this->assertEquals($mail->countMessages(array(Zend_Mail_Storage::FLAG_SEEN, Zend_Mail_Storage::FLAG_ANSWERED)), 1);
-		$this->assertEquals($mail->countMessages(array(Zend_Mail_Storage::FLAG_SEEN, Zend_Mail_Storage::FLAG_FLAGGED)), 0);
-		$this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_FLAGGED), 0);
-    }    	
+        $mail->setFlags(1, array(Zend_Mail_Storage::FLAG_SEEN, Zend_Mail_Storage::FLAG_ANSWERED));
+        $mail->setFlags(2, array(Zend_Mail_Storage::FLAG_SEEN));
+        $this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_SEEN), 2);
+        $this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_ANSWERED), 1);
+        $this->assertEquals($mail->countMessages(array(Zend_Mail_Storage::FLAG_SEEN, Zend_Mail_Storage::FLAG_ANSWERED)), 1);
+        $this->assertEquals($mail->countMessages(array(Zend_Mail_Storage::FLAG_SEEN, Zend_Mail_Storage::FLAG_FLAGGED)), 0);
+        $this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_FLAGGED), 0);
+    }
 }
