@@ -1,27 +1,37 @@
 <?php
-
 /**
+ * Zend Framework
+ *
+ * LICENSE
+ *
+ * This source file is subject to the new BSD license that is bundled
+ * with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://framework.zend.com/license/new-bsd
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@zend.com so we can send you a copy immediately.
+ *
  * @category   Zend
  * @package    Zend_Mail
  * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id: InterfaceTest.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
-
 /**
  * Zend_Mail_Storage_Mbox
  */
 require_once 'Zend/Mail/Storage/Mbox.php';
 
-/**
- * PHPUnit test case
- */
-require_once 'PHPUnit/Framework/TestCase.php';
-
-
 /**
  * @category   Zend
  * @package    Zend_Mail
  * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Mail
  */
 class Zend_Mail_InterfaceTest extends PHPUnit_Framework_TestCase
 {
@@ -37,7 +47,7 @@ class Zend_Mail_InterfaceTest extends PHPUnit_Framework_TestCase
         $list = new Zend_Mail_Storage_Mbox(array('filename' => $this->_mboxFile));
 
         $count = count($list);
-        $this->assertEquals(6, $count);
+        $this->assertEquals(7, $count);
     }
 
     public function testIsset()
@@ -104,7 +114,7 @@ class Zend_Mail_InterfaceTest extends PHPUnit_Framework_TestCase
             ++$count;
         }
 
-        $this->assertEquals(6, $count);
+        $this->assertEquals(7, $count);
     }
 
     public function testIterationWithSeek()
@@ -124,11 +134,11 @@ class Zend_Mail_InterfaceTest extends PHPUnit_Framework_TestCase
         $list = new Zend_Mail_Storage_Mbox(array('filename' => $this->_mboxFile));
 
         $count = 0;
-        foreach (new LimitIterator($list, 3, 6) as $key => $message) {
+        foreach (new LimitIterator($list, 3, 7) as $key => $message) {
             ++$count;
         }
 
-        $this->assertEquals(4, $count);
+        $this->assertEquals(5, $count);
     }
 
     public function testFallback()
