@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Measure
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2006 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: VolumeTest.php 6799 2007-11-09 22:44:42Z thomas $
+ * @version    $Id: VolumeTest.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
 
@@ -28,14 +27,12 @@
 require_once 'Zend/Measure/Volume.php';
 
 /**
- * PHPUnit test case
- */
-require_once 'PHPUnit/Framework/TestCase.php';
-
-
-/**
+ * @category   Zend
  * @package    Zend_Measure
  * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Measure
  */
 class Zend_Measure_VolumeTest extends PHPUnit_Framework_TestCase
 {
@@ -162,7 +159,7 @@ class Zend_Measure_VolumeTest extends PHPUnit_Framework_TestCase
      */
     public function testVolumeValueString()
     {
-        $value = new Zend_Measure_Volume('string -100.100,200',Zend_Measure_Volume::STANDARD,'de');
+        $value = new Zend_Measure_Volume('-100.100,200',Zend_Measure_Volume::STANDARD,'de');
         $this->assertEquals(-100100.200, $value->getValue(),'Zend_Measure_Volume Object not returned');
     }
 
@@ -173,8 +170,8 @@ class Zend_Measure_VolumeTest extends PHPUnit_Framework_TestCase
      */
     public function testVolumeEquality()
     {
-        $value = new Zend_Measure_Volume('string -100.100,200',Zend_Measure_Volume::STANDARD,'de');
-        $newvalue = new Zend_Measure_Volume('otherstring -100.100,200',Zend_Measure_Volume::STANDARD,'de');
+        $value = new Zend_Measure_Volume('-100.100,200',Zend_Measure_Volume::STANDARD,'de');
+        $newvalue = new Zend_Measure_Volume('-100.100,200',Zend_Measure_Volume::STANDARD,'de');
         $this->assertTrue($value->equals($newvalue),'Zend_Measure_Volume Object should be equal');
     }
 
@@ -185,8 +182,8 @@ class Zend_Measure_VolumeTest extends PHPUnit_Framework_TestCase
      */
     public function testVolumeNoEquality()
     {
-        $value = new Zend_Measure_Volume('string -100.100,200',Zend_Measure_Volume::STANDARD,'de');
-        $newvalue = new Zend_Measure_Volume('otherstring -100,200',Zend_Measure_Volume::STANDARD,'de');
+        $value = new Zend_Measure_Volume('-100.100,200',Zend_Measure_Volume::STANDARD,'de');
+        $newvalue = new Zend_Measure_Volume('-100,200',Zend_Measure_Volume::STANDARD,'de');
         $this->assertFalse($value->equals($newvalue),'Zend_Measure_Volume Object should be not equal');
     }
 
@@ -245,8 +242,8 @@ class Zend_Measure_VolumeTest extends PHPUnit_Framework_TestCase
      */
     public function testVolumeSetString()
     {
-        $value = new Zend_Measure_Volume('string -100.100,200',Zend_Measure_Volume::STANDARD,'de');
-        $value->setValue('otherstring -200.200,200',Zend_Measure_Volume::STANDARD,'de');
+        $value = new Zend_Measure_Volume('-100.100,200',Zend_Measure_Volume::STANDARD,'de');
+        $value->setValue('-200.200,200',Zend_Measure_Volume::STANDARD,'de');
         $this->assertEquals(-200200.200, $value->getValue(),'Zend_Measure_Volume Object not returned');
     }
 
@@ -259,7 +256,7 @@ class Zend_Measure_VolumeTest extends PHPUnit_Framework_TestCase
     {
         try {
             $value = new Zend_Measure_Volume('100',Zend_Measure_Volume::STANDARD,'de');
-            $value->setValue('otherstring -200.200,200','Volume::UNKNOWN','de');
+            $value->setValue('-200.200,200','Volume::UNKNOWN','de');
             $this->fail('Exception expected because of unknown type');
         } catch (Zend_Measure_Exception $e) {
             // success
