@@ -15,15 +15,14 @@
  * @category   Zend
  * @package    Zend_Memory
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: AccessControllerTest.php 8468 2008-02-29 17:56:34Z darby $
+ * @version    $Id: AccessControllerTest.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../TestHelper.php';
+if (!defined('PHPUnit_MAIN_METHOD')) {
+    define('PHPUnit_MAIN_METHOD', 'Zend_Memory_AccessControllerTest::main');
+}
 
 /** Zend_Memory */
 require_once 'Zend/Memory.php';
@@ -32,8 +31,9 @@ require_once 'Zend/Memory.php';
  * @category   Zend
  * @package    Zend_Memory
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Memory
  */
 class Zend_Memory_Container_AccessControllerTest extends PHPUnit_Framework_TestCase
 {
@@ -44,6 +44,40 @@ class Zend_Memory_Container_AccessControllerTest extends PHPUnit_Framework_TestC
      */
     private $_memoryManager = null;
 
+    public static function main()
+    {
+        $suite  = new PHPUnit_Framework_TestSuite(__CLASS__);
+        $result = PHPUnit_TextUI_TestRunner::run($suite);
+    }
+
+    public function setUp()
+    {
+        $tmpDir = sys_get_temp_dir() . '/zend_memory';
+        $this->_removeCacheDir($tmpDir);
+        mkdir($tmpDir);
+        $this->cacheDir = $tmpDir;
+    }
+
+    protected function _removeCacheDir($dir)
+    {
+        if (!file_exists($dir)) {
+            return true;
+        }
+
+        if (!is_dir($dir) || is_link($dir)) {
+            return unlink($dir);
+        }
+
+        foreach (scandir($dir) as $item) {
+            if ($item == '.' || $item == '..') {
+                continue;
+            }
+            $this->_removeCacheDir($dir . '/' . $item);
+        }
+
+        return rmdir($dir);
+    }
+
     /**
      * Retrieve memory manager
      *
@@ -51,7 +85,7 @@ class Zend_Memory_Container_AccessControllerTest extends PHPUnit_Framework_TestC
     private function _getMemoryManager()
     {
         if ($this->_memoryManager === null) {
-            $backendOptions = array('cache_dir' => dirname(__FILE__) . '/_files/'); // Directory where to put the cache files
+            $backendOptions = array('cache_dir' => $this->cacheDir); // Directory where to put the cache files
             $this->_memoryManager = Zend_Memory::factory('File', $backendOptions);
         }
 
@@ -121,3 +155,7 @@ class Zend_Memory_Container_AccessControllerTest extends PHPUnit_Framework_TestC
         $this->assertFalse((boolean)$memObject->isLocked());
     }
 }
+
+if (PHPUnit_MAIN_METHOD == 'Zend_Memory_AccessControllerTest::main') {
+    Zend_Memory_AccessControllerTest::main();
+}
