@@ -15,20 +15,15 @@
  * @category   Zend
  * @package    Zend_Memory
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: AllTests.php 8468 2008-02-29 17:56:34Z darby $
+ * @version    $Id: AllTests.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
 if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'Zend_Memory_AllTests::main');
 }
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
 require_once 'Zend/Memory/MemoryTest.php';
 require_once 'Zend/Memory/ValueTest.php';
 require_once 'Zend/Memory/MovableTest.php';
@@ -40,8 +35,9 @@ require_once 'Zend/Memory/MemoryManagerTest.php';
  * @category   Zend
  * @package    Zend_Memory
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Memory
  */
 class Zend_Memory_AllTests
 {
@@ -61,7 +57,6 @@ class Zend_Memory_AllTests
         $suite->addTestSuite('Zend_Memory_Container_AccessControllerTest');
         $suite->addTestSuite('Zend_Memory_MemoryManagerTest');
 
-
         return $suite;
     }
 }
