@@ -15,15 +15,14 @@
  * @category   Zend
  * @package    Zend_Memory
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: MemoryManagerTest.php 8468 2008-02-29 17:56:34Z darby $
+ * @version    $Id: MemoryManagerTest.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../TestHelper.php';
+if (!defined('PHPUnit_MAIN_METHOD')) {
+    define('PHPUnit_MAIN_METHOD', 'Zend_Memory_MemoryManagerTest::main');
+}
 
 /** Zend_Memory */
 require_once 'Zend/Memory.php';
@@ -32,11 +31,45 @@ require_once 'Zend/Memory.php';
  * @category   Zend
  * @package    Zend_Memory
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Memory
  */
 class Zend_Memory_MemoryManagerTest extends PHPUnit_Framework_TestCase
 {
+    public static function main()
+    {
+        $suite  = new PHPUnit_Framework_TestSuite(__CLASS__);
+        $result = PHPUnit_TextUI_TestRunner::run($suite);
+    }
+
+    public function setUp()
+    {
+        $tmpDir = sys_get_temp_dir() . '/zend_memory';
+        $this->_removeCacheDir($tmpDir);
+        mkdir($tmpDir);
+        $this->cacheDir = $tmpDir;
+    }
+
+    protected function _removeCacheDir($dir)
+    {
+        if (!file_exists($dir)) {
+            return true;
+        }
+
+        if (!is_dir($dir) || is_link($dir)) {
+            return unlink($dir);
+        }
+
+        foreach (scandir($dir) as $item) {
+            if ($item == '.' || $item == '..') {
+                continue;
+            }
+            $this->_removeCacheDir($dir . '/' . $item);
+        }
+
+        return rmdir($dir);
+    }
 
     /**
      * tests the Memory Manager creation
@@ -45,19 +78,31 @@ class Zend_Memory_MemoryManagerTest extends PHPUnit_Framework_TestCase
     public function testCreation()
     {
         /** 'File' backend */
-        $backendOptions = array('cache_dir' => dirname(__FILE__) . '/_files/'); // Directory where to put the cache files
+        $backendOptions = array('cache_dir' => $this->cacheDir); // Directory where to put the cache files
         $memoryManager = Zend_Memory::factory('File', $backendOptions);
         $this->assertTrue($memoryManager instanceof Zend_Memory_Manager);
     }
 
 
+    /**
+     * tests the Memory Manager backends naming processing
+     *
+     * @group ZF-9023
+     */
+    public function testBackendNamingProcessing()
+    {
+        /** 'File' backend */
+        $backendOptions = array('cache_dir' => $this->cacheDir); // Directory where to put the cache files
+        $memoryManager = Zend_Memory::factory('fIlE', $backendOptions);
+    }
+
     /**
      * tests the Memory Manager settings
      */
     public function testSettings()
     {
         /** 'File' backend */
-        $backendOptions = array('cache_dir' => dirname(__FILE__) . '/_files/'); // Directory where to put the cache files
+        $backendOptions = array('cache_dir' => $this->cacheDir); // Directory where to put the cache files
         $memoryManager = Zend_Memory::factory('File', $backendOptions);
 
         // MemoryLimit
@@ -77,7 +122,7 @@ class Zend_Memory_MemoryManagerTest extends PHPUnit_Framework_TestCase
     public function testCreate()
     {
         /** 'File' backend */
-        $backendOptions = array('cache_dir' => dirname(__FILE__) . '/_files/'); // Directory where to put the cache files
+        $backendOptions = array('cache_dir' => $this->cacheDir); // Directory where to put the cache files
         $memoryManager = Zend_Memory::factory('File', $backendOptions);
 
         $memObject1 = $memoryManager->create('Value of object 1');
@@ -104,7 +149,7 @@ class Zend_Memory_MemoryManagerTest extends PHPUnit_Framework_TestCase
     public function testProcessing()
     {
         /** 'File' backend */
-        $backendOptions = array('cache_dir' => dirname(__FILE__) . '/_files/'); // Directory where to put the cache files
+        $backendOptions = array('cache_dir' => $this->cacheDir); // Directory where to put the cache files
         $memoryManager = Zend_Memory::factory('File', $backendOptions);
 
         $memoryManager->setMinSize(256);
@@ -144,3 +189,7 @@ class Zend_Memory_MemoryManagerTest extends PHPUnit_Framework_TestCase
         }
     }
 }
+
+if (PHPUnit_MAIN_METHOD == 'Zend_Memory_MemoryManagerTest::main') {
+    Zend_Memory_MemoryManagerTest::main();
+}
