@@ -15,16 +15,11 @@
  * @category   Zend
  * @package    Zend_Memory
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: ValueTest.php 8468 2008-02-29 17:56:34Z darby $
+ * @version    $Id: ValueTest.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
 /** Zend_Memory */
 require_once 'Zend/Memory.php';
 
@@ -32,7 +27,7 @@ require_once 'Zend/Memory.php';
  * @category   Zend
  * @package    Zend_Memory
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_Memory_Container_Movable_Dummy extends Zend_Memory_Container_Movable
@@ -56,8 +51,12 @@ class Zend_Memory_Container_Movable_Dummy extends Zend_Memory_Container_Movable
 
 
 /**
+ * @category   Zend
  * @package    Zend_Memory
  * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Memory
  */
 class Zend_Memory_ValueTest extends PHPUnit_Framework_TestCase
 {
@@ -118,7 +117,11 @@ class Zend_Memory_ValueTest extends PHPUnit_Framework_TestCase
         $valueObject[2] = '_';
         $this->assertEquals((string)$valueObject, '01_3456789');
 
+
+        $error_level = error_reporting();
+        error_reporting($error_level & ~E_NOTICE);
         $valueObject[10] = '_';
         $this->assertEquals((string)$valueObject, '01_3456789_');
+        error_reporting($error_level);
     }
 }
