@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -15,29 +14,17 @@
  *
  * @category   Zend
  * @package    Zend_OpenId
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: OpenIdTest.php 10262 2008-07-21 16:31:27Z matthew $
+ * @version    $Id: OpenIdTest.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
-
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../TestHelper.php';
-
 /**
  * Zend_OpenId
  */
 require_once 'Zend/OpenId.php';
 
-
-/**
- * PHPUnit test case
- */
-require_once 'PHPUnit/Framework.php';
-
-
 /**
  * Zend_OpenId_ResponseHelper
  */
@@ -45,8 +32,12 @@ require_once 'Zend/OpenId/ResponseHelper.php';
 
 
 /**
+ * @category   Zend
  * @package    Zend_OpenId
  * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_OpenId
  */
 class Zend_OpenIdTest extends PHPUnit_Framework_TestCase
 {
@@ -351,7 +342,7 @@ class Zend_OpenIdTest extends PHPUnit_Framework_TestCase
 
         $url = 'http://example.com/test.php?Foo=Bar#Baz';
         $this->assertTrue( Zend_OpenId::normalizeUrl($url) );
-        $this->assertSame( 'http://example.com/test.php?Foo=Bar', $url );
+        $this->assertSame( 'http://example.com/test.php?Foo=Bar#Baz', $url );
     }
 
     /**
@@ -589,42 +580,42 @@ class Zend_OpenIdTest extends PHPUnit_Framework_TestCase
     public function testCreateDhKey()
     {
         try {
-	        $dh = Zend_OpenId::createDhKey(
-	            pack('H*', '0233'),
-	            pack('H*', '05'),
-	            pack('H*', '09'));
-	        $dh_details = Zend_OpenId::getDhKeyDetails($dh);
-	        $this->assertTrue( is_array($dh_details) );
-	        $this->assertSame( 4, count($dh_details));
-	        $this->assertSame( '0233', bin2hex($dh_details['p']) );
-	        $this->assertSame( '05', bin2hex($dh_details['g']) );
-	        $this->assertSame( '09', bin2hex($dh_details['priv_key']) );
-	        $this->assertSame( '4e', bin2hex($dh_details['pub_key']) );
+            $dh = Zend_OpenId::createDhKey(
+                pack('H*', '0233'),
+                pack('H*', '05'),
+                pack('H*', '09'));
+            $dh_details = Zend_OpenId::getDhKeyDetails($dh);
+            $this->assertTrue( is_array($dh_details) );
+            $this->assertSame( 4, count($dh_details));
+            $this->assertSame( '0233', bin2hex($dh_details['p']) );
+            $this->assertSame( '05', bin2hex($dh_details['g']) );
+            $this->assertSame( '09', bin2hex($dh_details['priv_key']) );
+            $this->assertSame( '4e', bin2hex($dh_details['pub_key']) );
 
-	        $dh = Zend_OpenId::createDhKey(
-	            pack('H*', '0233'),
-	            pack('H*', '02'),
-	            pack('H*', '09'));
-	        $dh_details = Zend_OpenId::getDhKeyDetails($dh);
-	        $this->assertTrue( is_array($dh_details) );
-	        $this->assertSame( 4, count($dh_details) );
-	        $this->assertSame( '0233', bin2hex($dh_details['p']) );
-	        $this->assertSame( '02', bin2hex($dh_details['g']) );
-	        $this->assertSame( '09', bin2hex($dh_details['priv_key']) );
-	        $this->assertSame( '0200', bin2hex($dh_details['pub_key']) );
+            $dh = Zend_OpenId::createDhKey(
+                pack('H*', '0233'),
+                pack('H*', '02'),
+                pack('H*', '09'));
+            $dh_details = Zend_OpenId::getDhKeyDetails($dh);
+            $this->assertTrue( is_array($dh_details) );
+            $this->assertSame( 4, count($dh_details) );
+            $this->assertSame( '0233', bin2hex($dh_details['p']) );
+            $this->assertSame( '02', bin2hex($dh_details['g']) );
+            $this->assertSame( '09', bin2hex($dh_details['priv_key']) );
+            $this->assertSame( '0200', bin2hex($dh_details['pub_key']) );
 
-	        $dh = Zend_OpenId::createDhKey(
-	            pack('H*', '0233'),
-	            pack('H*', '02'));
-	        $dh_details = Zend_OpenId::getDhKeyDetails($dh);
-	        $this->assertTrue( is_array($dh_details) );
-	        $this->assertSame( 4, count($dh_details) );
-	        $this->assertSame( '0233', bin2hex($dh_details['p']) );
-	        $this->assertSame( '02', bin2hex($dh_details['g']) );
-	        $this->assertTrue( is_string($dh_details['priv_key']) );
-	        $this->assertTrue( strlen($dh_details['priv_key']) > 0 );
-	        $this->assertTrue( is_string($dh_details['pub_key']) );
-	        $this->assertTrue( strlen($dh_details['pub_key']) > 0 );
+            $dh = Zend_OpenId::createDhKey(
+                pack('H*', '0233'),
+                pack('H*', '02'));
+            $dh_details = Zend_OpenId::getDhKeyDetails($dh);
+            $this->assertTrue( is_array($dh_details) );
+            $this->assertSame( 4, count($dh_details) );
+            $this->assertSame( '0233', bin2hex($dh_details['p']) );
+            $this->assertSame( '02', bin2hex($dh_details['g']) );
+            $this->assertTrue( is_string($dh_details['priv_key']) );
+            $this->assertTrue( strlen($dh_details['priv_key']) > 0 );
+            $this->assertTrue( is_string($dh_details['pub_key']) );
+            $this->assertTrue( strlen($dh_details['pub_key']) > 0 );
         } catch (Zend_OpenId_Exception $e) {
             $this->markTestSkipped($e->getMessage());
         }
@@ -675,4 +666,34 @@ class Zend_OpenIdTest extends PHPUnit_Framework_TestCase
         $this->assertSame( '00fe', bin2hex(Zend_OpenId::btwoc(pack('H*', 'fe'))) );
         $this->assertSame( '00ff', bin2hex(Zend_OpenId::btwoc(pack('H*', 'ff'))) );
     }
+
+    /**
+     * testing setSelfUrl
+     *
+     */
+    public function testSetSelfUrl()
+    {
+        unset($_SERVER['SCRIPT_URI']);
+        unset($_SERVER['HTTPS']);
+        unset($_SERVER['HTTP_HOST']);
+        unset($_SERVER['SERVER_NAME']);
+        unset($_SERVER['SERVER_PORT']);
+        unset($_SERVER['SCRIPT_URL']);
+        unset($_SERVER['REDIRECT_URL']);
+        unset($_SERVER['PHP_SELF']);
+        unset($_SERVER['SCRIPT_NAME']);
+        unset($_SERVER['PATH_INFO']);
+        $_SERVER['SCRIPT_URI'] = "http://www.test.com/";
+
+        $this->assertSame( 'http://www.test.com/', Zend_OpenId::selfUrl() );
+
+        $this->assertSame( null, Zend_OpenId::setSelfUrl("http://localhost/test") );
+        $this->assertSame( "http://localhost/test", Zend_OpenId::selfUrl() );
+
+        $this->assertSame( "http://localhost/test", Zend_OpenId::setSelfUrl() );
+        $this->assertSame( 'http://www.test.com/', Zend_OpenId::selfUrl() );
+
+        $this->assertSame( null, Zend_OpenId::setSelfUrl() );
+        $this->assertSame( 'http://www.test.com/', Zend_OpenId::selfUrl() );
+    }
 }
