@@ -15,16 +15,11 @@
  * @category   Zend
  * @package    Zend_Registry
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: RegistryTest.php 9007 2008-03-22 23:19:56Z alexander $
+ * @version    $Id: RegistryTest.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../TestHelper.php';
-
 /**
  * @see Zend_Registry
  */
@@ -34,8 +29,9 @@ require_once 'Zend/Registry.php';
  * @category   Zend
  * @package    Zend_Registry
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Registry
  */
 class Zend_RegistryTest extends PHPUnit_Framework_TestCase
 {
@@ -205,4 +201,10 @@ class Zend_RegistryTest extends PHPUnit_Framework_TestCase
         }
     }
 
-}
\ No newline at end of file
+    public function testDefaultRegistryArrayAsPropsZF4654()
+    {
+        $registry = Zend_Registry::getInstance();
+        $registry->bar = "baz";
+        $this->assertEquals('baz', Zend_Registry::get('bar'));
+    }
+}
