@@ -1,7 +1,23 @@
 <?php
 /**
- * @package Zend_Rest
+ * Zend Framework
+ *
+ * LICENSE
+ *
+ * This source file is subject to the new BSD license that is bundled
+ * with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://framework.zend.com/license/new-bsd
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@zend.com so we can send you a copy immediately.
+ *
+ * @category   Zend
+ * @package    Zend_Rest
  * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id: ServerTest.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
 // Call Zend_Rest_ServerTest::main() if this source file is executed directly.
@@ -9,8 +25,6 @@ if (!defined("PHPUnit_MAIN_METHOD")) {
     define("PHPUnit_MAIN_METHOD", "Zend_Rest_ServerTest::main");
 }
 
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
 /**
  * Zend_Rest_Server
  */
@@ -19,8 +33,13 @@ require_once 'Zend/Rest/Server.php';
 /**
  * Test cases for Zend_Rest_Server
  *
- * @package Zend_Rest
+ * @category   Zend
+ * @package    Zend_Rest
  * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Rest
+ * @group      Zend_Rest_Server
  */
 class Zend_Rest_ServerTest extends PHPUnit_Framework_TestCase
 {
@@ -31,7 +50,6 @@ class Zend_Rest_ServerTest extends PHPUnit_Framework_TestCase
      */
     public static function main()
     {
-        require_once "PHPUnit/TextUI/TestRunner.php";
 
         $suite  = new PHPUnit_Framework_TestSuite("Zend_Rest_ServerTest");
         $result = PHPUnit_TextUI_TestRunner::run($suite);
@@ -93,18 +111,18 @@ class Zend_Rest_ServerTest extends PHPUnit_Framework_TestCase
         $this->assertContains('failed', $result);
     }
 
-  	public function testHandleFunctionNoArgsUsingRequest()
-	{
+      public function testHandleFunctionNoArgsUsingRequest()
+    {
         $_REQUEST = array(
             'method' => 'Zend_Rest_Server_TestFunc2'
         );
-		$server = new Zend_Rest_Server();
-		$server->addFunction('Zend_Rest_Server_TestFunc2');
-		ob_start();
-		$server->handle();
-		$result = ob_get_clean();
-		$this->assertContains('<Zend_Rest_Server_TestFunc2 generator="zend" version="1.0"><response>Hello World</response><status>success</status></Zend_Rest_Server_TestFunc2>', $result, "Bad Result");
-	}
+        $server = new Zend_Rest_Server();
+        $server->addFunction('Zend_Rest_Server_TestFunc2');
+        ob_start();
+        $server->handle();
+        $result = ob_get_clean();
+        $this->assertContains('<Zend_Rest_Server_TestFunc2 generator="zend" version="1.0"><response>Hello World</response><status>success</status></Zend_Rest_Server_TestFunc2>', $result, "Bad Result");
+    }
 
     public function testHandleAnonymousArgFunction()
     {
@@ -330,6 +348,9 @@ class Zend_Rest_ServerTest extends PHPUnit_Framework_TestCase
         $this->assertContains("<foo>bar</foo>", $result, "Bad Result");
     }
 
+    /**
+     * @group ZF-3751
+     */
     public function testHandleInvalidMethod()
     {
         $server = new Zend_Rest_Server();
@@ -337,6 +358,7 @@ class Zend_Rest_ServerTest extends PHPUnit_Framework_TestCase
         $server->returnResponse(true);
         $response = $server->handle(array('method' => 'test3DomElement'));
         $this->assertContains('<status>failed</status>', $response);
+        $this->assertNotContains('<message>An unknown error occured. Please try again.</message>', $response);
     }
 
     public function testFault()
@@ -464,6 +486,7 @@ class Zend_Rest_ServerTest extends PHPUnit_Framework_TestCase
 
     /**
      * @see ZF-1992
+     * @group ZF-1992
      */
     public function testDefaultEncodingShouldBeUtf8()
     {
@@ -473,6 +496,7 @@ class Zend_Rest_ServerTest extends PHPUnit_Framework_TestCase
 
     /**
      * @see ZF-1992
+     * @group ZF-1992
      */
     public function testEncodingShouldBeMutableViaAccessors()
     {
@@ -484,6 +508,7 @@ class Zend_Rest_ServerTest extends PHPUnit_Framework_TestCase
 
     /**
      * @see ZF-2279
+     * @group ZF-2279
      */
     public function testNamesOfArgumentsShouldDetermineArgumentOrder()
     {
@@ -497,20 +522,24 @@ class Zend_Rest_ServerTest extends PHPUnit_Framework_TestCase
 
     /**
      * @see ZF-1949
+     * @see ZF-7977
+     * @group ZF-1949
+     * @group ZF-7977
      */
     public function testMissingArgumentsShouldResultInFaultResponse()
     {
         $server = new Zend_Rest_Server();
         $server->setClass('Zend_Rest_Server_Test');
         ob_start();
-        $server->handle(array('method' => 'testFunc6', 'arg1' => "Davey"));
+        $server->handle(array('method' => 'testFunc6', 'arg1' => 'Davey'));
         $result = ob_get_clean();
-        $this->assertRegexp('#<message>Invalid Method Call to(.*?)(Requires).*?(given).*?(</message>)#', $result);
+        $this->assertRegexp('#<message>Invalid Method Call to(.*?)(Missing argument\(s\): ).*?(</message>)#', $result);
         $this->assertContains('<status>failed</status>', $result);
     }
 
     /**
      * @see ZF-1949
+     * @group ZF-1949
      */
     public function testMissingArgumentsWithDefaultsShouldNotResultInFaultResponse()
     {
@@ -522,6 +551,32 @@ class Zend_Rest_ServerTest extends PHPUnit_Framework_TestCase
         $this->assertContains('<status>success</status>', $result, var_export($result, 1));
         $this->assertContains('<response>Hello today, How are you Davey</response>', $result, var_export($result, 1));
     }
+
+    /**
+     * @group ZF-3751
+     */
+    public function testCallingUnknownMethodDoesNotThrowUnknownButSpecificErrorExceptionMessage()
+    {
+        $server = new Zend_Rest_Server();
+        $server->setClass('Zend_Rest_Server_Test2');
+        $server->returnResponse(true);
+        $response = $server->handle(array('method' => 'testCallingInvalidMethod'));
+        $this->assertContains('<status>failed</status>', $response);
+        $this->assertNotContains('<message>An unknown error occured. Please try again.</message>', $response);
+    }
+
+    /**
+     * @group ZF-3751
+     */
+    public function testCallingNoMethodDoesNotThrowUnknownButSpecificErrorExceptionMessage()
+    {
+        $server = new Zend_Rest_Server();
+        $server->setClass('Zend_Rest_Server_Test2');
+        $server->returnResponse(true);
+        $response = $server->handle();
+        $this->assertContains('<status>failed</status>', $response);
+        $this->assertNotContains('<message>An unknown error occured. Please try again.</message>', $response);
+    }
 }
 
 /* Test Functions */
