@@ -1,11 +1,25 @@
 <?php
 /**
+ * Zend Framework
+ *
+ * LICENSE
+ *
+ * This source file is subject to the new BSD license that is bundled
+ * with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://framework.zend.com/license/new-bsd
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@zend.com so we can send you a copy immediately.
+ *
  * @category   Zend
  * @package    Zend_Search_Lucene
  * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id: SegmentMergerTest.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
-
 /**
  * Zend_Search_Lucene_Storage_Directory_Filesystem
  */
@@ -22,16 +36,13 @@ require_once 'Zend/Search/Lucene/Index/SegmentInfo.php';
  */
 require_once 'Zend/Search/Lucene/Index/SegmentMerger.php';
 
-/**
- * PHPUnit test case
- */
-require_once 'PHPUnit/Framework/TestCase.php';
-
-
 /**
  * @category   Zend
  * @package    Zend_Search_Lucene
  * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Search_Lucene
  */
 class Zend_Search_Lucene_Index_SegmentMergerTest extends PHPUnit_Framework_TestCase
 {
