@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,93 +15,40 @@
  * @category   Zend
  * @package    Zend_Service
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: AllTests.php 10743 2008-08-07 02:24:43Z matthew $
+ * @version    $Id: AllTests.php 24838 2012-05-31 11:37:11Z adamlundrigan $
  */
 
-
 if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'Zend_Service_AllTests::main');
 }
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
-/**
- * Exclude from code coverage report
- */
-PHPUnit_Util_Filter::addFileToFilter(__FILE__);
-
-/**
- * @see Zend_Service_AkismetTest
- */
 require_once 'Zend/Service/AkismetTest.php';
-
-/**
- * @see Zend_Service_Amazon_AllTests
- */
 require_once 'Zend/Service/Amazon/AllTests.php';
-
-/**
- * @see Zend_Service_Audioscrobbler_AllTests
- */
 require_once 'Zend/Service/Audioscrobbler/AllTests.php';
-
-/**
- * @see Zend_Service_Delicious_AllTests
- */
 require_once 'Zend/Service/Delicious/AllTests.php';
-
-/**
- * @see Zend_Service_Flickr_AllTests
- */
+require_once 'Zend/Service/DeveloperGarden/AllTests.php';
+require_once 'Zend/Service/Ebay/AllTests.php';
 require_once 'Zend/Service/Flickr/AllTests.php';
-
-/**
- * @see Zend_Service_Nirvanix_AllTests
- */
+require_once 'Zend/Service/LiveDocx/AllTests.php';
 require_once 'Zend/Service/Nirvanix/AllTests.php';
-
-/**
- * @see Zend_Service_ReCaptcha_AllTests
- */
 require_once 'Zend/Service/ReCaptcha/AllTests.php';
-
-/**
- * @see Zend_Service_SimpyTest
- */
-require_once 'Zend/Service/SimpyTest.php';
-
-/**
- * @see Zend_Service_SlideShareTest
- */
+require_once 'Zend/Service/ShortUrl/AllTests.php';
 require_once 'Zend/Service/SlideShareTest.php';
-
-/**
- * @see Zend_Service_StrikeIron_AllTests
- */
 require_once 'Zend/Service/StrikeIron/AllTests.php';
-
-/**
- * @see Zend_Service_Technorati_AllTests
- */
 require_once 'Zend/Service/Technorati/AllTests.php';
-
-/**
- * @see Zend_Service_Yahoo_AllTests
- */
+require_once 'Zend/Service/Twitter/AllTests.php';
+require_once 'Zend/Service/WindowsAzure/AllTests.php';
 require_once 'Zend/Service/Yahoo/AllTests.php';
 
-
 /**
  * @category   Zend
  * @package    Zend_Service
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Service
  */
 class Zend_Service_AllTests
 {
@@ -129,17 +75,18 @@ class Zend_Service_AllTests
         $suite->addTest(Zend_Service_Amazon_AllTests::suite());
         $suite->addTest(Zend_Service_Audioscrobbler_AllTests::suite());
         $suite->addTest(Zend_Service_Delicious_AllTests::suite());
+        $suite->addTest(Zend_Service_DeveloperGarden_AllTests::suite());
+        $suite->addTest(Zend_Service_Ebay_AllTests::suite());
         $suite->addTest(Zend_Service_Flickr_AllTests::suite());
+        $suite->addTest(Zend_Service_LiveDocx_AllTests::suite());
         $suite->addTest(Zend_Service_Nirvanix_AllTests::suite());
         $suite->addTest(Zend_Service_ReCaptcha_AllTests::suite());
-        if (defined('TESTS_ZEND_SERVICE_SIMPY_ENABLED') && constant('TESTS_ZEND_SERVICE_SIMPY_ENABLED')) {
-            $suite->addTestSuite('Zend_Service_SimpyTest');
-        } else {
-            $suite->addTestSuite('Zend_Service_SimpyTest_Skip');
-        }
+        $suite->addTest(Zend_Service_ShortUrl_AllTests::suite());
         $suite->addTestSuite('Zend_Service_SlideShareTest');
         $suite->addTest(Zend_Service_StrikeIron_AllTests::suite());
         $suite->addTest(Zend_Service_Technorati_AllTests::suite());
+        $suite->addTest(Zend_Service_Twitter_AllTests::suite());
+        $suite->addTest(Zend_Service_WindowsAzure_AllTests::suite());
         $suite->addTest(Zend_Service_Yahoo_AllTests::suite());
 
         return $suite;
