@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,17 +15,11 @@
  * @category   Zend
  * @package    Zend_Service_Flickr
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: OfflineTest.php 8733 2008-03-10 15:56:48Z jokke $
+ * @version    $Id: OfflineTest.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
-
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../../TestHelper.php';
-
 /**
  * @see Zend_Service_Flickr
  */
@@ -37,8 +30,10 @@ require_once 'Zend/Service/Flickr.php';
  * @category   Zend
  * @package    Zend_Service_Flickr
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Service
+ * @group      Zend_Service_Flickr
  */
 class Zend_Service_Flickr_OfflineTest extends PHPUnit_Framework_TestCase
 {
@@ -351,7 +346,7 @@ class Zend_Service_Flickr_OfflineTest extends PHPUnit_Framework_TestCase
             $this->assertContains('parameters are invalid', $e->getMessage());
         }
     }
-    
+
     /**
      * Basic testing to ensure that groupPoolGetPhotos() works as expected
      *
@@ -503,7 +498,7 @@ class Zend_Service_Flickr_OfflineTest extends PHPUnit_Framework_TestCase
             $this->assertContains('supply a group id', $e->getMessage());
         }
     }
-     
+
     /**
      * Ensures that groupPoolGetPhotos() throws an exception when an array is given for group_id
      *
@@ -555,7 +550,7 @@ class Zend_Service_Flickr_OfflineTest_FlickrProtectedMethodProxy extends Zend_Se
     {
         $this->_validateTagSearch($options);
     }
-    
+
     public function proxyValidateGroupPoolGetPhotos(array $options)
     {
         $this->_validateGroupPoolGetPhotos($options);
@@ -565,4 +560,4 @@ class Zend_Service_Flickr_OfflineTest_FlickrProtectedMethodProxy extends Zend_Se
     {
         $this->_compareOptions($options, $validOptions);
     }
-}
\ No newline at end of file
+}
