@@ -13,19 +13,13 @@
  * to license@zend.com so we can send you a copy immediately.
  *
  * @category   Zend
- * @package    Zend_Service
+ * @package    Zend_Service_StrikeIron
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: ExceptionTest.php 8064 2008-02-16 10:58:39Z thomas $
+ * @version    $Id: ExceptionTest.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
-
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../../TestHelper.php';
-
 /**
  * @see Zend_Service_StrikeIron_Exception
  */
@@ -34,16 +28,18 @@ require_once 'Zend/Service/StrikeIron/Exception.php';
 
 /**
  * @category   Zend
- * @package    Zend_Service
+ * @package    Zend_Service_StrikeIron
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Service
+ * @group      Zend_Service_StrikeIron
  */
-class Zend_Service_StrikeIron_ExceptionTest extends PHPUnit_Framework_TestCase 
+class Zend_Service_StrikeIron_ExceptionTest extends PHPUnit_Framework_TestCase
 {
     public function testInheritsFromZendException()
     {
         $exception = new Zend_Service_StrikeIron_Exception();
         $this->assertType('Zend_Exception', $exception);
     }
-}
\ No newline at end of file
+}
