@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,43 +15,26 @@
  * @category   Zend
  * @package    Zend_Service_Yahoo
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: AllTests.php 8064 2008-02-16 10:58:39Z thomas $
+ * @version    $Id: AllTests.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
-
 if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'Zend_Service_Yahoo_AllTests::main');
 }
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../../TestHelper.php';
-
-/**
- * Exclude from code coverage report
- */
-PHPUnit_Util_Filter::addFileToFilter(__FILE__);
-
-/**
- * @see Zend_Service_Yahoo_OfflineTest
- */
 require_once 'Zend/Service/Yahoo/OfflineTest.php';
-
-/**
- * @see Zend_Service_Yahoo_OnlineTest
- */
 require_once 'Zend/Service/Yahoo/OnlineTest.php';
 
-
 /**
  * @category   Zend
  * @package    Zend_Service_Yahoo
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Service
+ * @group      Zend_Service_Yahoo
  */
 class Zend_Service_Yahoo_AllTests
 {
