@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,17 +15,11 @@
  * @category   Zend
  * @package    Zend_Service_Yahoo
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: OfflineTest.php 8064 2008-02-16 10:58:39Z thomas $
+ * @version    $Id: OfflineTest.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
-
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../../TestHelper.php';
-
 /**
  * @see Zend_Service_Yahoo
  */
@@ -47,13 +40,19 @@ require_once 'Zend/Http/Client/Adapter/Socket.php';
  */
 require_once 'Zend/Http/Client/Adapter/Test.php';
 
+/**
+ * @see Zend_Service_Yahoo_WebResult
+ */
+require_once 'Zend/Service/Yahoo/WebResult.php';
 
 /**
  * @category   Zend
  * @package    Zend_Service_Yahoo
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Service
+ * @group      Zend_Service_Yahoo
  */
 class Zend_Service_Yahoo_OfflineTest extends PHPUnit_Framework_TestCase
 {
@@ -531,6 +530,19 @@ class Zend_Service_Yahoo_OfflineTest extends PHPUnit_Framework_TestCase
             $this->assertContains("option 'type'", $e->getMessage());
         }
     }
+
+    /**
+     * WebResult should check if the result has a Cache section or not
+     *
+     * @group ZF-3636
+     */
+    public function testWebResultCache(){
+        // create empty result eg. without cache section
+        $domDoc = new DOMDocument();
+        $element = $domDoc->createElement('Result');
+        // this should not result in errors
+        $webResult = new Zend_Service_Yahoo_WebResult($element);
+    }
 }
 
 
