@@ -13,32 +13,29 @@
  * to license@zend.com so we can send you a copy immediately.
  *
  * @category   Zend
- * @package    Zend_Session_SaveHandler
+ * @package    Zend_Session
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: DbTableTest.php 10116 2008-07-16 02:34:10Z matthew $
+ * @version    $Id: DbTableTest.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../../TestHelper.php';
-
 /**
  * @see Zend_Session_SaveHandler_DbTable
  */
 require_once 'Zend/Session/SaveHandler/DbTable.php';
 
 /**
- * Unit testing for Zend_Session_SaveHandler_DbTable include all tests for regular session handling
+ * Unit testing for Zend_Session_SaveHandler_DbTable include all tests for
+ * regular session handling
  *
  * @category   Zend
  * @package    Zend_Session
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @see        http://en.wikipedia.org/wiki/Black_box_testing
+ * @group      Zend_Session
+ * @group      Zend_Db_Table
  */
 class Zend_Session_SaveHandler_DbTableTest extends PHPUnit_Framework_TestCase
 {
@@ -67,6 +64,14 @@ class Zend_Session_SaveHandler_DbTableTest extends PHPUnit_Framework_TestCase
      */
     protected $_db;
 
+    /**
+     * Array to collect used Zend_Session_SaveHandler_DbTable objects, so they are not
+     * destroyed before all tests are done and session is not closed
+     *
+     * @var array
+     */
+    protected $_usedSaveHandlers = array();
+
     /**
      * Setup performed prior to each test method
      *
@@ -84,12 +89,15 @@ class Zend_Session_SaveHandler_DbTableTest extends PHPUnit_Framework_TestCase
      */
     public function tearDown()
     {
-        $this->_dropTable();
+        if ($this->_db instanceof Zend_Db_Adapter_Abstract) {
+            $this->_dropTable();
+        }
     }
 
     public function testConfigPrimaryAssignmentFullConfig()
     {
-        $saveHandler = new Zend_Session_SaveHandler_DbTable($this->_saveHandlerTableConfig);
+        $this->_usedSaveHandlers[] =
+            $saveHandler = new Zend_Session_SaveHandler_DbTable($this->_saveHandlerTableConfig);
         /**
          * @todo Test something other than that an exception is not thrown
          */
@@ -98,7 +106,8 @@ class Zend_Session_SaveHandler_DbTableTest extends PHPUnit_Framework_TestCase
     public function testConstructorThrowsExceptionGivenConfigAsNull()
     {
         try {
-            $saveHandler = new Zend_Session_SaveHandler_DbTable(null);
+            $this->_usedSaveHandlers[] =
+                $saveHandler = new Zend_Session_SaveHandler_DbTable(null);
             $this->fail('Expected Zend_Session_SaveHandler_Exception not thrown');
         } catch (Zend_Session_SaveHandler_Exception $e) {
             $this->assertContains('$config must be', $e->getMessage());
@@ -107,11 +116,10 @@ class Zend_Session_SaveHandler_DbTableTest extends PHPUnit_Framework_TestCase
 
     public function testTableNameSchema()
     {
-        //this is thrown AFTER what we want to test...
-        $this->setExpectedException('Zend_Db_Statement_Exception');
         $config = $this->_saveHandlerTableConfig;
         $config['name'] = 'schema.session';
-        $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
+        $this->_usedSaveHandlers[] =
+            $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
     }
 
     public function testTableEmptyNamePullFromSavePath()
@@ -121,7 +129,8 @@ class Zend_Session_SaveHandler_DbTableTest extends PHPUnit_Framework_TestCase
         try {
             $savePath = ini_get('session.save_path');
             ini_set('session.save_path', dirname(__FILE__));
-            $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
+            $this->_usedSaveHandlers[] =
+                $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
             $this->fail();
         } catch (Zend_Session_SaveHandler_Exception $e) {
             ini_set('session.save_path', $savePath);
@@ -138,7 +147,8 @@ class Zend_Session_SaveHandler_DbTableTest extends PHPUnit_Framework_TestCase
         $config['primary'] = array('id');
         $config[Zend_Session_SaveHandler_DbTable::PRIMARY_ASSIGNMENT]
             = Zend_Session_SaveHandler_DbTable::PRIMARY_ASSIGNMENT_SESSION_SAVE_PATH;
-        $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
+        $this->_usedSaveHandlers[] =
+            $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
         /**
          * @todo Test something other than that an exception is thrown
          */
@@ -150,7 +160,8 @@ class Zend_Session_SaveHandler_DbTableTest extends PHPUnit_Framework_TestCase
         $config['primary'] = array('id');
         $config[Zend_Session_SaveHandler_DbTable::PRIMARY_ASSIGNMENT]
             = Zend_Session_SaveHandler_DbTable::PRIMARY_ASSIGNMENT_SESSION_ID;
-        $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
+        $this->_usedSaveHandlers[] =
+            $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
         /**
          * @todo Test something other than that an exception is not thrown
          */
@@ -161,7 +172,8 @@ class Zend_Session_SaveHandler_DbTableTest extends PHPUnit_Framework_TestCase
         $this->setExpectedException('Zend_Session_SaveHandler_Exception');
         $config = $this->_saveHandlerTableConfig;
         unset($config[Zend_Session_SaveHandler_DbTable::MODIFIED_COLUMN]);
-        $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
+        $this->_usedSaveHandlers[] =
+            $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
         /**
          * @todo Test something other than that an exception is thrown
          */
@@ -172,7 +184,8 @@ class Zend_Session_SaveHandler_DbTableTest extends PHPUnit_Framework_TestCase
         $this->setExpectedException('Zend_Session_SaveHandler_Exception');
         $config = $this->_saveHandlerTableConfig;
         unset($config[Zend_Session_SaveHandler_DbTable::LIFETIME_COLUMN]);
-        $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
+        $this->_usedSaveHandlers[] =
+            $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
         /**
          * @todo Test something other than that an exception is thrown
          */
@@ -183,7 +196,8 @@ class Zend_Session_SaveHandler_DbTableTest extends PHPUnit_Framework_TestCase
         $this->setExpectedException('Zend_Session_SaveHandler_Exception');
         $config = $this->_saveHandlerTableConfig;
         unset($config[Zend_Session_SaveHandler_DbTable::DATA_COLUMN]);
-        $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
+        $this->_usedSaveHandlers[] =
+            $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
         /**
          * @todo Test something other than that an exception is thrown
          */
@@ -195,7 +209,8 @@ class Zend_Session_SaveHandler_DbTableTest extends PHPUnit_Framework_TestCase
         try {
             $config = $this->_saveHandlerTableConfig;
             array_pop($config[Zend_Session_SaveHandler_DbTable::PRIMARY_ASSIGNMENT]);
-            $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
+            $this->_usedSaveHandlers[] =
+                $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
             $this->fail();
         } catch (Zend_Session_SaveHandler_Exception $e) {
             /**
@@ -210,7 +225,8 @@ class Zend_Session_SaveHandler_DbTableTest extends PHPUnit_Framework_TestCase
         $config = $this->_saveHandlerTableConfig;
         unset($config[Zend_Session_SaveHandler_DbTable::PRIMARY_ASSIGNMENT]);
         $config['primary'] = $config['primary'][0];
-        $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
+        $this->_usedSaveHandlers[] =
+            $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
         /**
          * @todo Test something other than that an exception is not thrown
          */
@@ -224,7 +240,8 @@ class Zend_Session_SaveHandler_DbTableTest extends PHPUnit_Framework_TestCase
             $config[Zend_Session_SaveHandler_DbTable::PRIMARY_ASSIGNMENT] = array(
                 Zend_Session_SaveHandler_DbTable::PRIMARY_ASSIGNMENT_SESSION_NAME,
             );
-            $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
+            $this->_usedSaveHandlers[] =
+                $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
             $this->fail();
         } catch (Zend_Session_SaveHandler_Exception $e) {
             /**
@@ -240,7 +257,8 @@ class Zend_Session_SaveHandler_DbTableTest extends PHPUnit_Framework_TestCase
             $config = $this->_saveHandlerTableConfig;
             unset($config[Zend_Session_SaveHandler_DbTable::PRIMARY_ASSIGNMENT]);
             unset($config[Zend_Session_SaveHandler_DbTable::MODIFIED_COLUMN]);
-            $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
+            $this->_usedSaveHandlers[] =
+                $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
             $this->fail();
         } catch (Zend_Session_SaveHandler_Exception $e) {
             /**
@@ -256,7 +274,8 @@ class Zend_Session_SaveHandler_DbTableTest extends PHPUnit_Framework_TestCase
             $config = $this->_saveHandlerTableConfig;
             unset($config[Zend_Session_SaveHandler_DbTable::PRIMARY_ASSIGNMENT]);
             unset($config[Zend_Session_SaveHandler_DbTable::LIFETIME_COLUMN]);
-            $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
+            $this->_usedSaveHandlers[] =
+                $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
             $this->fail();
         } catch (Zend_Session_SaveHandler_Exception $e) {
             /**
@@ -272,7 +291,8 @@ class Zend_Session_SaveHandler_DbTableTest extends PHPUnit_Framework_TestCase
             $config = $this->_saveHandlerTableConfig;
             unset($config[Zend_Session_SaveHandler_DbTable::PRIMARY_ASSIGNMENT]);
             unset($config[Zend_Session_SaveHandler_DbTable::DATA_COLUMN]);
-            $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
+            $this->_usedSaveHandlers[] =
+                $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
             $this->fail();
         } catch (Zend_Session_SaveHandler_Exception $e) {
             /**
@@ -285,14 +305,16 @@ class Zend_Session_SaveHandler_DbTableTest extends PHPUnit_Framework_TestCase
     {
         $config = $this->_saveHandlerTableConfig;
         unset($config['lifetime']);
-        $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
+        $this->_usedSaveHandlers[] =
+            $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
         $this->assertSame($saveHandler->getLifetime(), (int) ini_get('session.gc_maxlifetime'),
             'lifetime must default to session.gc_maxlifetime'
         );
 
         $config = $this->_saveHandlerTableConfig;
         $lifetime = $config['lifetime'] = 1242;
-        $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
+        $this->_usedSaveHandlers[] =
+            $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
         $this->assertSame($lifetime, $saveHandler->getLifetime());
     }
 
@@ -301,7 +323,8 @@ class Zend_Session_SaveHandler_DbTableTest extends PHPUnit_Framework_TestCase
         try {
             $config = $this->_saveHandlerTableConfig;
             $config['overrideLifetime'] = true;
-            $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
+            $this->_usedSaveHandlers[] =
+                $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
         } catch (Zend_Session_SaveHandler_Exception $e) {
             /**
              * @todo Test something other than that an exception is thrown
@@ -321,7 +344,8 @@ class Zend_Session_SaveHandler_DbTableTest extends PHPUnit_Framework_TestCase
 
         $this->_setupDb($config['primary']);
 
-        $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
+        $this->_usedSaveHandlers[] =
+            $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
         Zend_Session::setSaveHandler($saveHandler);
         Zend_Session::start();
 
@@ -354,7 +378,8 @@ class Zend_Session_SaveHandler_DbTableTest extends PHPUnit_Framework_TestCase
         unset($config[Zend_Session_SaveHandler_DbTable::PRIMARY_ASSIGNMENT]);
         $config['primary'] = array($config['primary'][0]);
         $this->_setupDb($config['primary']);
-        $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
+        $this->_usedSaveHandlers[] =
+            $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
 
         $id = '242';
 
@@ -367,7 +392,8 @@ class Zend_Session_SaveHandler_DbTableTest extends PHPUnit_Framework_TestCase
     {
         $config = $this->_saveHandlerTableConfig;
         $this->_setupDb($config['primary']);
-        $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
+        $this->_usedSaveHandlers[] =
+            $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
         $saveHandler->open('savepath', 'sessionname');
 
         $id = '242';
@@ -383,7 +409,8 @@ class Zend_Session_SaveHandler_DbTableTest extends PHPUnit_Framework_TestCase
         unset($config[Zend_Session_SaveHandler_DbTable::PRIMARY_ASSIGNMENT]);
         $config['primary'] = array($config['primary'][0]);
         $this->_setupDb($config['primary']);
-        $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
+        $this->_usedSaveHandlers[] =
+            $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
 
         $id = '242';
 
@@ -404,7 +431,8 @@ class Zend_Session_SaveHandler_DbTableTest extends PHPUnit_Framework_TestCase
         $config['lifetime'] = 1;
 
         $this->_setupDb($config['primary']);
-        $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
+        $this->_usedSaveHandlers[] =
+            $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
 
         $id = '242';
 
@@ -427,7 +455,8 @@ class Zend_Session_SaveHandler_DbTableTest extends PHPUnit_Framework_TestCase
         $config['lifetime'] = 1;
 
         $this->_setupDb($config['primary']);
-        $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
+        $this->_usedSaveHandlers[] =
+            $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
 
         $id = 242;
 
@@ -467,7 +496,8 @@ class Zend_Session_SaveHandler_DbTableTest extends PHPUnit_Framework_TestCase
         $config['lifetime'] = 1;
 
         $this->_setupDb($config['primary']);
-        $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
+        $this->_usedSaveHandlers[] =
+            $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
         $this->assertSame(1, $saveHandler->getLifetime());
 
         $saveHandler->setLifetime(27);
@@ -477,25 +507,113 @@ class Zend_Session_SaveHandler_DbTableTest extends PHPUnit_Framework_TestCase
 
     public function testZendConfig()
     {
-        $saveHandler = new Zend_Session_SaveHandler_DbTable(new Zend_Config($this->_saveHandlerTableConfig));
+        $this->_usedSaveHandlers[] =
+            $saveHandler = new Zend_Session_SaveHandler_DbTable(new Zend_Config($this->_saveHandlerTableConfig));
         /**
          * @todo Test something other than that an exception is not thrown
          */
     }
 
+    /**
+     * @group 9294
+     */
+    public function testDestroyWithAutoQuoteIdentifiersEnabledAndDisabled()
+    {
+        $id       = uniqid();
+        $config   = $this->_saveHandlerTableConfig;
+        $configDb = array(
+            'options' => array(
+                'autoQuoteIdentifiers' => false,
+            ),
+            'profiler' => true
+        );
+        $this->_setupDb($config['primary'], $configDb);
+        $config['db'] = $this->_db;
+
+        $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
+        $saveHandler->destroy($id);
+        $lastQuery = $this->_db
+                          ->getProfiler()
+                          ->getLastQueryProfile()
+                          ->getQuery();
+        $partQueryExpected = "WHERE (id = '$id') AND (save_path = '') AND (name = '')";
+        $this->assertContains($partQueryExpected, $lastQuery);
+
+        $configDb = array(
+            'options' => array(
+                'autoQuoteIdentifiers' => true,
+            ),
+            'profiler' => true
+        );
+        $this->_setupDb($config['primary'], $configDb);
+        $config['db'] = $this->_db;
+
+        $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
+        $saveHandler->destroy($id);
+        $lastQuery = $this->_db
+                          ->getProfiler()
+                          ->getLastQueryProfile()
+                          ->getQuery();
+        $partQueryExpected = "WHERE (\"id\" = '$id') AND (\"save_path\" = '') AND (\"name\" = '')";
+        $this->assertContains($partQueryExpected, $lastQuery);
+    }
+
+    /**
+     * @group 9294
+     */
+    public function testGcWithAutoQuoteIdentifiersEnabledAndDisabled()
+    {
+        $config = $this->_saveHandlerTableConfig;
+        $configDb = array(
+            'options' => array(
+                'autoQuoteIdentifiers' => false,
+            ),
+            'profiler' => true
+        );
+        $this->_setupDb($config['primary'], $configDb);
+        $config['db'] = $this->_db;
+
+        $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
+        $saveHandler->gc(false);
+        $lastQuery = $this->_db
+                          ->getProfiler()
+                          ->getLastQueryProfile()
+                          ->getQuery();
+        $partQueryExpected = "WHERE (modified + lifetime < ";
+        $this->assertContains($partQueryExpected, $lastQuery);
+
+        $configDb = array(
+            'options' => array(
+                'autoQuoteIdentifiers' => true,
+            ),
+            'profiler' => true
+        );
+        $this->_setupDb($config['primary'], $configDb);
+        $config['db'] = $this->_db;
+
+        $saveHandler = new Zend_Session_SaveHandler_DbTable($config);
+        $saveHandler->gc(false);
+        $lastQuery = $this->_db
+                          ->getProfiler()
+                          ->getLastQueryProfile()
+                          ->getQuery();
+        $partQueryExpected = "WHERE (\"modified\" + \"lifetime\" < ";
+        $this->assertContains($partQueryExpected, $lastQuery);
+    }
+
     /**
      * Sets up the database connection and creates the table for session data
      *
      * @param  array $primary
      * @return void
      */
-    protected function _setupDb(array $primary)
+    protected function _setupDb(array $primary, array $config = array())
     {
         if (!extension_loaded('pdo_sqlite')) {
             $this->markTestSkipped('The pdo_sqlite extension must be available and enabled for this test');
         }
 
-        $this->_db = Zend_Db::factory('Pdo_Sqlite', array('dbname' => ':memory:'));
+        $this->_db = Zend_Db::factory('Pdo_Sqlite', array('dbname' => ':memory:') + $config);
         Zend_Db_Table_Abstract::setDefaultAdapter($this->_db);
         $query = array();
         $query[] = 'CREATE TABLE `Sessions` ( ';
@@ -534,4 +652,4 @@ class Zend_Session_SaveHandler_DbTableTestSkip extends PHPUnit_Framework_TestCas
     {
         $this->markTestSkipped('The pdo_sqlite extension must be available and enabled for this test');
     }
-}
\ No newline at end of file
+}
