@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,18 +15,11 @@
  * @category   Zend
  * @package    Zend_Session
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: SessionTest.php 10802 2008-08-08 12:14:42Z alexander $
+ * @version    $Id: SessionTest.php 24819 2012-05-28 19:25:03Z rob $
  */
 
-
-/**
- * PHPUnit test case
- */
-require_once 'PHPUnit/Framework/TestCase.php';
-
-
 /**
  * @see Zend_Session
  */
@@ -40,9 +32,9 @@ require_once 'Zend/Session.php';
  * @category   Zend
  * @package    Zend_Session
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @see        http://en.wikipedia.org/wiki/Black_box_testing
+ * @group      Zend_Session
  */
 class Zend_SessionTest extends PHPUnit_Framework_TestCase
 {
@@ -65,9 +57,12 @@ class Zend_SessionTest extends PHPUnit_Framework_TestCase
      *
      * @return void
      */
-    public function __construct()
+    public function __construct($name = NULL, array $data = array(), $dataName = '')
     {
-        $this->_script = 'php -c ' . php_ini_loaded_file() . ' '
+        parent::__construct($name, $data, $dataName);
+        $this->_script = 'php '
+            . '-c ' . escapeshellarg(php_ini_loaded_file()) . ' '
+            . '-d include_path=' . get_include_path() . ' '
             . escapeshellarg(dirname(__FILE__) . DIRECTORY_SEPARATOR . 'SessionTestHelper.php');
 
         $this->_savePath = ini_get('session.save_path');
@@ -373,6 +368,23 @@ class Zend_SessionTest extends PHPUnit_Framework_TestCase
         }
     }
 
+    /**
+     * test for detection of illegal namespace names; expect exception complaining about name beginning
+     * with an underscore
+     *
+     * @return void
+     */
+    public function testInitNamespaceNumber()
+    {
+        try {
+            $s = new Zend_Session_Namespace('0namespace');
+            $this->fail('No exception was returned when requesting a namespace having a name beginning with '
+                . 'a number');
+        } catch (Zend_Session_Exception $e) {
+            $this->assertRegexp('/number/i', $e->getMessage());
+        }
+    }
+
     /**
      * test iteration; expect native PHP foreach statement is able to properly iterate all items in a session namespace
      *
@@ -765,6 +777,7 @@ class Zend_SessionTest extends PHPUnit_Framework_TestCase
     /**
      * test expiration of namespaces and namespace variables by seconds; expect expiration of specified keys/namespace
      *
+     * @runInSeparateProcess
      * @return void
      */
     public function testSetExpirationSeconds()
@@ -824,6 +837,7 @@ class Zend_SessionTest extends PHPUnit_Framework_TestCase
     /**
      * test expiration of namespaces by hops; expect expiration of specified namespace in the proper number of hops
      *
+     * @runInSeparateProcess
      * @return void
      */
     public function testSetExpireSessionHops()
@@ -856,6 +870,7 @@ class Zend_SessionTest extends PHPUnit_Framework_TestCase
     /**
      * test expiration of namespace variables by hops; expect expiration of specified keys in the proper number of hops
      *
+     * @runInSeparateProcess
      * @return void
      */
     public function testSetExpireSessionVarsByHops1()
@@ -866,6 +881,7 @@ class Zend_SessionTest extends PHPUnit_Framework_TestCase
     /**
      * sanity check .. we should be able to repeat this test without problems
      *
+     * @runInSeparateProcess
      * @return void
      */
     public function testSetExpireSessionVarsByHops2()
@@ -873,6 +889,29 @@ class Zend_SessionTest extends PHPUnit_Framework_TestCase
         $this->setExpireSessionVarsByHops();
     }
 
+    /**
+     * @group ZF-7196
+     * @runInSeparateProcess
+     */
+    public function testUnsettingNamespaceKeyWithoutUnsettingCompleteExpirationData()
+    {
+        $namespace = new Zend_Session_Namespace('DummyNamespace');
+
+        $namespace->foo = 23;
+        $namespace->bar = 42;
+
+        $namespace->setExpirationHops(1);
+
+        $sessionId = session_id();
+
+        session_write_close();
+        exec($this->_script . ' expireAll ' . $sessionId . ' DummyNamespace ZF-7196', $result, $returnValue);
+        session_start();
+
+        $result = $this->sortResult($result);
+        $this->assertSame(';bar === 42', $result);
+    }
+
     /**
      * test expiration of namespace variables by hops; expect expiration of specified keys in the proper number of hops
      *
@@ -931,6 +970,7 @@ class Zend_SessionTest extends PHPUnit_Framework_TestCase
     /**
      * test expiration of namespace variables by hops; expect expiration of specified keys in the proper number of hops
      *
+     * @runInSeparateProcess
      * @return void
      */
     public function testSetExpireSessionVarsByHopsOnUse()
@@ -975,4 +1015,99 @@ class Zend_SessionTest extends PHPUnit_Framework_TestCase
         // Do not destroy session since it still may be used by other tests
         // Zend_Session::destroy();
     }
+
+    /**
+     * @group ZF-5003
+     */
+    public function testProcessSessionMetadataShouldNotThrowAnError()
+    {
+        Zend_Session::$_unitTestEnabled = true;
+        if (isset($_SESSION) && isset($_SESSION['__ZF'])) {
+            unset($_SESSION['__ZF']);
+        }
+        Zend_Session::start();
+    }
+
+    /**
+     * test for method getNamespace()
+     *
+     * @group ZF-1982
+     * @return void
+     */
+    public function testGetNameSpaceMethod()
+    {
+        Zend_Session::$_unitTestEnabled = true;
+        $namespace = array(
+            'FooBar',
+            'Foo_Bar',
+            'Foo-Bar',
+            'Foo1000'
+        );
+        foreach ($namespace as $v) {
+            $s = new Zend_Session_Namespace($v);
+            $this->assertEquals($v, $s->getNamespace());
+        }
+    }
+
+    /**
+     * @group ZF-11186
+     */
+    public function testNoNoticesIfNoValidatorDataInSession()
+    {
+        try {
+            Zend_Session::start();
+            require_once dirname(__FILE__) . '/Validator/NoticeValidator.php';
+            Zend_Session::registerValidator(new Zend_Session_Validator_NoticeValidator);
+        } catch (PHPUnit_Framework_Error_Notice $exception) {
+            $this->fail($exception->getMessage());
+        }
+    }
+
+    /**
+     * @group ZF-3378
+     */
+    public function testInvalidPreexistingSessionIdDoesNotPreventRegenerationOfSid()
+    {
+        // Pattern: [0-9a-v]*
+        ini_set('session.hash_bits_per_character', 5);
+
+        // Session store
+        $sessionCharSet = array_merge(range(0,9), range('a','v'));
+        $sessionStore = dirname(__FILE__)
+                      . DIRECTORY_SEPARATOR . "_files"
+                      . DIRECTORY_SEPARATOR . "ZF-3378";
+        if ( !is_dir($sessionStore) ) @mkdir($sessionStore, 0755, true);
+        ini_set('session.save_path', "1;666;" . $sessionStore);
+
+        // When using subdirs for session.save_path, the directory structure
+        // is your own responsibility...set it up, or else bad things happen
+        foreach ( $sessionCharSet as $subdir ) {
+            @mkdir($sessionStore . DIRECTORY_SEPARATOR . $subdir);
+        }
+
+        // Set session ID to invalid value
+        session_id('xxx');
+
+        // Attempt to start the session
+        try {
+            /** @see Zend_Session */
+            require_once "Zend/Session.php";
+            Zend_Session::start();
+        } catch (Zend_Session_Exception $e) {
+            Zend_Session::regenerateId();
+        }
+        // Get the current SID
+        $sid = Zend_Session::getId();
+
+        // We don't need the session any more, clean it up
+        Zend_Session::destroy();
+        foreach ( $sessionCharSet as $subdir ) {
+            @rmdir($sessionStore . DIRECTORY_SEPARATOR . $subdir);
+        }
+        @rmdir($sessionStore);
+
+        // Check the result
+        $this->assertRegExp('/^[0-9a-v]+$/', $sid);
+        $this->assertNotEquals('xxx', $sid);
+    }
 }
