@@ -1,11 +1,30 @@
 <?php
+/**
+ * Zend Framework
+ *
+ * LICENSE
+ *
+ * This source file is subject to the new BSD license that is bundled
+ * with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://framework.zend.com/license/new-bsd
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@zend.com so we can send you a copy immediately.
+ *
+ * @category   Zend
+ * @package    Zend_Test
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id: ControllerTestCaseTest.php 25205 2013-01-10 11:23:25Z frosch $
+ */
+
 // Call Zend_Test_PHPUnit_ControllerTestCaseTest::main() if this source file is executed directly.
 if (!defined("PHPUnit_MAIN_METHOD")) {
     define("PHPUnit_MAIN_METHOD", "Zend_Test_PHPUnit_ControllerTestCaseTest::main");
 }
 
-require_once dirname(__FILE__) . '/../../../TestHelper.php';
-
 /** Zend_Test_PHPUnit_ControllerTestCase */
 require_once 'Zend/Test/PHPUnit/ControllerTestCase.php';
 
@@ -20,8 +39,16 @@ require_once 'Zend/Controller/Action.php';
 
 /**
  * Test class for Zend_Test_PHPUnit_ControllerTestCase.
+ *
+ * @category   Zend
+ * @package    Zend_Test
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Test
+ * @group      Zend_Test_PHPUnit
  */
-class Zend_Test_PHPUnit_ControllerTestCaseTest extends PHPUnit_Framework_TestCase 
+class Zend_Test_PHPUnit_ControllerTestCaseTest extends PHPUnit_Framework_TestCase
 {
     /**
      * Runs the test methods of this class.
@@ -276,6 +303,8 @@ class Zend_Test_PHPUnit_ControllerTestCaseTest extends PHPUnit_Framework_TestCas
         $this->testCase->assertQuery('div#foo legend.bat', $body);
         $this->testCase->assertNotQuery('div#foo legend.bogus', $body);
         $this->testCase->assertQueryContentContains('legend.bat', 'La di da', $body);
+        $this->testCase->assertQueryContentContains('legend.numeric', 42, $body);
+        $this->testCase->assertNotQueryContentContains('legend.numeric', 31, $body);
         $this->testCase->assertNotQueryContentContains('legend.bat', 'La do da', $body);
         $this->testCase->assertQueryContentRegex('legend.bat', '/d[a|i]/i', $body);
         $this->testCase->assertNotQueryContentRegex('legend.bat', '/d[o|e]/i', $body);
@@ -285,6 +314,16 @@ class Zend_Test_PHPUnit_ControllerTestCaseTest extends PHPUnit_Framework_TestCas
         $this->testCase->assertQueryCountMax('div#foo legend.bar', 2, $body);
     }
 
+    /**
+     * @group ZF-4673
+     */
+    public function testAssertionsShouldIncreasePhpUnitAssertionCounter()
+    {
+        $this->testAssertQueryShouldDoNothingForValidResponseContent();
+        $this->assertTrue(0 < $this->testCase->getNumAssertions());
+        $this->assertTrue(12 <= $this->testCase->getNumAssertions());
+    }
+
     public function testAssertQueryShouldThrowExceptionsForInValidResponseContent()
     {
         $this->testCase->getFrontController()->setControllerDirectory(dirname(__FILE__) . '/_files/application/controllers');
@@ -590,6 +629,19 @@ class Zend_Test_PHPUnit_ControllerTestCaseTest extends PHPUnit_Framework_TestCas
         $this->assertNotSame($response, $test);
     }
 
+    /**
+     * @group ZF-4511
+     */
+    public function testResetRequestShouldClearRequestObject()
+    {
+        $this->testCase->getFrontController()->setControllerDirectory(dirname(__FILE__) . '/_files/application/controllers');
+        $this->testCase->dispatch('/zend-test-php-unit-foo/baz');
+        $request = $this->testCase->getRequest();
+        $this->testCase->resetRequest();
+        $test = $this->testCase->getRequest();
+        $this->assertNotSame($request, $test);
+    }
+
     public function testResetResponseShouldClearAllViewPlaceholders()
     {
         $this->testCase->getFrontController()->setControllerDirectory(dirname(__FILE__) . '/_files/application/controllers');
@@ -666,6 +718,156 @@ class Zend_Test_PHPUnit_ControllerTestCaseTest extends PHPUnit_Framework_TestCas
         $this->assertNull($request->getPost('foo'), 'Retrieved foo post parameter: ' . var_export($request->getPost(), 1));
         $this->assertNull($request->getCookie('bar'), 'Retrieved bar cookie parameter: ' . var_export($request->getCookie(), 1));
     }
+
+    /**
+     * @group ZF-4511
+     */
+    public function testResetRequestShouldClearPostAndQueryParameters()
+    {
+        $this->testCase->getFrontController()->setControllerDirectory(dirname(__FILE__) . '/_files/application/controllers');
+        $this->testCase->getRequest()->setPost(array(
+            'foo' => 'bar',
+        ));
+        $this->testCase->getRequest()->setQuery(array(
+            'bar' => 'baz',
+        ));
+        $this->testCase->dispatch('/zend-test-php-unit-foo/baz');
+        $this->testCase->resetRequest();
+        $this->assertTrue(empty($_POST));
+        $this->assertTrue(empty($_GET));
+    }
+
+    /**
+     * @group ZF-7839
+     */
+    public function testTestCaseShouldAllowUsingApplicationObjectAsBootstrap()
+    {
+        require_once 'Zend/Application.php';
+        $application = new Zend_Application('testing', array(
+            'resources' => array(
+                'frontcontroller' => array(
+                    'controllerDirectory' => dirname(__FILE__) . '/_files/application/controllers',
+                ),
+            ),
+        ));
+        $this->testCase->bootstrap = $application;
+        $this->testCase->bootstrap();
+        $this->assertEquals(
+            $application->getBootstrap()->getResource('frontcontroller'),
+            $this->testCase->getFrontController()
+        );
+    }
+
+    /**
+     * @group ZF-8193
+     */
+    public function testWhenApplicationObjectUsedAsBootstrapTestCaseShouldExecuteBootstrapRunMethod()
+    {
+        require_once 'Zend/Application.php';
+        $application = new Zend_Application('testing', array(
+            'resources' => array(
+                'frontcontroller' => array(
+                    'controllerDirectory' => dirname(__FILE__) . '/_files/application/controllers',
+                ),
+            ),
+        ));
+        $this->testCase->bootstrap = $application;
+        $this->testCase->bootstrap();
+        $this->testCase->dispatch('/');
+        $front = $application->getBootstrap()->getResource('frontcontroller');
+        $boot  = $front->getParam('bootstrap');
+        $type  = is_object($boot)
+               ? get_class($boot)
+               : gettype($boot);
+        $this->assertTrue($boot === $this->testCase->bootstrap->getBootstrap(), $type);
+    }
+    
+    /**
+     * @group ZF-7496
+     * @dataProvider providerRedirectWorksAsExpectedFromHookMethodsInActionController
+     */
+    public function testRedirectWorksAsExpectedFromHookMethodsInActionController($dispatchTo)
+    {
+        $this->testCase->getFrontController()->setControllerDirectory(dirname(__FILE__) . '/_files/application/controllers');
+        $this->testCase->dispatch($dispatchTo);
+        $this->testCase->assertRedirectTo('/login');
+        $this->assertNotEquals('action body', $this->testCase->getResponse()->getBody());
+    }
+    
+    /**
+     * Data provider for testRedirectWorksAsExpectedFromHookMethodsInActionController
+     * @return array
+     */
+    public function providerRedirectWorksAsExpectedFromHookMethodsInActionController()
+    {
+        return array(
+            array('/zend-test-redirect-from-init/baz'),
+            array('/zend-test-redirect-from-pre-dispatch/baz')
+        );
+    }
+    
+    /**
+     * @group ZF-7496
+     * @dataProvider providerRedirectWorksAsExpectedFromHookMethodsInFrontControllerPlugin
+     */
+    public function testRedirectWorksAsExpectedFromHookMethodsInFrontControllerPlugin($pluginName)
+    {
+        require_once dirname(__FILE__) . "/_files/application/plugins/RedirectFrom{$pluginName}.php";
+        $className = "Application_Plugin_RedirectFrom{$pluginName}";
+        
+        $fc = $this->testCase->getFrontController();
+        $fc->setControllerDirectory(dirname(__FILE__) . '/_files/application/controllers')
+           ->registerPlugin(new $className());
+        $this->testCase->dispatch('/');
+        $this->testCase->assertRedirectTo('/login');
+        $this->assertNotEquals('action body', $this->testCase->getResponse()->getBody());
+    }
+
+    /**
+     * @group ZF-12492
+     * @internal Since header value is being cast into a string, we should only
+     * need to check 0 and 0.0
+     */
+    public function testHeaderAssertionShouldDoNothingForValidComparisonWithZeroForValue()
+    {
+        $this->testCase->getResponse()->setHeader('Expires', '0', true);
+        $this->testCase->assertResponseCode(200);
+        $this->testCase->assertNotResponseCode(500);
+        $this->testCase->assertHeader('Expires');
+        $this->testCase->assertNotHeader('X-Bogus');
+        $this->testCase->assertHeaderContains('Expires', '0');
+        $this->testCase->assertNotHeaderContains('Expires', 'my-bar');
+        $this->testCase->assertHeaderRegex('Expires', '#^\d#i');
+        $this->testCase->assertNotHeaderRegex(
+            'Expires', '#^[a-z-]+/[a-z-]+$#i'
+        );
+
+        $this->testCase->getResponse()->setHeader('Expires', '0.0', true);
+        $this->testCase->assertResponseCode(200);
+        $this->testCase->assertNotResponseCode(500);
+        $this->testCase->assertHeader('Expires');
+        $this->testCase->assertNotHeader('X-Bogus');
+        $this->testCase->assertHeaderContains('Expires', '0.0');
+        $this->testCase->assertNotHeaderContains('Expires', 'my-bar');
+        $this->testCase->assertHeaderRegex('Expires', '#^\d+#i');
+        $this->testCase->assertNotHeaderRegex(
+            'Expires', '#^[a-z-]+/[a-z-]+$#i'
+        );
+    }
+    
+    /**
+     * Data provider for testRedirectWorksAsExpectedFromHookMethodsInFrontControllerPlugin
+     * @return array
+     */
+    public function providerRedirectWorksAsExpectedFromHookMethodsInFrontControllerPlugin()
+    {
+        return array(
+            array('RouteStartup'),
+            array('RouteShutdown'),
+            array('DispatchLoopStartup'),
+            array('PreDispatch')
+        );
+    }
 }
 
 // Concrete test case class for testing purposes
