@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,29 +15,23 @@
  * @category   Zend
  * @package    Zend_Validate
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: StringLengthTest.php 8064 2008-02-16 10:58:39Z thomas $
+ * @version    $Id: StringLengthTest.php 24593 2012-01-05 20:35:02Z matthew $
  */
 
-
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
 /**
  * @see Zend_Validate_StringLength
  */
 require_once 'Zend/Validate/StringLength.php';
 
-
 /**
  * @category   Zend
  * @package    Zend_Validate
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Validate
  */
 class Zend_Validate_StringLengthTest extends PHPUnit_Framework_TestCase
 {
@@ -162,4 +155,26 @@ class Zend_Validate_StringLengthTest extends PHPUnit_Framework_TestCase
                 );
         }
     }
+
+    /**
+     * @return void
+     */
+    public function testDifferentEncodingWithValidator()
+    {
+        iconv_set_encoding('internal_encoding', 'UTF-8');
+        $validator = new Zend_Validate_StringLength(2, 2, 'UTF-8');
+        $this->assertEquals(true, $validator->isValid('ab'));
+
+        $this->assertEquals('UTF-8', $validator->getEncoding());
+        $validator->setEncoding('ISO-8859-1');
+        $this->assertEquals('ISO-8859-1', $validator->getEncoding());
+    }
+
+    /**
+     * @ZF-4352
+     */
+    public function testNonStringValidation()
+    {
+        $this->assertFalse($this->_validator->isValid(array(1 => 1)));
+    }
 }
