@@ -1,5 +1,24 @@
 <?php
-require_once 'PHPUnit/Framework/TestCase.php';
+/**
+ * Zend Framework
+ *
+ * LICENSE
+ *
+ * This source file is subject to the new BSD license that is bundled
+ * with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://framework.zend.com/license/new-bsd
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@zend.com so we can send you a copy immediately.
+ *
+ * @category   Zend
+ * @package    Zend_XmlRpc
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version $Id: ClientTest.php 24593 2012-01-05 20:35:02Z matthew $
+ */
 
 require_once 'Zend/XmlRpc/Client.php';
 
@@ -7,19 +26,39 @@ require_once 'Zend/XmlRpc/Response.php';
 
 require_once 'Zend/Http/Client/Adapter/Test.php';
 
+require_once 'Zend/XmlRpc/Value/DateTime.php';
+
 /**
  * Test case for Zend_XmlRpc_Value
  *
- * @package Zend_XmlRpc
+ * @category   Zend
+ * @package    Zend_XmlRpc
  * @subpackage UnitTests
- * @version $Id$
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_XmlRpc
  */
-class Zend_XmlRpc_ClientTest extends PHPUnit_Framework_TestCase 
+class Zend_XmlRpc_ClientTest extends PHPUnit_Framework_TestCase
 {
+    /**
+     * @var Zend_Http_Client_Adapter_Abstract
+     */
+    protected $httpAdapter;
+
+    /**
+     * @var Zend_Http_Client
+     */
+    protected $httpClient;
+
+    /**
+     * @var Zend_XmlRpc_Client
+     */
+    protected $xmlrpcClient;
+
     public function setUp()
     {
         $this->httpAdapter = new Zend_Http_Client_Adapter_Test();
-        $this->httpClient = new Zend_Http_Client('http://foo', 
+        $this->httpClient = new Zend_Http_Client('http://foo',
                                     array('adapter' => $this->httpAdapter));
 
         $this->xmlrpcClient = new Zend_XmlRpc_Client('http://foo');
@@ -65,7 +104,7 @@ class Zend_XmlRpc_ClientTest extends PHPUnit_Framework_TestCase
     {
         $this->setServerResponseTo(true);
         $this->xmlrpcClient->call('foo');
-        
+
         $this->assertType('Zend_XmlRpc_Request', $this->xmlrpcClient->getLastRequest());
         $this->assertType('Zend_XmlRpc_Response', $this->xmlrpcClient->getLastResponse());
     }
@@ -86,7 +125,7 @@ class Zend_XmlRpc_ClientTest extends PHPUnit_Framework_TestCase
         $this->assertSame($expectedReturn, $response->getReturnValue());
         $this->assertFalse($response->isFault());
     }
-    
+
     public function testSuccessfulRpcMethodCallWithParameters()
     {
         $expectedMethod = 'foo.bar';
@@ -94,7 +133,7 @@ class Zend_XmlRpc_ClientTest extends PHPUnit_Framework_TestCase
         $expectedReturn = array(7, false, 'foo' => 'bar');
 
         $this->setServerResponseTo($expectedReturn);
-        
+
         $actualReturn = $this->xmlrpcClient->call($expectedMethod, $expectedParams);
         $this->assertSame($expectedReturn, $actualReturn);
 
@@ -102,14 +141,41 @@ class Zend_XmlRpc_ClientTest extends PHPUnit_Framework_TestCase
         $response = $this->xmlrpcClient->getLastResponse();
 
         $this->assertSame($expectedMethod, $request->getMethod());
-        $this->assertSame($expectedParams, $request->getParams());
+        $params = $request->getParams();
+        $this->assertSame(count($expectedParams), count($params));
+        $this->assertSame($expectedParams[0], $params[0]->getValue());
+        $this->assertSame($expectedParams[1], $params[1]->getValue());
+        $this->assertSame($expectedParams[2], $params[2]->getValue());
+        $this->assertSame($expectedParams['foo'], $params['foo']->getValue());
+
         $this->assertSame($expectedReturn, $response->getReturnValue());
         $this->assertFalse($response->isFault());
     }
-    
+
     /**
-     * Test for ZF-1412
-     * 
+     * @group ZF-2090
+     */
+    public function testSuccessfullyDetectsEmptyArrayParameterAsArray()
+    {
+        $expectedMethod = 'foo.bar';
+        $expectedParams = array(array());
+        $expectedReturn = array(true);
+
+        $this->setServerResponseTo($expectedReturn);
+
+        $actualReturn = $this->xmlrpcClient->call($expectedMethod, $expectedParams);
+        $this->assertSame($expectedReturn, $actualReturn);
+
+        $request  = $this->xmlrpcClient->getLastRequest();
+
+        $params = $request->getParams();
+        $this->assertSame(count($expectedParams), count($params));
+        $this->assertSame($expectedParams[0], $params[0]->getValue());
+    }
+
+    /**
+     * @group ZF-1412
+     *
      * @return void
      */
     public function testSuccessfulRpcMethodCallWithMixedDateParameters()
@@ -117,13 +183,13 @@ class Zend_XmlRpc_ClientTest extends PHPUnit_Framework_TestCase
         $time = time();
         $expectedMethod = 'foo.bar';
         $expectedParams = array(
-            'username', 
+            'username',
             new Zend_XmlRpc_Value_DateTime($time)
         );
         $expectedReturn = array('username', $time);
 
         $this->setServerResponseTo($expectedReturn);
-        
+
         $actualReturn = $this->xmlrpcClient->call($expectedMethod, $expectedParams);
         $this->assertSame($expectedReturn, $actualReturn);
 
@@ -131,21 +197,121 @@ class Zend_XmlRpc_ClientTest extends PHPUnit_Framework_TestCase
         $response = $this->xmlrpcClient->getLastResponse();
 
         $this->assertSame($expectedMethod, $request->getMethod());
-        $this->assertSame($expectedParams, $request->getParams());
+        $params = $request->getParams();
+        $this->assertSame(count($expectedParams), count($params));
+        $this->assertSame($expectedParams[0], $params[0]->getValue());
+        $this->assertSame($expectedParams[1], $params[1]);
         $this->assertSame($expectedReturn, $response->getReturnValue());
         $this->assertFalse($response->isFault());
     }
 
+    /**
+     * @group ZF-1797
+     */
+    public function testSuccesfulRpcMethodCallWithXmlRpcValueParameters()
+    {
+        $time   = time();
+        $params = array(
+            new Zend_XmlRpc_Value_Boolean(true),
+            new Zend_XmlRpc_Value_Integer(4),
+            new Zend_XmlRpc_Value_String('foo')
+        );
+        $expect = array(true, 4, 'foo');
+
+        $this->setServerResponseTo($expect);
+
+        $result = $this->xmlrpcClient->call('foo.bar', $params);
+        $this->assertSame($expect, $result);
+
+        $request  = $this->xmlrpcClient->getLastRequest();
+        $response = $this->xmlrpcClient->getLastResponse();
+
+        $this->assertSame('foo.bar', $request->getMethod());
+        $this->assertSame($params, $request->getParams());
+        $this->assertSame($expect, $response->getReturnValue());
+        $this->assertFalse($response->isFault());
+    }
+
+    /**
+     * @group ZF-2978
+     */
+    public function testSkippingSystemCallDisabledByDefault()
+    {
+        $this->assertFalse($this->xmlrpcClient->skipSystemLookup());
+    }
+
+    /**
+     * @group ZF-6993
+     */
+    public function testWhenPassingAStringAndAnIntegerIsExpectedParamIsConverted()
+    {
+        $this->mockIntrospector();
+        $this->mockedIntrospector
+             ->expects($this->exactly(2))
+             ->method('getMethodSignature')
+             ->with('test.method')
+             ->will($this->returnValue(array(array('parameters' => array('int')))));
+
+        $expect = 'test.method response';
+        $this->setServerResponseTo($expect);
+
+        $this->assertSame($expect, $this->xmlrpcClient->call('test.method', array('1')));
+        $params = $this->xmlrpcClient->getLastRequest()->getParams();
+        $this->assertSame(1, $params[0]->getValue());
+
+        $this->setServerResponseTo($expect);
+        $this->assertSame($expect, $this->xmlrpcClient->call('test.method', '1'));
+        $params = $this->xmlrpcClient->getLastRequest()->getParams();
+        $this->assertSame(1, $params[0]->getValue());
+    }
+
+    /**
+     * @group ZF-8074
+     */
+    public function testXmlRpcObjectsAreNotConverted()
+    {
+        $this->mockIntrospector();
+        $this->mockedIntrospector
+             ->expects($this->exactly(1))
+             ->method('getMethodSignature')
+             ->with('date.method')
+             ->will($this->returnValue(array(array('parameters' => array('dateTime.iso8601', 'string')))));
+
+        $expects = 'date.method response';
+        $this->setServerResponseTo($expects);
+        $this->assertSame($expects, $this->xmlrpcClient->call('date.method', array(Zend_XmlRpc_Value::getXmlRpcValue(time(), Zend_XmlRpc_Value::XMLRPC_TYPE_DATETIME), 'foo')));
+    }
+
+    public function testAllowsSkippingSystemCallForArrayStructLookup()
+    {
+        $this->xmlrpcClient->setSkipSystemLookup(true);
+        $this->assertTrue($this->xmlrpcClient->skipSystemLookup());
+    }
+
+    public function testSkipsSystemCallWhenDirected()
+    {
+        $this->mockHttpClient();
+        $this->mockedHttpClient->expects($this->once())
+                               ->method('request')
+                               ->with('POST')
+                               ->will($this->returnValue($this->makeHttpResponseFor('foo')));
+        $this->xmlrpcClient->setHttpClient($this->mockedHttpClient);
+        $this->xmlrpcClient->setSkipSystemLookup(true);
+        $this->assertSame('foo', $this->xmlrpcClient->call('test.method'));
+    }
+
+    /**#@-*/
+
     // Faults
-    
+
     public function testRpcMethodCallThrowsOnHttpFailure()
     {
         $status  = 404;
         $message = 'Not Found';
         $body    = 'oops';
-        
+
         $response = $this->makeHttpResponseFrom($body, $status, $message);
-        $this->httpAdapter->setResponse($response);        
+        $this->httpAdapter->setResponse($response);
 
         try {
             $this->xmlrpcClient->call('foo');
@@ -161,12 +327,12 @@ class Zend_XmlRpc_ClientTest extends PHPUnit_Framework_TestCase
     {
         $code = 9;
         $message = 'foo';
-        
+
         $fault = new Zend_XmlRpc_Fault($code, $message);
-        $xml = $fault->saveXML();
+        $xml = $fault->saveXml();
 
         $response = $this->makeHttpResponseFrom($xml);
-        $this->httpAdapter->setResponse($response);        
+        $this->httpAdapter->setResponse($response);
 
         try {
             $this->xmlrpcClient->call('foo');
@@ -177,15 +343,15 @@ class Zend_XmlRpc_ClientTest extends PHPUnit_Framework_TestCase
             $this->assertEquals($code, $e->getCode());
         }
     }
-    
+
     // Server Proxy
-    
+
     public function testGetProxyReturnsServerProxy()
     {
         $class = 'Zend_XmlRpc_Client_ServerProxy';
         $this->assertType($class, $this->xmlrpcClient->getProxy());
     }
-    
+
     public function testRpcMethodCallsThroughServerProxy()
     {
         $expectedReturn = array(7, false, 'foo' => 'bar');
@@ -197,7 +363,7 @@ class Zend_XmlRpc_ClientTest extends PHPUnit_Framework_TestCase
         $request = $this->xmlrpcClient->getLastRequest();
         $this->assertEquals('listMethods', $request->getMethod());
     }
-    
+
     public function testRpcMethodCallsThroughNestedServerProxies()
     {
         $expectedReturn = array(7, false, 'foo' => 'bar');
@@ -209,7 +375,7 @@ class Zend_XmlRpc_ClientTest extends PHPUnit_Framework_TestCase
         $request = $this->xmlrpcClient->getLastRequest();
         $this->assertEquals('foo.bar.baz.boo', $request->getMethod());
     }
-    
+
     public function testClientCachesServerProxies()
     {
         $proxy = $this->xmlrpcClient->getProxy();
@@ -217,8 +383,8 @@ class Zend_XmlRpc_ClientTest extends PHPUnit_Framework_TestCase
 
         $proxy = $this->xmlrpcClient->getProxy('foo');
         $this->assertSame($proxy, $this->xmlrpcClient->getProxy('foo'));
-    }    
-    
+    }
+
     public function testServerProxyCachesNestedProxies()
     {
         $proxy = $this->xmlrpcClient->getProxy();
@@ -249,62 +415,62 @@ class Zend_XmlRpc_ClientTest extends PHPUnit_Framework_TestCase
         $xmlrpcClient->setIntrospector($introspector);
         $this->assertSame($introspector, $xmlrpcClient->getIntrospector());
     }
-    
+
     public function testGettingMethodSignature()
     {
         $method = 'foo';
         $signatures = array(array('int', 'int', 'int'));
         $this->setServerResponseTo($signatures);
-        
+
         $i = $this->xmlrpcClient->getIntrospector();
         $this->assertEquals($signatures, $i->getMethodSignature($method));
-        
+
         $request = $this->xmlrpcClient->getLastRequest();
         $this->assertEquals('system.methodSignature', $request->getMethod());
         $this->assertEquals(array($method), $request->getParams());
     }
-    
+
     public function testListingMethods()
     {
         $methods = array('foo', 'bar', 'baz');
         $this->setServerResponseTo($methods);
-        
+
         $i = $this->xmlrpcClient->getIntrospector();
         $this->assertEquals($methods, $i->listMethods());
-        
+
         $request = $this->xmlrpcClient->getLastRequest();
         $this->assertEquals('system.listMethods', $request->getMethod());
-        $this->assertEquals(array(), $request->getParams());        
+        $this->assertEquals(array(), $request->getParams());
     }
-    
+
     public function testGettingAllMethodSignaturesByLooping()
     {
         // system.listMethods() will return ['foo', 'bar']
         $methods = array('foo', 'bar');
         $response = $this->getServerResponseFor($methods);
         $this->httpAdapter->setResponse($response);
-        
+
         // system.methodSignature('foo') will return [['int'], ['int', 'string']]
         $fooSignatures = array(array('int'), array('int', 'string'));
         $response = $this->getServerResponseFor($fooSignatures);
         $this->httpAdapter->addResponse($response);
-        
+
         // system.methodSignature('bar') will return [['boolean']]
         $barSignatures = array(array('boolean'));
         $response = $this->getServerResponseFor($barSignatures);
         $this->httpAdapter->addResponse($response);
-        
+
         $expected = array('foo' => $fooSignatures,
                           'bar' => $barSignatures);
 
         $i = $this->xmlrpcClient->getIntrospector();
         $this->assertEquals($expected, $i->getSignatureForEachMethodByLooping());
-        
+
         $request = $this->xmlrpcClient->getLastRequest();
         $this->assertEquals('system.methodSignature', $request->getMethod());
         $this->assertEquals(array('bar'), $request->getParams());
     }
-    
+
     public function testGettingAllMethodSignaturesByMulticall()
     {
         // system.listMethods() will return ['foo', 'bar']
@@ -317,7 +483,7 @@ class Zend_XmlRpc_ClientTest extends PHPUnit_Framework_TestCase
                                        'params'     => array('foo')),
                                  array('methodName' => 'system.methodSignature',
                                        'params'     => array('bar')));
-        
+
         // system.multicall() will then return [fooSignatures, barSignatures]
         $fooSignatures = array(array('int'), array('int', 'string'));
         $barSignatures = array(array('boolean'));
@@ -326,16 +492,16 @@ class Zend_XmlRpc_ClientTest extends PHPUnit_Framework_TestCase
         $this->httpAdapter->addResponse($response);
 
         $i = $this->xmlrpcClient->getIntrospector();
-        
+
         $expected = array('foo' => $fooSignatures,
                           'bar' => $barSignatures);
         $this->assertEquals($expected, $i->getSignatureForEachMethodByMulticall());
-        
+
         $request = $this->xmlrpcClient->getLastRequest();
         $this->assertEquals('system.multicall', $request->getMethod());
         $this->assertEquals(array($multicallParams), $request->getParams());
     }
-    
+
     public function testGettingAllMethodSignaturesByMulticallThrowsOnBadCount()
     {
         // system.listMethods() will return ['foo', 'bar']
@@ -358,7 +524,7 @@ class Zend_XmlRpc_ClientTest extends PHPUnit_Framework_TestCase
             $this->assertRegexp('/bad number/i', $e->getMessage());
         }
     }
-    
+
     public function testGettingAllMethodSignaturesByMulticallThrowsOnBadType()
     {
         // system.listMethods() will return ['foo', 'bar']
@@ -380,7 +546,7 @@ class Zend_XmlRpc_ClientTest extends PHPUnit_Framework_TestCase
             $this->assertRegexp('/got integer/i', $e->getMessage());
         }
     }
-    
+
     public function testGettingAllMethodSignaturesDefaultsToMulticall()
     {
         // system.listMethods() will return ['foo', 'bar']
@@ -396,15 +562,15 @@ class Zend_XmlRpc_ClientTest extends PHPUnit_Framework_TestCase
         $this->httpAdapter->addResponse($response);
 
         $i = $this->xmlrpcClient->getIntrospector();
-        
+
         $expected = array('foo' => $fooSignatures,
                           'bar' => $barSignatures);
         $this->assertEquals($expected, $i->getSignatureForEachMethod());
-        
+
         $request = $this->xmlrpcClient->getLastRequest();
         $this->assertEquals('system.multicall', $request->getMethod());
     }
-    
+
     public function testGettingAllMethodSignaturesDegradesToLooping()
     {
         // system.listMethods() will return ['foo', 'bar']
@@ -414,9 +580,9 @@ class Zend_XmlRpc_ClientTest extends PHPUnit_Framework_TestCase
 
         // system.multicall() will return a fault
         $fault = new Zend_XmlRpc_Fault(7, 'bad method');
-        $xml = $fault->saveXML();
+        $xml = $fault->saveXml();
         $response = $this->makeHttpResponseFrom($xml);
-        $this->httpAdapter->addResponse($response);  
+        $this->httpAdapter->addResponse($response);
 
         // system.methodSignature('foo') will return [['int'], ['int', 'string']]
         $fooSignatures = array(array('int'), array('int', 'string'));
@@ -427,20 +593,150 @@ class Zend_XmlRpc_ClientTest extends PHPUnit_Framework_TestCase
         $barSignatures = array(array('boolean'));
         $response = $this->getServerResponseFor($barSignatures);
         $this->httpAdapter->addResponse($response);
-        
+
         $i = $this->xmlrpcClient->getIntrospector();
-        
+
         $expected = array('foo' => $fooSignatures,
                           'bar' => $barSignatures);
         $this->assertEquals($expected, $i->getSignatureForEachMethod());
-        
+
         $request = $this->xmlrpcClient->getLastRequest();
         $this->assertEquals('system.methodSignature', $request->getMethod());
     }
+
+    /**
+     * @group ZF-4372
+     */
+    public function testSettingUriOnHttpClientIsNotOverwrittenByXmlRpcClient()
+    {
+        $changedUri = "http://bar:80";
+        // Overwrite: http://foo:80
+        $this->setServerResponseTo(array());
+        $this->xmlrpcClient->getHttpClient()->setUri($changedUri);
+        $this->xmlrpcClient->call("foo");
+        $uri = $this->xmlrpcClient->getHttpClient()->getUri(true);
+
+        $this->assertEquals($changedUri, $uri);
+    }
+
+    /**
+     * @group ZF-4372
+     */
+    public function testSettingNoHttpClientUriForcesClientToSetUri()
+    {
+        $baseUri = "http://foo:80";
+        $this->httpAdapter = new Zend_Http_Client_Adapter_Test();
+        $this->httpClient = new Zend_Http_Client(null, array('adapter' => $this->httpAdapter));
+
+        $this->xmlrpcClient = new Zend_XmlRpc_Client($baseUri);
+        $this->xmlrpcClient->setHttpClient($this->httpClient);
+
+        $this->setServerResponseTo(array());
+        $this->assertNull($this->xmlrpcClient->getHttpClient()->getUri());
+        $this->xmlrpcClient->call("foo");
+        $uri = $this->xmlrpcClient->getHttpClient()->getUri(true);
+
+        $this->assertEquals($baseUri, $uri);
+    }
+
+    /**
+     * @group ZF-3288
+     */
+    public function testCustomHttpClientUserAgentIsNotOverridden()
+    {
+        $this->assertNull(
+            $this->httpClient->getHeader('user-agent'),
+            'UA is null if no request was made'
+        );
+        $this->setServerResponseTo(true);
+        $this->assertTrue($this->xmlrpcClient->call('method'));
+        $this->assertSame(
+            'Zend_XmlRpc_Client',
+            $this->httpClient->getHeader('user-agent'),
+            'If no custom UA is set, set Zend_XmlRpc_Client'
+        );
+
+        $expectedUserAgent = 'Zend_XmlRpc_Client (custom)';
+        $this->httpClient->setHeaders(array('user-agent' => $expectedUserAgent));
+
+        $this->setServerResponseTo(true);
+        $this->assertTrue($this->xmlrpcClient->call('method'));
+        $this->assertSame($expectedUserAgent, $this->httpClient->getHeader('user-agent'));
+    }
+
+    /**
+     * @group ZF-8478
+     */
+    public function testPythonSimpleXMLRPCServerWithUnsupportedMethodSignatures()
+    {
+        try
+        {
+        	$introspector = new Zend_XmlRpc_Client_ServerIntrospection(
+                new Test_XmlRpc_Client('http://localhost/')
+            );
+
+            $signature = $introspector->getMethodSignature('add');
+            if (!is_array($signature)) {
+                $this->fail('Expected exception has not been thrown');
+            }
+        }
+        catch (Zend_XmlRpc_Client_IntrospectException $e) {
+            $this->assertEquals('Invalid signature for method "add"', $e->getMessage());
+        }
+    }
+
+    /**
+     * @group ZF-8580
+     */
+    public function testCallSelectsCorrectSignatureIfMoreThanOneIsAvailable()
+    {
+        $this->mockIntrospector();
+
+        $this->mockedIntrospector
+             ->expects($this->exactly(2))
+             ->method('getMethodSignature')
+             ->with('get')
+             ->will($this->returnValue(array(
+                 array('parameters' => array('int')),
+                 array('parameters' => array('array'))
+             )));
+
+          $expectedResult = 'array';
+          $this->setServerResponseTo($expectedResult);
+
+          $this->assertSame(
+              $expectedResult,
+              $this->xmlrpcClient->call('get', array(array(1)))
+          );
+
+          $expectedResult = 'integer';
+          $this->setServerResponseTo($expectedResult);
+
+          $this->assertSame(
+              $expectedResult,
+              $this->xmlrpcClient->call('get', array(1))
+          );
+    }
     
-    
+    /**
+     * @group ZF-1897
+     */
+    public function testHandlesLeadingOrTrailingWhitespaceInChunkedResponseProperly()
+    {
+        $baseUri = "http://foo:80";
+        $this->httpAdapter = new Zend_Http_Client_Adapter_Test();
+        $this->httpClient = new Zend_Http_Client(null, array('adapter' => $this->httpAdapter));
+        
+        $respBody = file_get_contents(dirname(__FILE__) . "/_files/ZF1897-response-chunked.txt");
+        $this->httpAdapter->setResponse($respBody);
+
+        $this->xmlrpcClient = new Zend_XmlRpc_Client($baseUri);
+        $this->xmlrpcClient->setHttpClient($this->httpClient);
+        
+        $this->assertEquals('FOO', $this->xmlrpcClient->call('foo'));
+    }
+
     // Helpers
-    
     public function setServerResponseTo($nativeVars)
     {
         $response = $this->getServerResponseFor($nativeVars);
@@ -451,13 +747,13 @@ class Zend_XmlRpc_ClientTest extends PHPUnit_Framework_TestCase
     {
         $response = new Zend_XmlRpc_Response();
         $response->setReturnValue($nativeVars);
-        $xml = $response->saveXML();
+        $xml = $response->saveXml();
 
         $response = $this->makeHttpResponseFrom($xml);
         return $response;
     }
 
-    public function makeHttpResponseFrom($data, $status=200, $message='OK') 
+    public function makeHttpResponseFrom($data, $status=200, $message='OK')
     {
         $headers = array("HTTP/1.1 $status $message",
                          "Status: $status",
@@ -466,4 +762,56 @@ class Zend_XmlRpc_ClientTest extends PHPUnit_Framework_TestCase
                          );
         return implode("\r\n", $headers) . "\r\n\r\n$data\r\n\r\n";
     }
+
+    public function makeHttpResponseFor($nativeVars)
+    {
+        $response = $this->getServerResponseFor($nativeVars);
+        return Zend_Http_Response::fromString($response);
+    }
+
+    public function mockIntrospector()
+    {
+        $this->mockedIntrospector = $this->getMock(
+            'Zend_XmlRpc_Client_ServerIntrospection',
+            array(),
+            array(),
+            '',
+            false,
+            false
+        );
+        $this->xmlrpcClient->setIntrospector($this->mockedIntrospector);
+    }
+
+    public function mockHttpClient()
+    {
+        $this->mockedHttpClient = $this->getMock('Zend_Http_Client');
+        $this->xmlrpcClient->setHttpClient($this->mockedHttpClient);
+    }
+}
+
+/** related to ZF-8478 */
+require_once 'Zend/XmlRpc/Client/ServerProxy.php';
+class Python_SimpleXMLRPCServerWithUnsupportedIntrospection extends Zend_XmlRpc_Client_ServerProxy {
+    public function __call($method, $args) {
+        if ($method == 'methodSignature') {
+            return 'signatures not supported';
+        }
+        return parent::__call($method, $args);
+    }
+}
+
+/** related to ZF-8478 */
+require_once 'Zend/XmlRpc/Client.php';
+class Test_XmlRpc_Client extends Zend_XmlRpc_Client {
+    public function getProxy($namespace = '') {
+    	if (empty($this->_proxyCache[$namespace])) {
+    	    $this->_proxyCache[$namespace] = new Python_SimpleXMLRPCServerWithUnsupportedIntrospection($this, $namespace);
+    	}
+        return parent::getProxy($namespace);
+    }
+}
+
+// Call Zend_XmlRpc_ClientTest::main() if this source file is executed directly.
+if (PHPUnit_MAIN_METHOD == "Zend_XmlRpc_ClientTest::main") {
+    Zend_XmlRpc_ClientTest::main();
 }
