@@ -1,10 +1,24 @@
 <?php
-// Call Zend_XmlRpc_ServerTest::main() if this source file is executed directly.
-if (!defined('PHPUnit_MAIN_METHOD')) {
-    define('PHPUnit_MAIN_METHOD', 'Zend_XmlRpc_ServerTest::main');
-}
-
-require_once dirname(__FILE__) . '/../../TestHelper.php';
+/**
+ * Zend Framework
+ *
+ * LICENSE
+ *
+ * This source file is subject to the new BSD license that is bundled
+ * with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://framework.zend.com/license/new-bsd
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@zend.com so we can send you a copy immediately.
+ *
+ * @category   Zend
+ * @package    Zend_XmlRpc
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version $Id: ServerTest.php 24593 2012-01-05 20:35:02Z matthew $
+ */
 
 require_once 'Zend/XmlRpc/Server.php';
 require_once 'Zend/XmlRpc/Request.php';
@@ -13,11 +27,14 @@ require_once 'Zend/XmlRpc/Response.php';
 /**
  * Test case for Zend_XmlRpc_Server
  *
- * @package Zend_XmlRpc
+ * @category   Zend
+ * @package    Zend_XmlRpc
  * @subpackage UnitTests
- * @version $Id: ServerTest.php 8974 2008-03-21 20:26:07Z matthew $
+ * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_XmlRpc
  */
-class Zend_XmlRpc_ServerTest extends PHPUnit_Framework_TestCase 
+class Zend_XmlRpc_ServerTest extends PHPUnit_Framework_TestCase
 {
     /**
      * Zend_XmlRpc_Server object
@@ -25,21 +42,10 @@ class Zend_XmlRpc_ServerTest extends PHPUnit_Framework_TestCase
      */
     protected $_server;
 
-    /**
-     * Runs the test methods of this class.
-     *
-     * @return void
-     */
-    public static function main()
-    {
-        $suite  = new PHPUnit_Framework_TestSuite("Zend_XmlRpc_ServerTest");
-        $result = PHPUnit_TextUI_TestRunner::run($suite);
-    }
-
     /**
      * Setup environment
      */
-    public function setUp() 
+    public function setUp()
     {
         $this->_server = new Zend_XmlRpc_Server();
     }
@@ -47,7 +53,7 @@ class Zend_XmlRpc_ServerTest extends PHPUnit_Framework_TestCase
     /**
      * Teardown environment
      */
-    public function tearDown() 
+    public function tearDown()
     {
         unset($this->_server);
     }
@@ -55,9 +61,9 @@ class Zend_XmlRpc_ServerTest extends PHPUnit_Framework_TestCase
     /**
      * __construct() test
      *
-     * Call as method call 
+     * Call as method call
      *
-     * Returns: void 
+     * Returns: void
      */
     public function test__construct()
     {
@@ -67,19 +73,19 @@ class Zend_XmlRpc_ServerTest extends PHPUnit_Framework_TestCase
     /**
      * addFunction() test
      *
-     * Call as method call 
+     * Call as method call
      *
      * Expects:
-     * - function: 
-     * - namespace: Optional; has default; 
-     * 
-     * Returns: void 
+     * - function:
+     * - namespace: Optional; has default;
+     *
+     * Returns: void
      */
     public function testAddFunction()
     {
         try {
             $this->_server->addFunction('Zend_XmlRpc_Server_testFunction', 'zsr');
-        } catch (Exception $e) {
+        } catch (Zend_XmlRpc_Exception $e) {
             $this->fail('Attachment should have worked');
         }
 
@@ -89,7 +95,7 @@ class Zend_XmlRpc_ServerTest extends PHPUnit_Framework_TestCase
         try {
             $this->_server->addFunction('nosuchfunction');
             $this->fail('nosuchfunction() should not exist and should throw an exception');
-        } catch (Exception $e) {
+        } catch (Zend_XmlRpc_Exception $e) {
             // do nothing
         }
 
@@ -102,7 +108,7 @@ class Zend_XmlRpc_ServerTest extends PHPUnit_Framework_TestCase
                 ),
                 'zsr'
             );
-        } catch (Exception $e) {
+        } catch (Zend_XmlRpc_Exception $e) {
             $this->fail('Error attaching array of functions: ' . $e->getMessage());
         }
         $methods = $server->listMethods();
@@ -123,7 +129,7 @@ class Zend_XmlRpc_ServerTest extends PHPUnit_Framework_TestCase
                 ),
                 'zsr'
             );
-        } catch (Exception $e) {
+        } catch (Zend_XmlRpc_Exception $e) {
             $this->fail('Error attaching functions: ' . $e->getMessage());
         }
 
@@ -150,6 +156,38 @@ class Zend_XmlRpc_ServerTest extends PHPUnit_Framework_TestCase
         $this->assertFalse(in_array('test.__construct', $methods));
     }
 
+    /**
+     * @group ZF-6526
+     */
+    public function testSettingClassWithArguments()
+    {
+        $this->_server->setClass('Zend_XmlRpc_Server_testClass', 'test', 'argv-argument');
+        $this->assertTrue($this->_server->sendArgumentsToAllMethods());
+        $request = new Zend_XmlRpc_Request();
+        $request->setMethod('test.test4');
+        $response = $this->_server->handle($request);
+        $this->assertNotType('Zend_XmlRpc_Fault', $response);
+        $this->assertSame(
+            array('test1' => 'argv-argument',
+                'test2' => null,
+                'arg' => array('argv-argument')),
+            $response->getReturnValue());
+    }
+
+    public function testSettingClassWithArgumentsOnlyPassingToConstructor()
+    {
+        $this->_server->setClass('Zend_XmlRpc_Server_testClass', 'test', 'a1', 'a2');
+        $this->_server->sendArgumentsToAllMethods(false);
+        $this->assertFalse($this->_server->sendArgumentsToAllMethods());
+
+        $request = new Zend_XmlRpc_Request();
+        $request->setMethod('test.test4');
+        $request->setParams(array('foo'));
+        $response = $this->_server->handle($request);
+        $this->assertNotType('Zend_XmlRpc_Fault', $response);
+        $this->assertSame(array('test1' => 'a1', 'test2' => 'a2', 'arg' => array('foo')), $response->getReturnValue());
+    }
+
     /**
      * fault() test
      */
@@ -169,12 +207,12 @@ class Zend_XmlRpc_ServerTest extends PHPUnit_Framework_TestCase
     /**
      * handle() test
      *
-     * Call as method call 
+     * Call as method call
      *
      * Expects:
-     * - request: Optional; 
-     * 
-     * Returns: Zend_XmlRpc_Response|Zend_XmlRpc_Fault 
+     * - request: Optional;
+     *
+     * Returns: Zend_XmlRpc_Response|Zend_XmlRpc_Fault
      */
     public function testHandle()
     {
@@ -201,19 +239,30 @@ class Zend_XmlRpc_ServerTest extends PHPUnit_Framework_TestCase
         $this->assertEquals(623, $response->getCode());
     }
 
+    public function testCallingInvalidMethod()
+    {
+        $request = new Zend_XmlRpc_Request();
+        $request->setMethod('invalid');
+        $response = $this->_server->handle($request);
+        $this->assertType('Zend_XmlRpc_Fault', $response);
+        $this->assertSame('Method "invalid" does not exist', $response->getMessage());
+        $this->assertSame(620, $response->getCode());
+    }
+
+
     /**
      * setResponseClass() test
      *
-     * Call as method call 
+     * Call as method call
      *
      * Expects:
-     * - class: 
-     * 
-     * Returns: boolean 
+     * - class:
+     *
+     * Returns: boolean
      */
     public function testSetResponseClass()
     {
-        $this->_server->setResponseClass('Zend_XmlRpc_Server_testResponse');
+        $this->assertTrue($this->_server->setResponseClass('Zend_XmlRpc_Server_testResponse'));
         $request = new Zend_XmlRpc_Request();
         $request->setMethod('system.listMethods');
         $response = $this->_server->handle($request);
@@ -225,9 +274,9 @@ class Zend_XmlRpc_ServerTest extends PHPUnit_Framework_TestCase
     /**
      * listMethods() test
      *
-     * Call as method call 
+     * Call as method call
      *
-     * Returns: array 
+     * Returns: array
      */
     public function testListMethods()
     {
@@ -242,45 +291,51 @@ class Zend_XmlRpc_ServerTest extends PHPUnit_Framework_TestCase
     /**
      * methodHelp() test
      *
-     * Call as method call 
+     * Call as method call
      *
      * Expects:
-     * - method: 
-     * 
-     * Returns: string 
+     * - method:
+     *
+     * Returns: string
      */
     public function testMethodHelp()
     {
-        $help = $this->_server->methodHelp('system.listMethods');
-        $this->assertContains('all available XMLRPC methods', $help);
+        $help = $this->_server->methodHelp('system.methodHelp', 'system.listMethods');
+        $this->assertContains('Display help message for an XMLRPC method', $help);
+
+        $this->setExpectedException('Zend_XmlRpc_Server_Exception', 'Method "foo" does not exist');
+        $this->_server->methodHelp('foo');
     }
 
     /**
      * methodSignature() test
      *
-     * Call as method call 
+     * Call as method call
      *
      * Expects:
-     * - method: 
-     * 
-     * Returns: array 
+     * - method:
+     *
+     * Returns: array
      */
     public function testMethodSignature()
     {
         $sig = $this->_server->methodSignature('system.methodSignature');
         $this->assertTrue(is_array($sig));
         $this->assertEquals(1, count($sig), var_export($sig, 1));
+
+        $this->setExpectedException('Zend_XmlRpc_Server_Exception', 'Method "foo" does not exist');
+        $this->_server->methodSignature('foo');
     }
 
     /**
      * multicall() test
      *
-     * Call as method call 
+     * Call as method call
      *
      * Expects:
-     * - methods: 
-     * 
-     * Returns: array 
+     * - methods:
+     *
+     * Returns: array
      */
     public function testMulticall()
     {
@@ -302,23 +357,55 @@ class Zend_XmlRpc_ServerTest extends PHPUnit_Framework_TestCase
         $this->assertTrue($response instanceof Zend_XmlRpc_Response, $response->__toString() . "\n\n" . $request->__toString());
         $returns = $response->getReturnValue();
         $this->assertTrue(is_array($returns));
-        $this->assertEquals(2, count($returns));
+        $this->assertEquals(2, count($returns), var_export($returns, 1));
         $this->assertTrue(is_array($returns[0]), var_export($returns[0], 1));
         $this->assertTrue(is_string($returns[1]), var_export($returns[1], 1));
     }
 
+    /**
+     * @group ZF-5635
+     */
+    public function testMulticallHandlesFaults()
+    {
+        $struct = array(
+            array(
+                'methodName' => 'system.listMethods',
+                'params' => array()
+            ),
+            array(
+                'methodName' => 'undefined',
+                'params' => array()
+            )
+        );
+        $request = new Zend_XmlRpc_Request();
+        $request->setMethod('system.multicall');
+        $request->addParam($struct);
+        $response = $this->_server->handle($request);
+
+        $this->assertTrue($response instanceof Zend_XmlRpc_Response, $response->__toString() . "\n\n" . $request->__toString());
+        $returns = $response->getReturnValue();
+        $this->assertTrue(is_array($returns));
+        $this->assertEquals(2, count($returns), var_export($returns, 1));
+        $this->assertTrue(is_array($returns[0]), var_export($returns[0], 1));
+        $this->assertSame(array(
+            'faultCode' => 620, 'faultString' => 'Method "undefined" does not exist'),
+            $returns[1], var_export($returns[1], 1));
+    }
+
     /**
      * Test get/setEncoding()
      */
     public function testGetSetEncoding()
     {
         $this->assertEquals('UTF-8', $this->_server->getEncoding());
-        $this->_server->setEncoding('ISO-8859-1');
+        $this->assertEquals('UTF-8', Zend_XmlRpc_Value::getGenerator()->getEncoding());
+        $this->assertSame($this->_server, $this->_server->setEncoding('ISO-8859-1'));
         $this->assertEquals('ISO-8859-1', $this->_server->getEncoding());
+        $this->assertEquals('ISO-8859-1', Zend_XmlRpc_Value::getGenerator()->getEncoding());
     }
 
     /**
-     * Test request/response encoding 
+     * Test request/response encoding
      */
     public function testRequestResponseEncoding()
     {
@@ -355,7 +442,7 @@ class Zend_XmlRpc_ServerTest extends PHPUnit_Framework_TestCase
         try {
             $this->_server->addFunction($o);
             $this->fail('addFunction() should not accept objects');
-        } catch (Exception $e) {
+        } catch (Zend_XmlRpc_Exception $e) {
             // success
         }
     }
@@ -366,7 +453,14 @@ class Zend_XmlRpc_ServerTest extends PHPUnit_Framework_TestCase
         try {
             $this->_server->loadFunctions($o);
             $this->fail('loadFunctions() should not accept objects');
-        } catch (Exception $e) {
+        } catch (Zend_XmlRpc_Exception $e) {
+            // success
+        }
+
+        try {
+            $this->_server->loadFunctions('foo');
+            $this->fail('loadFunctions() should not accept primitive values');
+        } catch (Zend_XmlRpc_Server_Exception $e) {
             // success
         }
 
@@ -374,18 +468,28 @@ class Zend_XmlRpc_ServerTest extends PHPUnit_Framework_TestCase
         try {
             $this->_server->loadFunctions($o);
             $this->fail('loadFunctions() should not allow non-reflection objects in an array');
-        } catch (Exception $e) {
-            // success
+        } catch (Zend_Server_Exception $e) {
+            $this->assertSame('Invalid method provided', $e->getMessage());
         }
     }
 
+    public function testLoadFunctionsReadsMethodsFromServerDefinitionObjects()
+    {
+        $mockedMethod = $this->getMock('Zend_Server_Method_Definition', array(), array(), '', false,
+            false);
+        $mockedDefinition = $this->getMock('Zend_Server_Definition', array(), array(), '', false, false);
+        $mockedDefinition->expects($this->once())
+                         ->method('getMethods')
+                         ->will($this->returnValue(array('bar' => $mockedMethod)));
+        $this->_server->loadFunctions($mockedDefinition);
+    }
+
     public function testSetClassThrowsExceptionWithInvalidClass()
     {
         try {
             $this->_server->setClass('mybogusclass');
             $this->fail('setClass() should not allow invalid classes');
-        } catch (Exception $e) {
-            // success
+        } catch (Zend_XmlRpc_Exception $e) {
         }
     }
 
@@ -401,14 +505,14 @@ class Zend_XmlRpc_ServerTest extends PHPUnit_Framework_TestCase
         try {
             $this->_server->setRequest('Zend_XmlRpc_Server_testRequest2');
             $this->fail('Invalid request class should throw exception');
-        } catch (Exception $e) {
+        } catch (Zend_XmlRpc_Exception $e) {
             // success
         }
 
         try {
             $this->_server->setRequest($this);
             $this->fail('Invalid request object should throw exception');
-        } catch (Exception $e) {
+        } catch (Zend_XmlRpc_Exception $e) {
             // success
         }
     }
@@ -497,7 +601,7 @@ class Zend_XmlRpc_ServerTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * @see ZF-2872
+     * @group ZF-2872
      */
     public function testCanMarshalBase64Requests()
     {
@@ -510,15 +614,61 @@ class Zend_XmlRpc_ServerTest extends PHPUnit_Framework_TestCase
         $this->assertFalse($response instanceof Zend_XmlRpc_Fault);
         $this->assertEquals($data, $response->getReturnValue());
     }
+
+    /**
+     * @group ZF-6034
+     */
+    public function testPrototypeReturnValueMustReflectDocBlock()
+    {
+        $server = new Zend_XmlRpc_Server();
+        $server->setClass('Zend_XmlRpc_Server_testClass');
+        $table = $server->getDispatchTable();
+        $method = $table->getMethod('test1');
+        foreach ($method->getPrototypes() as $prototype) {
+            $this->assertNotEquals('void', $prototype->getReturnType(), var_export($prototype, 1));
+        }
+    }
+
+    public function testCallingUnregisteredMethod()
+    {
+        $this->setExpectedException('Zend_XmlRpc_Server_Exception',
+            'Unknown instance method called on server: foobarbaz');
+        $this->_server->foobarbaz();
+    }
+
+    public function testSetPersistenceDoesNothing()
+    {
+        $this->assertNull($this->_server->setPersistence('foo'));
+        $this->assertNull($this->_server->setPersistence('whatever'));
+    }
+
+    public function testPassingInvalidRequestClassThrowsException()
+    {
+        $this->setExpectedException('Zend_XmlRpc_Server_Exception', 'Invalid request class');
+        $this->_server->setRequest('stdClass');
+    }
+
+    public function testPassingInvalidResponseClassThrowsException()
+    {
+        $this->setExpectedException('Zend_XmlRpc_Server_Exception', 'Invalid response class');
+        $this->_server->setResponseClass('stdClass');
+    }
+
+    public function testCreatingFaultWithEmptyMessageResultsInUnknownError()
+    {
+        $fault = $this->_server->fault('', 123);
+        $this->assertSame('Unknown Error', $fault->getMessage());
+        $this->assertSame(123, $fault->getCode());
+    }
 }
 
 /**
- * Zend_XmlRpc_Server_testFunction 
+ * Zend_XmlRpc_Server_testFunction
  *
  * Function for use with xmlrpc server unit tests
- * 
- * @param array $var1 
- * @param string $var2 
+ *
+ * @param array $var1
+ * @param string $var2
  * @return string
  */
 function Zend_XmlRpc_Server_testFunction($var1, $var2 = 'optional')
@@ -530,7 +680,7 @@ function Zend_XmlRpc_Server_testFunction($var1, $var2 = 'optional')
  * Zend_XmlRpc_Server_testFunction2
  *
  * Function for use with xmlrpc server unit tests
- * 
+ *
  * @return string
  */
 function Zend_XmlRpc_Server_testFunction2()
@@ -541,21 +691,26 @@ function Zend_XmlRpc_Server_testFunction2()
 
 class Zend_XmlRpc_Server_testClass
 {
+    private $_value1;
+    private $_value2;
+
     /**
      * Constructor
-     * 
+     *
      * @return void
      */
-    public function __construct()
+    public function __construct($value1 = null, $value2 = null)
     {
+        $this->_value1 = $value1;
+        $this->_value2 = $value2;
     }
 
     /**
-     * Test1 
+     * Test1
      *
      * Returns 'String: ' . $string
-     * 
-     * @param string $string 
+     *
+     * @param string $string
      * @return string
      */
     public function test1($string)
@@ -564,11 +719,11 @@ class Zend_XmlRpc_Server_testClass
     }
 
     /**
-     * Test2 
+     * Test2
      *
      * Returns imploded array
-     * 
-     * @param array $array 
+     *
+     * @param array $array
      * @return string
      */
     public static function test2($array)
@@ -577,20 +732,29 @@ class Zend_XmlRpc_Server_testClass
     }
 
     /**
-     * Test3 
+     * Test3
      *
      * Should not be available...
-     * 
+     *
      * @return void
      */
     protected function _test3()
     {
     }
 
+    /**
+     * @param string $arg
+     * @return struct
+     */
+    public function test4($arg)
+    {
+        return array('test1' => $this->_value1, 'test2' => $this->_value2, 'arg' => func_get_args());
+    }
+
     /**
      * Test base64 encoding in request and response
-     * 
-     * @param  base64 $data 
+     *
+     * @param  base64 $data
      * @return base64
      */
     public function base64($data)
